@@ -9,14 +9,21 @@ import sys
 import traceback
 import uuid
 import zlib
-from typing import Dict
+from pathlib import Path
+from typing import Dict, List
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from werkzeug.datastructures import FileStorage
 
-from pandaserver.api.v1.common import generate_response, get_dn, request_validation
-from pandaserver.api.v1.system_api import get_http_endpoint, get_https_endpoint
+from pandaserver.api.v1.common import (
+    generate_response,
+    get_dn,
+    get_endpoint,
+    has_production_role,
+    request_validation,
+)
 from pandaserver.config import panda_config
 from pandaserver.jobdispatcher import Protocol
 from pandaserver.srvcore import CoreUtils
@@ -88,7 +95,7 @@ def upload_jedi_log(req: PandaRequest, file: FileStorage) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_jedi_log
+        Path: /v1/file_server/upload_jedi_log
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -130,11 +137,18 @@ def upload_jedi_log(req: PandaRequest, file: FileStorage) -> Dict:
         # return the URL depending on the protocol
         if panda_config.disableHTTP:
             protocol = "https"
-            server = get_https_endpoint(req)
         else:
             protocol = "http"
-            server = get_http_endpoint(req)
+        success, server = get_endpoint(protocol)
+        if not success:
+            error_message = f"cannot get endpoint: {server}"
+            tmp_logger.error(error_message)
+            tmp_logger.debug("Done")
+            return generate_response(False, error_message)
+
         file_url = f"{protocol}://{server}/cache{jedi_log_directory}/{file_base_name}"
+        tmp_logger.debug("Done")
+        return generate_response(True, data=file_url)
 
     except Exception:
         error_type, error_value = sys.exc_info()[:2]
@@ -143,9 +157,6 @@ def upload_jedi_log(req: PandaRequest, file: FileStorage) -> Dict:
         tmp_logger.debug("Done")
         return generate_response(False, error_message)
 
-    tmp_logger.debug("Done")
-    return generate_response(True, data=file_url)
-
 
 @request_validation(_logger, secure=True, production=True, request_method="POST")
 def update_jedi_log(req: PandaRequest, file: FileStorage) -> Dict:
@@ -156,7 +167,7 @@ def update_jedi_log(req: PandaRequest, file: FileStorage) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/update_jedi_log
+        Path: /v1/file_server/update_jedi_log
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -199,7 +210,7 @@ def download_jedi_log(req: PandaRequest, log_name: str, offset: int = 0) -> str:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/download_jedi_log
+        Path: /v1/file_server/download_jedi_log
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -244,7 +255,7 @@ def upload_cache_file(req: PandaRequest, file: FileStorage) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_cache_file
+        Path: /v1/file_server/upload_cache_file
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -254,7 +265,7 @@ def upload_cache_file(req: PandaRequest, file: FileStorage) -> Dict:
         dict: The system response `{"success": success, "message": message, "data": data}`. When unsuccessful, the message field will indicate the issue.
     """
 
-    tmp_logger = LogWrapper(_logger, f"upload_cache_file-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_logger = LogWrapper(_logger, f"upload_cache_file-{naive_utcnow().isoformat('/')}")
     tmp_logger.debug(f"Start")
 
     # check if using secure connection and the proxy is not limited
@@ -336,6 +347,7 @@ def upload_cache_file(req: PandaRequest, file: FileStorage) -> Dict:
         # decode Footer
         footer = file_content[-8:]
         checksum, _ = struct.unpack("II", footer)
+        checksum = str(checksum)
         tmp_logger.debug(f"CRC from gzip Footer {checksum}")
     except Exception:
         # use None to avoid delay for now
@@ -359,10 +371,17 @@ def upload_cache_file(req: PandaRequest, file: FileStorage) -> Dict:
         if not to_insert:
             tmp_logger.debug("skipped to insert to DB")
         else:
-            # TODO: change to the new API method once implemented
-            status_client, output_client = Client.insertSandboxFileInfo(user_name, file.filename, file_size, checksum)
-            if status_client != 0 or output_client.startswith("ERROR"):
-                error_message = f"ERROR : failed to register file in database with {status_client} {output_client}"
+            status_client, output_client = Client.register_cache_file(user_name, file.filename, file_size, checksum)
+            if status_client != 0:
+                error_message = f"ERROR : failed to register sandbox to DB with {status_client} {output_client}"
+                tmp_logger.error(error_message)
+                tmp_logger.debug("Done")
+                return generate_response(False, error_message)
+
+            success = output_client["success"]
+            message = output_client["message"]
+            if not success:
+                error_message = f"ERROR : failed to register sandbox to DB with {message}"
                 tmp_logger.error(error_message)
                 tmp_logger.debug("Done")
                 return generate_response(False, error_message)
@@ -385,7 +404,7 @@ def touch_cache_file(req: PandaRequest, file_name: str) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/touch_cache_file
+        Path: /v1/file_server/touch_cache_file
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -418,7 +437,7 @@ def delete_cache_file(req: PandaRequest, file_name: str) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/delete_cache_file
+        Path: /v1/file_server/delete_cache_file
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -448,7 +467,7 @@ def register_cache_file(req: PandaRequest, user_name: str, file_name: str, file_
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/register_cache_file
+        Path: /v1/file_server/register_cache_file
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -473,13 +492,15 @@ def register_cache_file(req: PandaRequest, user_name: str, file_name: str, file_
 
     message = global_task_buffer.insertSandboxFileInfo(user_name, host_name, file_name, file_size, checksum)
     if message != "OK":
+        tmp_logger.debug("Done")
         return generate_response(False, message)
 
+    tmp_logger.debug("Done")
     return generate_response(True)
 
 
-@request_validation(_logger, secure=True, request_method="GET")
-def validate_cache_file(req: PandaRequest, file_size: int, checksum: str) -> Dict:
+@request_validation(_logger, secure=True, request_method="POST")
+def validate_cache_file(req: PandaRequest, file_size: int, checksum: int | str) -> Dict:
     """
     Validate cache file
 
@@ -487,12 +508,12 @@ def validate_cache_file(req: PandaRequest, file_size: int, checksum: str) -> Dic
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/validate_cache_file
+        Path: /v1/file_server/validate_cache_file
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
         file_size(int): file size
-        checksum(string): checksum
+        checksum(int): checksum
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. When successful the message will return the host and file name.
@@ -532,7 +553,7 @@ def upload_hpo_checkpoint(req: PandaRequest, file: FileStorage) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_hpo_checkpoint
+        Path: /v1/file_server/upload_hpo_checkpoint
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -593,7 +614,7 @@ def delete_hpo_checkpoint(req: PandaRequest, task_id: str, sub_id: str) -> Dict:
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/delete_hpo_checkpoint
+        Path: /v1/file_server/delete_hpo_checkpoint
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -620,45 +641,91 @@ def delete_hpo_checkpoint(req: PandaRequest, task_id: str, sub_id: str) -> Dict:
 
 
 @request_validation(_logger, secure=True, request_method="POST")
-def upload_file_recovery_request(req: PandaRequest, task_id: int, dry_run: bool = None) -> Dict:
+def upload_file_recovery_request(
+    req: PandaRequest,
+    task_id: int = None,
+    dry_run: bool = None,
+    dataset: str = None,
+    files: List[str] = None,
+    no_child_retry: bool = False,
+    resurrect_datasets: bool = False,
+    force: bool = False,
+    reproduce_parent: bool = False,
+    reproduce_upto_nth_gen: int = 0,
+) -> Dict:
     """
     Upload file recovery request
 
-    Upload request to recover lost files. Requires a secure connection.
+    Upload request to recover lost files. Either task_id or dataset needs to be specified. Requires a secure connection.
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_jedi_log
+        Path: /v1/file_server/upload_file_recovery_request
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        task_id(int): JEDI task ID.
-        dry_run(bool): dry run flag.
+        task_id(int, optional): JEDI task ID. Either task_id or dataset must be provided.
+        dry_run(bool, optional): dry run flag.
+        dataset(string, optional): the dataset name in which to recover files. Either task_id or dataset must be provided.
+        files(list of str, optional): list of file names to recover.
+        no_child_retry(bool, optional): flag to avoid retrying child tasks. Default is False.
+        resurrect_datasets(bool, optional): Specifies whether to resurrect datasets when they were already deleted. Default is False.
+        force(bool, optional): To force recovery even if there is no lost file. Default is False.
+        reproduce_parent(bool, optional): Specifies whether to reproduce the parent task if the input files that originally generated the lost files have been deleted. Default: False.
+        reproduce_upto_nth_gen(int, optional): Defines how many generations of parent tasks should be reproduced. Default 0, meaning no parent tasks are reproduced. When this is set to N>0, reproduce_parent is set to True automatically.
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. When unsuccessful, the message field will indicate the issue.
     """
 
     user_name = req.subprocess_env["SSL_CLIENT_S_DN"]
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     tmp_logger = LogWrapper(_logger, f"put_file_recovery_request < task_id={task_id} >")
     tmp_logger.debug(f"Start user={user_name}")
 
     try:
+        # check that at least task_id or dataset is provided
+        if not task_id and not dataset:
+            error_message = "Either task_id or dataset must be provided"
+            tmp_logger.error(error_message)
+            return generate_response(False, error_message)
+
         # generate the filename
         file_name = f"{panda_config.cache_dir}/recov.{str(uuid.uuid4())}"
+        log_filename = f"jedilog/lost_file_recovery.{str(uuid.uuid4())}.log"
         tmp_logger.debug(f"file={file_name}")
 
+        # check if the user has production manager role
+        is_production_manager = has_production_role(req)
+
         # write the file content
+
         with open(file_name, "w") as file_object:
             data = {
                 "userName": user_name,
                 "creationTime": creation_time,
-                "jediTaskID": task_id,
+                "logFilename": log_filename,
+                "isProductionManager": is_production_manager,
             }
+            if task_id:
+                data["jediTaskID"] = task_id
             if dry_run:
                 data["dryRun"] = True
+            if dataset:
+                data["ds"] = dataset
+            if files:
+                data["files"] = ",".join(files)
+            if no_child_retry:
+                data["noChildRetry"] = True
+            if resurrect_datasets:
+                data["resurrectDS"] = True
+            if force:
+                data["force"] = True
+            if reproduce_parent:
+                data["reproduceParent"] = True
+            if reproduce_upto_nth_gen > 0:
+                data["reproduceUptoNthGen"] = reproduce_upto_nth_gen
 
             json.dump(data, file_object)
     except Exception as exc:
@@ -666,8 +733,17 @@ def upload_file_recovery_request(req: PandaRequest, task_id: int, dry_run: bool
         tmp_logger.error(error_message + traceback.format_exc())
         return generate_response(False, error_message)
 
+    # create an empty log file to be filled later
+    Path(os.path.join(panda_config.cache_dir, log_filename)).touch()
+
+    # return the URL depending on the protocol
+    protocol = "https" if panda_config.disableHTTP else "http"
+    _, server = get_endpoint(protocol)
+    log_file_url = f"{protocol}://{server}/cache/{log_filename}"
+
     tmp_logger.debug("done")
-    return generate_response(True, message="The request was accepted and will be processed in a few minutes")
+    data = {"logFileURL": log_file_url}
+    return generate_response(True, message="The request was accepted and will be processed in a few minutes", data=data)
 
 
 @request_validation(_logger, secure=True, request_method="POST")
@@ -679,7 +755,7 @@ def upload_workflow_request(req: PandaRequest, data: str, dry_run: bool = False,
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_jedi_log
+        Path: /v1/file_server/upload_workflow_request
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -693,7 +769,7 @@ def upload_workflow_request(req: PandaRequest, data: str, dry_run: bool = False,
     """
 
     user_name = req.subprocess_env["SSL_CLIENT_S_DN"]
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     tmp_logger = LogWrapper(_logger, "upload_workflow_request")
 
@@ -767,7 +843,7 @@ def upload_event_picking_request(
 
     API details:
         HTTP Method: POST
-        Path: /file_server/v1/upload_jedi_log
+        Path: /v1/file_server/upload_event_picking_request
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -792,10 +868,10 @@ def upload_event_picking_request(
 
     user_name = req.subprocess_env["SSL_CLIENT_S_DN"]
 
-    tmp_logger = LogWrapper(_logger, f"upload_event_picking_request-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_logger = LogWrapper(_logger, f"upload_event_picking_request-{naive_utcnow().isoformat('/')}")
     tmp_logger.debug(f"Start for {user_name}")
 
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     # get total size
     content_length = _get_content_length(req, tmp_logger)
