@@ -43,11 +43,11 @@ def get_status(req: PandaRequest, job_ids: List[int], timeout: int = 60) -> Dict
 
     API details:
         HTTP Method: GET
-        Path: /job/v1/get_status
+        Path: /v1/job/get_status
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        job_ids(List[int]): list of PanDA job IDs.
+        job_ids(list of int): list of PanDA job IDs.
         timeout(int, optional): The timeout value. Defaults to 60.
 
     Returns:
@@ -57,7 +57,7 @@ def get_status(req: PandaRequest, job_ids: List[int], timeout: int = 60) -> Dict
     tmp_logger.debug("Start")
 
     # The task buffer method expect a comma separated list of job_ids
-    job_ids_str = ",".join(job_ids)
+    job_ids_str = ",".join([str(job_id) for job_id in job_ids])
     timed_method = TimedMethod(global_task_buffer.checkJobStatus, timeout)
     timed_method.run(job_ids_str)
 
@@ -86,11 +86,11 @@ def get_description(self, job_ids: List[int]) -> Dict:
 
     API details:
         HTTP Method: GET
-        Path: /job/v1/get_description
+        Path: /v1/job/get_description
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        job_ids (List[int]): List of PanDA job IDs.
+        job_ids (list of int): List of PanDA job IDs.
         timeout (int, optional): The timeout value. Defaults to 60.
 
     Returns:
@@ -126,11 +126,11 @@ def get_description_incl_archive(req: PandaRequest, job_ids: List[int]) -> Dict:
 
     API details:
         HTTP Method: GET
-        Path: /job/v1/get_description_incl_archive
+        Path: /v1/job/get_description_incl_archive
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables.
-        job_ids (List[int]): List of PanDA job IDs.
+        job_ids (list of int): List of PanDA job IDs.
         timeout (int, optional): The timeout value. Defaults to 60.
 
     Returns:
@@ -152,12 +152,12 @@ def get_description_incl_archive(req: PandaRequest, job_ids: List[int]) -> Dict:
 
     tmp_logger.debug(f"Retrieving data for {str(job_ids)}")
 
-    ret = global_task_buffer.getFullJobStatus(job_ids)
+    ret = global_task_buffer.getFullJobStatus(job_ids, use_json=True)
     tmp_logger.debug("getFullJobStatus end")
     return generate_response(True, data=ret)
 
 
-@request_validation(_logger, secure=True, request_method="GET")
+@request_validation(_logger, secure=False, request_method="GET")
 def generate_offline_execution_script(req: PandaRequest, job_id: int, days: int = None) -> Dict:
     """
     Get execution script for a job.
@@ -166,7 +166,7 @@ def generate_offline_execution_script(req: PandaRequest, job_id: int, days: int
 
     API details:
         HTTP Method: GET
-        Path: /job/v1/generate_offline_execution_script
+        Path: /v1/job/generate_offline_execution_script
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -181,11 +181,11 @@ def generate_offline_execution_script(req: PandaRequest, job_id: int, days: int
     script = global_task_buffer.getScriptOfflineRunning(job_id, days)
 
     if script.startswith("ERROR"):
-        tmp_logger.debug("Failed to generate script")
-        return generate_response(False, message=script)
+        tmp_logger.debug(f"Failed to generate script: {script}")
+        return script
 
     tmp_logger.debug("Done")
-    return generate_response(True, data={"script": script})
+    return script
 
 
 @request_validation(_logger, secure=True, request_method="GET")
@@ -197,7 +197,7 @@ def get_metadata_for_analysis_jobs(req: PandaRequest, task_id: int) -> Dict:
 
     API details:
         HTTP Method: GET
-        Path: /job/v1/get_metadata_for_analysis_jobs
+        Path: /v1/job/get_metadata_for_analysis_jobs
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -213,14 +213,14 @@ def get_metadata_for_analysis_jobs(req: PandaRequest, task_id: int) -> Dict:
     metadata = global_task_buffer.getUserJobMetadata(task_id)
     if not metadata:
         tmp_logger.debug("No metadata found")
-        return generate_response(False, message="No metadata found")
+        return generate_response(True, message="No metadata found", data={})
 
     tmp_logger.debug("Done")
     return generate_response(True, data=metadata)
 
 
 @request_validation(_logger, secure=True, request_method="POST")
-def kill(req, job_ids: List[int], code: int = None, use_email_as_id: bool = False, kill_options: List = []):
+def kill(req, job_ids: List[int], code: int = None, use_email_as_id: bool = False, kill_options: List[str] = []):
     """
     Kill the jobs
 
@@ -228,29 +228,29 @@ def kill(req, job_ids: List[int], code: int = None, use_email_as_id: bool = Fals
 
     API details:
         HTTP Method: POST
-        Path: /job/v1/kill
+        Path: /v1/job/kill
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        job_ids (List): List of PanDA job IDs
+        job_ids (list): List of PanDA job IDs
         code (int, optional): The kill code. Defaults to None.
-        ```
-        code
-        2: expire
-        3: aborted
-        4: expire in waiting
-        7: retry by server
-        8: rebrokerage
-        9: force kill
-        10: fast rebrokerage in overloaded PQ
-        50: kill by JEDI
-        51: reassigned by JEDI
-        52: force kill by JEDI
-        55: killed since task is (almost) done
-        60: workload was terminated by the pilot without actual work
-        91: kill user jobs with prod role
-        99: force kill user jobs with prod role
-        ```
+            ```
+            code
+            2: expire
+            3: aborted
+            4: expire in waiting
+            7: retry by server
+            8: rebrokerage
+            9: force kill
+            10: fast rebrokerage in overloaded PQ
+            50: kill by JEDI
+            51: reassigned by JEDI
+            52: force kill by JEDI
+            55: killed since task is (almost) done
+            60: workload was terminated by the pilot without actual work
+            91: kill user jobs with prod role
+            99: force kill user jobs with prod role
+            ```
         use_email_as_id (bool, optional): Use the email as ID. Defaults to False.
         kill_options (List, optional): Defaults to []. Possible options are: `keepUnmerged`, `jobSubStatus=xyz`
 
@@ -290,11 +290,11 @@ def reassign(req: PandaRequest, job_ids: List[int]):
 
     API details:
         HTTP Method: POST
-        Path: /job/v1/reassign
+        Path: /v1/job/reassign
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        job_ids (List): List of PanDA job IDs
+        job_ids (list): List of PanDA job IDs
 
     Returns:
         dict: The system response `{"success": True}`.
@@ -318,7 +318,7 @@ def set_command(req: PandaRequest, job_id: int, command: str):
 
     API details:
         HTTP Method: POST
-        Path: /job/v1/set_command
+        Path: /v1/job/set_command
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -344,7 +344,7 @@ def set_debug_mode(req: PandaRequest, job_id: int, mode: bool):
 
     API details:
         HTTP Method: POST
-        Path: /job/v1/set_debug_mode
+        Path: /v1/job/set_debug_mode
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -378,13 +378,13 @@ def set_debug_mode(req: PandaRequest, job_id: int, mode: bool):
 @request_validation(_logger, secure=True, request_method="POST")
 def submit(req: PandaRequest, jobs: str):
     """
-    Set the debug mode
+    Submit jobs
 
     Sets the debug mode for a job. Requires a secure connection.
 
     API details:
         HTTP Method: POST
-        Path: /job/v1/submit
+        Path: /v1/job/submit
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
