@@ -7,6 +7,7 @@ from typing import List
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 from pandaserver.api.v1.common import (
     TimedMethod,
@@ -20,6 +21,7 @@ from pandaserver.config import panda_config
 from pandaserver.dataservice.adder_gen import AdderGen
 from pandaserver.jobdispatcher import Protocol
 from pandaserver.srvcore import CoreUtils
+from pandaserver.srvcore.CoreUtils import normalize_cpu_model
 from pandaserver.srvcore.panda_request import PandaRequest
 from pandaserver.taskbuffer.TaskBuffer import TaskBuffer
 
@@ -69,6 +71,7 @@ def acquire_jobs(
     scheduler_id: str = None,
     job_type: str = None,
     via_topic: bool = None,
+    remaining_time=None,
 ) -> dict:
     """
     Acquire jobs
@@ -77,7 +80,7 @@ def acquire_jobs(
 
     API details:
         HTTP Method: POST
-        Path: /pilot/v1/acquire_jobs
+        Path: /v1/pilot/acquire_jobs
 
     Args:
         req(PandaRequest): Internally generated request object containing the environment variables.
@@ -100,13 +103,14 @@ def acquire_jobs(
         job_type(str, optional): Job type, e.g. `user`, `unified`, ... This is necessary on top of the `prodsourcelabel`
                                  to disambiguate the cases of test jobs that can be production or analysis. Optional and defaults to `None`.
         via_topic(bool, optional): Topic for message broker. Optional and defaults to `None`.
+        remaining_time(int, optional): Remaining walltime. Optional and defaults to `None`.
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. The data is a list of job dictionaries.
               When failed, the message contains the error message.
     """
 
-    tmp_logger = LogWrapper(_logger, f"acquire_jobs {datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_logger = LogWrapper(_logger, f"acquire_jobs {naive_utcnow().isoformat('/')}")
     tmp_logger.debug(f"Start for {site_name}")
 
     # get DN and FQANs
@@ -143,12 +147,18 @@ def acquire_jobs(
     except (ValueError, TypeError):
         disk_space = 0
 
+    # convert remaining time
+    try:
+        remaining_time = max(0, remaining_time)
+    except (ValueError, TypeError):
+        remaining_time = 0
+
     tmp_logger.debug(
         f"{site_name}, n_jobs={n_jobs}, memory={memory}, disk={disk_space}, source_label={prod_source_label}, "
         f"node={node}, ce={computing_element}, user={prod_user_id}, proxy={get_proxy_key}, "
         f"task_id={task_id}, DN={real_dn}, role={is_production_manager}, "
         f"bg={background}, rt={resource_type}, harvester_id={harvester_id}, worker_id={worker_id}, "
-        f"scheduler_id={scheduler_id}, job_type={job_type}, via_topic={via_topic}"
+        f"scheduler_id={scheduler_id}, job_type={job_type}, via_topic={via_topic} remaining_time={remaining_time}"
     )
 
     # log the acquire_jobs as it's used for site activity metrics
@@ -189,6 +199,7 @@ def acquire_jobs(
         job_type,
         is_grandly_unified,
         via_topic,
+        remaining_time,
     )
 
     # Time-out
@@ -267,16 +278,20 @@ def get_job_status(req: PandaRequest, job_ids: List[int], timeout: int = 60) ->
 
     Gets the status for a list of jobs. Requires a secure connection.
 
+    API details:
+        HTTP Method: GET
+        Path: /v1/pilot/get_job_status
+
     Args:
         req(PandaRequest): Internally generated request object containing the environment variables.
-        job_ids(List[int]): list of job IDs.
+        job_ids(list): list of job IDs.
         timeout(int, optional): The timeout value. Defaults to 60.
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. The data is a list of job status dictionaries, in the format
-        ```
-        [{"job_id": <job_id_requested>, "status": "not found", "attempt_number": 0}), {"job_id": <job_id>, "status": <status>, "attempt_number": <attempt_nr>}]
-        ```
+            ```
+            [{"job_id": <job_id_requested>, "status": "not found", "attempt_number": 0}), {"job_id": <job_id>, "status": <status>, "attempt_number": <attempt_nr>}]
+            ```
     """
 
     tmp_logger = LogWrapper(_logger, f"get_job_status {job_ids}")
@@ -325,7 +340,7 @@ def update_job(
     meta_data: str = "",
     cpu_conversion_factor: float = None,
     trans_exit_code: str = None,
-    pilot_error_code: str = None,
+    pilot_error_code: int = None,
     pilot_error_diag: str = None,
     exe_error_code: int = None,
     exe_error_diag: str = None,
@@ -359,6 +374,9 @@ def update_job(
     corrupted_files: str = None,
     mean_core_count: int = None,
     cpu_architecture_level: int = None,
+    grid: str = None,
+    source_site: str = None,
+    destination_site: str = None,
     timeout: int = 60,
 ):
     """
@@ -368,7 +386,7 @@ def update_job(
 
     API details:
         HTTP Method: POST
-        Path: /pilot/v1/update_job
+        Path: /v1/pilot/update_job
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -384,7 +402,7 @@ def update_job(
         pilot_id(str, optional): Pilot ID. Optional, defaults to `None`
         batch_id(str, optional): Batch ID. Optional, defaults to `None`
         trans_exit_code(str, optional): Transformation exit code. Optional, defaults to `None`
-        pilot_error_code(str, optional): Pilot error code. Optional, defaults to `None`
+        pilot_error_code(int, optional): Pilot error code. Optional, defaults to `None`
         pilot_error_diag(str, optional): Pilot error message. Optional, defaults to `None`
         exe_error_code(int, optional): Execution error code. Optional, defaults to `None`
         exe_error_diag(str, optional): Execution error message. Optional, defaults to `None`
@@ -414,6 +432,9 @@ def update_job(
         rate_wbytes(int, optional): Measured rate for written bytes. Optional, defaults to `None`
         corrupted_files(str, optional): List of corrupted files in comma separated format. Optional, defaults to `None`
         cpu_architecture_level(int, optional): CPU architecture level (e.g. `x86_64-v3`). Optional, defaults to `None`
+        grid(str, optional): Grid type. Optional, defaults to `None`
+        source_site(str, optional): Source site name. Optional, defaults to `None`
+        destination_site(str, optional): Destination site name. Optional, defaults to `None`
         job_metrics(str, optional): Job metrics. Optional, defaults to `None`
         job_output_report(str, optional): Job output report. Optional, defaults to `""`
         pilot_log(str, optional): Pilot log excerpt. Optional, defaults to `""`
@@ -440,6 +461,7 @@ def update_job(
         f"max_pss={max_pss}, avg_rss={avg_rss}, avg_vmem={avg_vmem}, avg_swap={avg_swap}, avg_pss={avg_pss}, "
         f"tot_rchar={tot_rchar}, tot_wchar={tot_wchar}, tot_rbytes={tot_rbytes}, tot_wbytes={tot_wbytes}, rate_rchar={rate_rchar}, "
         f"rate_wchar={rate_wchar}, rate_rbytes={rate_rbytes}, rate_wbytes={rate_wbytes}, mean_core_count={mean_core_count}, "
+        f"grid={grid}, source_site={source_site}, destination_site={destination_site}, "
         f"corrupted_files={corrupted_files}\n==job_output_report==\n{job_output_report}\n==LOG==\n{pilot_log[:1024]}\n==Meta==\n{meta_data[:1024]}\n"
         f"==Metrics==\n{job_metrics}\n==stdout==\n{stdout})"
     )
@@ -448,12 +470,15 @@ def update_job(
 
     # aborting message
     if job_id == "NULL":
-        return Protocol.Response(Protocol.SC_Success).encode(acceptJson=True)
+        response = Protocol.Response(Protocol.SC_Invalid)
+        return generate_response(success=False, message="job_id is NULL", data=response.data)
 
-    # check status
+    # check the job status is valid
     if job_status not in VALID_JOB_STATES:
-        tmp_logger.warning(f"invalid job_status={job_status} for updateJob")
-        return Protocol.Response(Protocol.SC_Success).encode(acceptJson=True)
+        message = f"Invalid job status: {job_status}"
+        tmp_logger.warning(message)
+        response = Protocol.Response(Protocol.SC_Invalid)
+        return generate_response(success=False, message=message, data=response.data)
 
     # create the job parameter map
     param = {}
@@ -487,6 +512,9 @@ def update_job(
         ("avgSWAP", avg_swap, lambda x: int(float(x))),
         ("avgPSS", avg_pss, lambda x: int(float(x))),
         ("corruptedFiles", corrupted_files, str),
+        ("grid", grid, str),
+        ("sourceSite", source_site, str),
+        ("destinationSite", destination_site, str),
     ]
 
     # Iterate through fields, apply transformations and add to `param`
@@ -549,7 +577,7 @@ def update_job(
         if len(ret) > 0 and not ret[0]:
             message = "Failed to add meta_data"
             tmp_logger.debug(message)
-            return generate_response(False, message)
+            return generate_response(True, message, data={"StatusCode": Protocol.SC_Failed, "ErrorDiag": message})
 
     # add stdout
     if stdout != "":
@@ -563,9 +591,7 @@ def update_job(
         update_state_change = True  # update stateChangeTime to prevent Watcher from finding this job
         param["jobDispatcherErrorDiag"] = None
     elif job_status in ("holding", "transferring"):
-        param["jobDispatcherErrorDiag"] = (
-            f"set to {job_status} by the pilot at {datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime('%Y-%m-%d %H:%M:%S')}"
-        )
+        param["jobDispatcherErrorDiag"] = f"set to {job_status} by the pilot at {naive_utcnow().strftime('%Y-%m-%d %H:%M:%S')}"
 
     # update the job status in the database
     timeout = None if job_status == "holding" else timeout
@@ -575,17 +601,19 @@ def update_job(
     # time-out
     if timed_method.result == Protocol.TimeOutToken:
         message = "Timed out"
-        tmp_logger.debug(message)
-        return generate_response(False, message=message)
+        tmp_logger.error(message)
+        response = Protocol.Response(Protocol.SC_TimeOut)
+        return generate_response(True, message=message, data=response.data)
 
     # no result
     if not timed_method.result:
         message = "Database error"
-        tmp_logger.debug(message)
-        return generate_response(False, message=message)
+        tmp_logger.error(message)
+        response = Protocol.Response(Protocol.SC_Failed)
+        return generate_response(True, message=message, data=response.data)
 
     # generate the response with the result
-    data = {}
+    data = {"StatusCode": Protocol.SC_Success}
     result = timed_method.result
 
     # set the secrets
@@ -617,7 +645,7 @@ def update_jobs_bulk(req, job_list: List, harvester_id: str = None):
 
     API details:
         HTTP Method: POST
-        Path: /pilot/v1/update_jobs_bulk
+        Path: /v1/pilot/update_jobs_bulk
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
@@ -631,19 +659,23 @@ def update_jobs_bulk(req, job_list: List, harvester_id: str = None):
     """
     tmp_logger = LogWrapper(_logger, f"update_jobs_bulk harvester_id={harvester_id}")
     tmp_logger.debug("Start")
-    t_start = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+    t_start = naive_utcnow()
 
     success = False
     message = ""
     data = []
+
     try:
         for job_dict in job_list:
-            job_id = job_dict["jobId"]
-            del job_dict["jobId"]
-            status = job_dict["state"]
-            del job_dict["state"]
-            if "metaData" in job_dict:
-                job_dict["metaData"] = str(job_dict["metaData"])
+            job_id = job_dict["job_id"]
+            del job_dict["job_id"]
+
+            status = job_dict["job_status"]
+            del job_dict["job_status"]
+
+            if "meta_data" in job_dict:
+                job_dict["meta_data"] = str(job_dict["meta_data"])
+
             tmp_ret = update_job(req, job_id, status, **job_dict)
             data.append(tmp_ret)
         success = True
@@ -653,7 +685,7 @@ def update_jobs_bulk(req, job_list: List, harvester_id: str = None):
         data = []
         tmp_logger.error(f"{message}\n{traceback.format_exc()}")
 
-    t_delta = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - t_start
+    t_delta = naive_utcnow() - t_start
     tmp_logger.debug(f"Done. Took {t_delta.seconds}.{t_delta.microseconds // 1000:03d} sec")
     return generate_response(success, message, data)
 
@@ -667,7 +699,7 @@ def update_worker_status(req: PandaRequest, worker_id, harvester_id, status, tim
 
     API details:
         HTTP Method: POST
-        Path: /pilot/v1/update_worker_status
+        Path: /v1/pilot/update_worker_status
 
     Args:
         req(PandaRequest): Internally generated request object containing the environment variables.
@@ -717,14 +749,16 @@ def update_worker_node(
     site: str,
     host_name: str,
     cpu_model: str,
-    n_logical_cpus: int,
-    n_sockets: int,
-    cores_per_socket: int,
-    threads_per_core: int,
-    cpu_architecture: str,
-    cpu_architecture_level: str,
-    clock_speed: float,
-    total_memory: int,
+    panda_queue: str = None,
+    n_logical_cpus: int = None,
+    n_sockets: int = None,
+    cores_per_socket: int = None,
+    threads_per_core: int = None,
+    cpu_architecture: str = None,
+    cpu_architecture_level: str = None,
+    clock_speed: float = None,
+    total_memory: int = None,
+    total_local_disk: int = None,
     timeout: int = 60,
 ):
     """
@@ -734,35 +768,40 @@ def update_worker_node(
 
     API details:
         HTTP Method: POST
-        Path: /pilot/v1/update_worker_node
+        Path: /v1/pilot/update_worker_node
 
     Args:
         req(PandaRequest): Internally generated request object containing the environment variables.
         site(str): Site name (e.g. ATLAS site name, not PanDA queue).
         host_name(str): Host name. In the case of reporting in format `slot@worker_node.example.com`, the slot ID will be parsed out.
-        cpu_model(str): CPU model, e.g. `AMD EPYC 7351`
-        n_logical_cpus(int): Number of logical CPUs: n_sockets * cores_per_socket * threads_per_core.
-                             When SMT is enabled, this is the number of threads. Otherwise it is the number of cores.
-        n_sockets(int): Number of sockets.
-        cores_per_socket(int): Number of cores per socket.
-        threads_per_core(int): Number of threads per core. When SMT is disabled, this is 1. Otherwise a number > 1.
-        cpu_architecture(str): CPU architecture, e.g. `x86_64`
-        cpu_architecture_level(str): CPU architecture level, e.g. `x86-64-v3`
-        clock_speed(float): Clock speed in GHz.
-        total_memory(int): Total memory in MB.
+        cpu_model(str): CPU model, e.g. `AMD EPYC 7351`.
+        panda_queue(str, optional): PanDA queue the worker node is associated to. Optional, defaults to `None`.
+        n_logical_cpus(int, optional): Number of logical CPUs: n_sockets * cores_per_socket * threads_per_core.
+                             When SMT is enabled, this is the number of threads. Otherwise it is the number of cores. Optional, defaults to `None`.
+        n_sockets(int, optional): Number of sockets. Optional, defaults to `None`.
+        cores_per_socket(int, optional): Number of cores per socket. Optional, defaults to `None`.
+        threads_per_core(int, optional): Number of threads per core. When SMT is disabled, this is 1. Otherwise a number > 1. Optional, defaults to `None`.
+        cpu_architecture(str, optional): CPU architecture, e.g. `x86_64`. Optional, defaults to `None`.
+        cpu_architecture_level(str, optional): CPU architecture level, e.g. `x86-64-v3`. Optional, defaults to `None`.
+        clock_speed(float, optional): Clock speed in MHz. Optional, defaults to `None`.
+        total_memory(int, optional): Total memory in MB. Optional, defaults to `None`.
+        total_local_disk(int, optional): Total disk space in GB. Optional, defaults to `None`.
         timeout(int, optional): The timeout value. Defaults to 60.
 
     Returns:
         dict: The system response  `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message.
     """
-    tmp_logger = LogWrapper(_logger, f"update_worker_node site={site} host_name={host_name} cpu_model={cpu_model}")
+    tmp_logger = LogWrapper(_logger, f"update_worker_node site={site} host_name={host_name} cpu_model={cpu_model} panda_queue={panda_queue}")
     tmp_logger.debug("Start")
 
+    cpu_model_normalized = normalize_cpu_model(cpu_model)
+
     timed_method = TimedMethod(global_task_buffer.update_worker_node, timeout)
     timed_method.run(
         site,
         host_name,
         cpu_model,
+        cpu_model_normalized,
         n_logical_cpus,
         n_sockets,
         cores_per_socket,
@@ -771,6 +810,7 @@ def update_worker_node(
         cpu_architecture_level,
         clock_speed,
         total_memory,
+        total_local_disk,
     )
 
     if timed_method.result == Protocol.TimeOutToken:  # timeout
@@ -782,3 +822,72 @@ def update_worker_node(
 
     tmp_logger.debug(f"Done")
     return generate_response(success, message)
+
+
+@request_validation(_logger, secure=True, production=True, request_method="POST")
+def update_worker_node_gpu(
+    req: PandaRequest,
+    site: str,
+    host_name: str,
+    vendor: str,
+    model: str,
+    count: int,
+    vram: int = None,
+    architecture: str = None,
+    framework: str = None,
+    framework_version: str = None,
+    driver_version: str = None,
+    timeout: int = 60,
+):
+    """
+    Update GPUs for a worker node
+
+    Updates the GPUs associated to a worker node in the worker node map. When already found, it updates the `last_seen` time. Requires a secure connection and production role.
+
+    API details:
+        HTTP Method: POST
+        Path: /v1/pilot/update_worker_node_gpu
+
+    Args:
+        req(PandaRequest): Internally generated request object containing the environment variables.
+        site(str): Site name (e.g. ATLAS site name, not PanDA queue).
+        host_name(str): Host name. In the case of reporting in format `slot@worker_node.example.com`, the slot ID will be parsed out.
+        vendor(str): GPU vendor, e.g. `NVIDIA`.
+        model(str): GPU model, e.g. `A100 80GB`.
+        count(int): Number of GPUs of this type in the worker node.
+        vram(int, optional): VRAM memory in MB. Defaults to `None`.
+        architecture(str, optional): GPU architecture, e.g. `Tesla`, `Ampere`... Defaults to `None`.
+        framework(str, optional): Driver framework available, e.g. `CUDA`. Defaults to `None`.
+        framework_version(str, optional): Version of the driver framework, e.g. `12.2`. Defaults to `None`.
+        driver_version(str, optional): Version of the driver, e.g. `575.51.03`. Defaults to `None`
+        timeout(int, optional): The timeout value. Defaults to `60`.
+
+    Returns:
+        dict: The system response  `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message.
+    """
+    tmp_logger = LogWrapper(_logger, f"update_worker_node_gpu site={site} host_name={host_name} vendor={vendor} model={model}")
+    tmp_logger.debug("Start")
+
+    timed_method = TimedMethod(global_task_buffer.update_worker_node_gpu, timeout)
+    timed_method.run(
+        site,
+        host_name,
+        vendor,
+        model,
+        count,
+        vram,
+        architecture,
+        framework,
+        framework_version,
+        driver_version,
+    )
+
+    if timed_method.result == Protocol.TimeOutToken:  # timeout
+        message = "Updating worker node GPU timed out"
+        tmp_logger.error(message)
+        return generate_response(False, message)
+
+    success, message = timed_method.result
+
+    tmp_logger.debug(f"Done")
+    return generate_response(success, message)
