@@ -7,6 +7,7 @@ from typing import Any, Dict, List
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 from pandaserver.api.v1.common import (
     MESSAGE_TASK_ID,
@@ -18,7 +19,9 @@ from pandaserver.api.v1.common import (
     has_production_role,
     request_validation,
 )
+from pandaserver.srvcore.CoreUtils import clean_user_id
 from pandaserver.srvcore.panda_request import PandaRequest
+from pandaserver.taskbuffer.JediTaskSpec import JediTaskSpec
 from pandaserver.taskbuffer.TaskBuffer import TaskBuffer
 
 _logger = PandaLogger().getLogger("api_task")
@@ -38,10 +41,12 @@ def init_task_buffer(task_buffer: TaskBuffer) -> None:
 def retry(
     req: PandaRequest,
     task_id: int,
-    new_parameters: str = None,
-    no_child_retry: bool = None,
-    disable_staging_mode: bool = None,
-    keep_gshare_priority: bool = None,
+    new_parameters: Dict | str = None,
+    no_child_retry: bool = False,
+    discard_events: bool = False,
+    disable_staging_mode: bool = False,
+    keep_gshare_priority: bool = False,
+    ignore_hard_exhausted: bool = False,
 ) -> Dict[str, Any]:
     """
     Task retry
@@ -50,16 +55,18 @@ def retry(
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/retry
+        Path: /v1/task/retry
 
     Args:
         req(PandaRequest): internally generated request object
         task_id(int): JEDI Task ID
-        new_parameters(Dict, optional): a json dictionary with the new parameters for rerunning the task. The new parameters are merged with the existing ones.
+        new_parameters(Dict, optional): a dictionary with the new parameters for rerunning the task. The new parameters are merged with the existing ones.
                                         The parameters are the attributes in the JediTaskSpec object (https://github.com/PanDAWMS/panda-jedi/blob/master/pandajedi/jedicore/JediTaskSpec.py).
-        no_child_retry(bool, optional): if True, the child tasks are not retried
-        disable_staging_mode(bool, optional): if True, the task skips staging state and directly goes to subsequent state
-        keep_gshare_priority(bool, optional): if True, the task keeps current gshare and priority
+        no_child_retry(bool, optional): if True, the child tasks are not retried. Defaults to False
+        discard_events(bool, optional): if True, events will be discarded. Defaults to False
+        disable_staging_mode(bool, optional): if True, the task skips staging state and directly goes to subsequent state. Defaults to False
+        keep_gshare_priority(bool, optional): if True, the task keeps current gshare and priority. Defaults to False
+        ignore_hard_exhausted(bool, optional): if True, the task ignores the limits for hard exhausted state and can be retried even if it is very faulty. Defaults to False
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message. Return code in the data field, 0 for success, others for failure.
@@ -72,6 +79,9 @@ def retry(
 
     # retry with new parameters
     if new_parameters:
+        if isinstance(new_parameters, str):
+            new_parameters = json.loads(new_parameters)
+
         try:
             # get original parameters
             old_parameters_json = global_task_buffer.getTaskParamsPanda(task_id)
@@ -93,17 +103,12 @@ def retry(
         except Exception as e:
             ret = 1, f"new parameter conversion failed with {str(e)}"
     else:
+        # disable ignore_hard_exhausted if not production_role
+        if not production_role and ignore_hard_exhausted:
+            ignore_hard_exhausted = False
         # get command qualifier
-        qualifier = ""
-        for com_key, com_param in [
-            ("sole", no_child_retry),
-            ("discard", no_child_retry),
-            ("staged", disable_staging_mode),
-            ("keep", keep_gshare_priority),
-        ]:
-            if com_param:
-                qualifier += f"{com_key} "
-        qualifier = qualifier.strip()
+        qualifier = JediTaskSpec.get_retry_command_qualifiers(no_child_retry, discard_events, disable_staging_mode, keep_gshare_priority, ignore_hard_exhausted)
+        qualifier = " ".join(qualifier)
         # normal retry
         ret = global_task_buffer.sendCommandTaskPanda(
             task_id,
@@ -113,10 +118,24 @@ def retry(
             properErrorCode=True,
             comQualifier=qualifier,
         )
+
+    if ret[0] == 5:
+        # retry failed analysis jobs
+        job_ids = global_task_buffer.getJobdefIDsForFailedJob(task_id)
+        clean_id = clean_user_id(user)
+        for job_id in job_ids:
+            global_task_buffer.finalizePendingJobs(clean_id, job_id)
+        global_task_buffer.increaseAttemptNrPanda(task_id, 5)
+        return_str = f"retry has been triggered for failed jobs while the task is still {ret[1]}"
+        if not new_parameters:
+            ret = 0, return_str
+        else:
+            ret = 3, return_str
+
     tmp_logger.debug("Done")
 
     data, message = ret
-    success = data == 0
+    success = True
     return generate_response(success, message, data)
 
 
@@ -130,7 +149,7 @@ def resume(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/resume
+        Path: /v1/task/resume
 
     Args:
         req(PandaRequest): internally generated request object
@@ -166,12 +185,11 @@ def release(req: PandaRequest, task_id: int) -> Dict[str, Any]:
     """
     Task release
 
-    Release a given task. This triggers the avalanche for tasks in scouting state or dynamically reconfigures the task to skip over the scouting state.
-    Requires a secure connection and production role.
+    Release a given task by skipping iDDS for staging. Requires a secure connection and production role.
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/release
+        Path: /v1/task/release
 
     Args:
         req(PandaRequest): internally generated request object
@@ -205,7 +223,7 @@ def release(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
 # reassign task to site/cloud
 @request_validation(_logger, secure=True, request_method="POST")
-def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = None, nucleus: str = None, soft: bool = None, mode: str = None):
+def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = None, nucleus: str = None, mode: str = None):
     """
     Task reassign
 
@@ -213,7 +231,7 @@ def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = Non
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/reassign
+        Path: /v1/task/reassign
 
     Args:
         req(PandaRequest): internally generated request object
@@ -221,8 +239,7 @@ def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = Non
         site(str, optional): site name
         cloud(str, optional): cloud name
         nucleus(str, optional): nucleus name
-        soft(bool, optional): soft reassign
-        mode(str, optional): soft/nokill reassign
+        mode(str, optional): `kill` (kills all jobs, default), `soft` (kills queued jobs) or `nokill` (doesn't kill jobs)
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message. Return code in the data field, 0 for success, others for failure.
@@ -242,9 +259,10 @@ def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = Non
     is_production_role = has_production_role(req)
 
     # reassign to site, nucleus or cloud
-    if site:
+    # note that ProdSys sets site or nucleus to "" for a rebrokerage
+    if site is not None:
         comment = f"site:{site}:y"  # set 'y' to go back to oldStatus immediately
-    elif nucleus:
+    elif nucleus is not None:
         comment = f"nucleus:{nucleus}:n"
     else:
         comment = f"cloud:{cloud}:n"
@@ -252,7 +270,7 @@ def reassign(req: PandaRequest, task_id: int, site: str = None, cloud: str = Non
     # set additional modes
     if mode == "nokill":
         comment += ":nokill reassign"
-    elif mode == "soft" or soft is True:
+    elif mode == "soft":
         comment += ":soft reassign"
 
     ret = global_task_buffer.sendCommandTaskPanda(
@@ -280,7 +298,7 @@ def pause(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/pause
+        Path: /v1/task/pause
 
     Args:
         req(PandaRequest): internally generated request object
@@ -320,7 +338,7 @@ def kill(req: PandaRequest, task_id: int = None, broadcast: bool = False) -> Dic
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/kill
+        Path: /v1/task/kill
 
     Args:
         req(PandaRequest): internally generated request object
@@ -368,30 +386,30 @@ def kill_unfinished_jobs(req: PandaRequest, task_id: int, code: int = None, use_
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/kill_unfinished_jobs
+        Path: /v1/task/kill_unfinished_jobs
 
     Args:
         req(PandaRequest): internally generated request object containing the env variables
-        task_id (int): JEDI task ID
-        code (int, optional): The kill code. Defaults to None.
-        ```
-        code
-        2: expire
-        3: aborted
-        4: expire in waiting
-        7: retry by server
-        8: rebrokerage
-        9: force kill
-        10: fast rebrokerage in overloaded PQ
-        50: kill by JEDI
-        51: reassigned by JEDI
-        52: force kill by JEDI
-        55: killed since task is (almost) done
-        60: workload was terminated by the pilot without actual work
-        91: kill user jobs with prod role
-        99: force kill user jobs with prod role
-        ```
-        use_email_as_id (bool, optional): Use the email as ID. Defaults to False.
+        task_id(int): JEDI task ID
+        code(int, optional): The kill code. Defaults to None.
+            ```
+            code
+            2: expire
+            3: aborted
+            4: expire in waiting
+            7: retry by server
+            8: rebrokerage
+            9: force kill
+            10: fast rebrokerage in overloaded PQ
+            50: kill by JEDI
+            51: reassigned by JEDI
+            52: force kill by JEDI
+            55: killed since task is (almost) done
+            60: workload was terminated by the pilot without actual work
+            91: kill user jobs with prod role
+            99: force kill user jobs with prod role
+            ```
+        use_email_as_id(bool, optional): Use the email as ID. Defaults to False.
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. The data field contains a list of bools indicating the success of the kill operations.
@@ -432,7 +450,7 @@ def finish(req: PandaRequest, task_id: int, soft: bool = False, broadcast: bool
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/finish
+        Path: /v1/task/finish
 
     Args:
         req(PandaRequest): internally generated request object
@@ -487,7 +505,7 @@ def reactivate(req: PandaRequest, task_id: int, keep_attempt_nr: bool = False, t
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/reactivate
+        Path: /v1/task/reactivate
 
     Args:
         req(PandaRequest): internally generated request object
@@ -513,7 +531,7 @@ def reactivate(req: PandaRequest, task_id: int, keep_attempt_nr: bool = False, t
 
     tmp_logger.debug("Done")
 
-    return generate_response(success, message)
+    return generate_response(success, message, code)
 
 
 @request_validation(_logger, secure=True, production=True, request_method="POST")
@@ -521,11 +539,11 @@ def avalanche(req: PandaRequest, task_id: int) -> Dict[str, Any]:
     """
     Task avalanche
 
-    Avalanche a given task. Requires a secure connection and production role.
+    Avalanche a given task. This triggers the avalanche for tasks in scouting state or dynamically reconfigures the task to skip over the scouting state. Requires a secure connection and production role.
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/avalanche
+        Path: /v1/task/avalanche
 
     Args:
         req(PandaRequest): internally generated request object
@@ -557,7 +575,7 @@ def avalanche(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
 
 @request_validation(_logger, secure=True, request_method="POST")
-def reload_input(req: PandaRequest, task_id: int) -> Dict[str, Any]:
+def reload_input(req: PandaRequest, task_id: int, ignore_hard_exhausted: bool = False) -> Dict[str, Any]:
     """
     Reload input
 
@@ -565,11 +583,12 @@ def reload_input(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/reload_input
+        Path: /v1/task/reload_input
 
     Args:
         req(PandaRequest): internally generated request object
         task_id(int): JEDI Task ID
+        ignore_hard_exhausted(bool, optional): ignore the limits for hard exhausted
 
     Returns:
         dict: The system response. True for success, False for failure, and an error message. Return code in the data field, 0 for success, others for failure.
@@ -587,7 +606,15 @@ def reload_input(req: PandaRequest, task_id: int) -> Dict[str, Any]:
         tmp_logger.error("Failed due to invalid task_id")
         return generate_response(False, message=MESSAGE_TASK_ID)
 
-    ret = global_task_buffer.sendCommandTaskPanda(task_id, user, is_production_role, "incexec", comComment="{}", propeErrorCode=True)
+    # allow ignore_hard_exhausted only for production role
+    if not is_production_role and ignore_hard_exhausted:
+        ignore_hard_exhausted = False
+
+    # specify ignore_hard_exhausted as a command qualifier in command's comment
+    com_qualifier = JediTaskSpec.get_retry_command_qualifiers(ignore_hard_exhausted=ignore_hard_exhausted)
+    com_comment = json.dumps([{}, com_qualifier])
+
+    ret = global_task_buffer.sendCommandTaskPanda(task_id, user, is_production_role, "incexec", comComment=com_comment, properErrorCode=True)
     data, message = ret
     success = data == 0
 
@@ -597,7 +624,7 @@ def reload_input(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
 
 @request_validation(_logger, secure=True, production=True, request_method="POST")
-def reassign_global_share(req: PandaRequest, task_id_list: List, share: str, reassign_running_jobs: bool) -> Dict[str, Any]:
+def reassign_global_share(req: PandaRequest, task_id_list: List[int], share: str, reassign_running_jobs: bool) -> Dict[str, Any]:
     """
     Reassign the global share of a task
 
@@ -605,11 +632,11 @@ def reassign_global_share(req: PandaRequest, task_id_list: List, share: str, rea
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/reassign_global_share
+        Path: /v1/task/reassign_global_share
 
     Args:
         req(PandaRequest): internally generated request object
-        task_id_list(List): List of JEDI task IDs to reassign
+        task_id_list(list): List of JEDI task IDs to reassign
         share(str): destination share
         reassign_running_jobs(bool): whether you want to reassign existing running jobs
 
@@ -641,7 +668,7 @@ def enable_jumbo_jobs(req: PandaRequest, task_id: int, jumbo_jobs_total: int, ju
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/reassign_global_share
+        Path: /v1/task/enable_jumbo_jobs
 
     Args:
         req(PandaRequest): internally generated request object
@@ -680,7 +707,7 @@ def get_jumbo_job_datasets(req: PandaRequest, from_offset: int, to_offset: int =
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_jumbo_job_datasets
+        Path: /v1/task/get_jumbo_job_datasets
 
     Args:
         req(PandaRequest): internally generated request object
@@ -715,7 +742,7 @@ def enable_job_cloning(
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/enable_job_cloning
+        Path: /v1/task/enable_job_cloning
 
     Args:
         req(PandaRequest): internally generated request object
@@ -744,7 +771,7 @@ def disable_job_cloning(req: PandaRequest, jedi_task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/disable_job_cloning
+        Path: /v1/task/disable_job_cloning
 
     Args:
         req(PandaRequest): internally generated request object
@@ -770,7 +797,7 @@ def increase_attempts(req: PandaRequest, task_id: int, increase: int) -> Dict[st
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/increase_attempts
+        Path: /v1/task/increase_attempts
 
     Args:
         req(PandaRequest): internally generated request object
@@ -817,7 +844,7 @@ def get_status(req, task_id):
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_status
+        Path: /v1/task/get_status
 
     Args:
         req(PandaRequest): internally generated request object
@@ -856,7 +883,7 @@ def get_details(req: PandaRequest, task_id: int, include_parameters: bool = Fals
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_details
+        Path: /v1/task/get_details
 
     Args:
         req(PandaRequest): internally generated request object
@@ -892,7 +919,7 @@ def change_attribute(req: PandaRequest, task_id: int, attribute_name: str, value
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/change_attribute
+        Path: /v1/task/change_attribute
 
     Args:
         req(PandaRequest): internally generated request object
@@ -934,41 +961,33 @@ def change_attribute(req: PandaRequest, task_id: int, attribute_name: str, value
 
 
 @request_validation(_logger, secure=True, production=True, request_method="POST")
-def change_modification_time(req: PandaRequest, task_id: int, positive_hour_offset: int) -> Dict[str, Any]:
+def change_modification_time(req: PandaRequest, task_id: int, hour_offset: int) -> Dict[str, Any]:
     """
     Change task modification time
 
-    Change the modification time for a task to `now() + positive_hour_offset`. Requires a secure connection and production role.
+    Change the modification time for a task to `now() + hour_offset`. Requires a secure connection and production role.
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/change_modification_time
+        Path: /v1/task/change_modification_time
 
     Args:
         req(PandaRequest): internally generated request object
         task_id(int): JEDI task ID
-        positive_hour_offset(int): number of hours to add to the current time
+        hour_offset(int): number of hours to add to the current time. Use a negative value (e.g. -12) to trigger task brokerage.
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message. Return code in the data field, 0 for success, others for failure.
     """
-    tmp_logger = LogWrapper(_logger, f"change_modification_time < task_id={task_id} positive_hour_offset={positive_hour_offset} >")
+    tmp_logger = LogWrapper(_logger, f"change_modification_time < task_id={task_id} hour_offset={hour_offset} >")
     tmp_logger.debug("Start")
 
-    # check task_id
-    try:
-        task_id = int(task_id)
-    except ValueError:
-        tmp_logger.error("Failed due to invalid task_id")
-        return generate_response(False, message=MESSAGE_TASK_ID)
-
     # check offset
     try:
-        positive_hour_offset = int(positive_hour_offset)
-        new_modification_time = datetime.datetime.now() + datetime.timedelta(hours=positive_hour_offset)
+        new_modification_time = datetime.datetime.now() + datetime.timedelta(hours=hour_offset)
     except ValueError:
-        tmp_logger.error("Failed due to invalid positive_hour_offset")
-        return generate_response(False, message=f"failed to convert {positive_hour_offset} to time")
+        tmp_logger.error("Failed due to invalid hour_offset")
+        return generate_response(False, message=f"failed to convert {hour_offset} to time")
 
     n_tasks_changed = global_task_buffer.changeTaskAttributePanda(task_id, "modificationTime", new_modification_time)
     if n_tasks_changed is None:  # method excepted
@@ -992,7 +1011,7 @@ def change_priority(req: PandaRequest, task_id: int, priority: int):
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/change_priority
+        Path: /v1/task/change_priority
 
     Args:
         req(PandaRequest): internally generated request object
@@ -1036,21 +1055,21 @@ def change_priority(req: PandaRequest, task_id: int, priority: int):
 
 
 @request_validation(_logger, secure=True, production=True, request_method="POST")
-def change_split_rule(req: PandaRequest, task_id: int, attribute_name: str, value: int) -> Dict[str, Any]:
+def change_split_rule(req: PandaRequest, task_id: int, attribute_name: str, value: str) -> Dict[str, Any]:
     """
     Change the split rule
 
-    Change the split rule for a task. Requires a secure connection and production role.
+    Change the split rule for a task by modifying or adding an `attribute_name=value pair`. Requires a secure connection and production role.
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/change_split_rule
+        Path: /v1/task/change_split_rule
 
     Args:
         req(PandaRequest): internally generated request object
         task_id(int): JEDI task ID
-        attribute_name(str): split rule attribute to change
-        value(int): value to set to the attribute
+        attribute_name(str): split rule attribute to change. The allowed attributes are one of: `"AI", "TW", "EC", "ES", "MF", "NG", "NI", "NF", "NJ", "AV", "IL", "LI", "LC", "CC", "OT", "UZ"`
+        value(str): value to set to the attribute
 
     Returns:
         dict: The system response `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message.
@@ -1088,7 +1107,7 @@ def change_split_rule(req: PandaRequest, task_id: int, attribute_name: str, valu
 
 
 @request_validation(_logger, secure=True, request_method="GET")
-def get_tasks_modified_since(req, since: str, dn: str = "", full: bool = False, min_task_id: int = None, prod_source_label: str = "user") -> Dict[str, Any]:
+def get_tasks_modified_since(req, since: str, dn: str = None, full: bool = False, min_task_id: int = None, prod_source_label: str = "user") -> Dict[str, Any]:
     """
     Get tasks modified since
 
@@ -1096,7 +1115,7 @@ def get_tasks_modified_since(req, since: str, dn: str = "", full: bool = False,
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_tasks_modified_since
+        Path: /v1/task/get_tasks_modified_since
 
     Args:
         req(PandaRequest): internally generated request object
@@ -1115,11 +1134,6 @@ def get_tasks_modified_since(req, since: str, dn: str = "", full: bool = False,
     if not dn:
         dn = get_dn(req)
 
-    try:
-        min_task_id = int(min_task_id)
-    except ValueError:
-        min_task_id = None
-
     tmp_logger.debug(f"parameters dn:{dn} since:{since} full:{full} min_task_id:{min_task_id} prod_source_label:{prod_source_label}")
 
     tasks = global_task_buffer.getJediTasksInTimeRange(dn, since, full, min_task_id, prod_source_label)
@@ -1130,7 +1144,7 @@ def get_tasks_modified_since(req, since: str, dn: str = "", full: bool = False,
 
 
 @request_validation(_logger, secure=True, request_method="GET")
-def get_datasets_and_files(req, task_id, dataset_types: List = ("input", "pseudo_input")) -> Dict[str, Any]:
+def get_datasets_and_files(req, task_id, dataset_types: List[str] = ("input", "pseudo_input")) -> Dict[str, Any]:
     """
     Get datasets and files
 
@@ -1159,7 +1173,7 @@ def get_datasets_and_files(req, task_id, dataset_types: List = ("input", "pseudo
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_datasets_and_files
+        Path: /v1/task/get_datasets_and_files
 
     Args:
         req(PandaRequest): internally generated request object
@@ -1195,7 +1209,7 @@ def get_job_ids(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_job_ids
+        Path: /v1/task/get_job_ids
 
     Args:
         req(PandaRequest): internally generated request object
@@ -1229,7 +1243,7 @@ def submit(req: PandaRequest, task_parameters: Dict, parent_tid: int = None) ->
 
     API details:
         HTTP Method: POST
-        Path: /task/v1/submit
+        Path: /v1/task/submit
 
     Args:
         req(PandaRequest): internally generated request object
@@ -1240,7 +1254,7 @@ def submit(req: PandaRequest, task_parameters: Dict, parent_tid: int = None) ->
         dict: The system response `{"success": success, "message": message, "data": data}`. True for success, False for failure, and an error message.
               Return code in the data field, 0 for success, others for failure.
     """
-    tmp_log = LogWrapper(_logger, f"submit {datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"submit {naive_utcnow().isoformat('/')}")
     tmp_log.debug("Start")
 
     user = get_dn(req)
@@ -1251,7 +1265,7 @@ def submit(req: PandaRequest, task_parameters: Dict, parent_tid: int = None) ->
     ret = global_task_buffer.insertTaskParamsPanda(task_parameters, user, is_production_role, fqans, properErrorCode=True, parent_tid=parent_tid, decode=False)
 
     code, message = ret
-    success = code == 0
+    success = code in (0, 3)
     if not success:
         return generate_response(False, message=message, data=code)
 
@@ -1280,7 +1294,7 @@ def get_task_parameters(req: PandaRequest, task_id: int) -> Dict[str, Any]:
 
     API details:
         HTTP Method: GET
-        Path: /task/v1/get_task_parameters
+        Path: /v1/task/get_task_parameters
 
     Args:
         req(PandaRequest): internally generated request object
