@@ -167,6 +167,10 @@ if "configurator_use_cert" not in tmpSelf.__dict__:
 if "add_serialized" not in tmpSelf.__dict__:
     tmpSelf.__dict__["add_serialized"] = False
 
+# disable file aggregation
+if "disable_file_aggregation" not in tmpSelf.__dict__:
+    tmpSelf.__dict__["disable_file_aggregation"] = False
+
 # dict for plugins
 g_pluginMap = {}
 
