@@ -9,6 +9,7 @@ import traceback
 import requests
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import get_sql_IN_bind_variables, naive_utcnow
 from pandacommon.pandautils.thread_utils import GenericThread
 from urllib3.exceptions import InsecureRequestWarning
 
@@ -151,7 +152,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                                         _, res_missing = taskBuffer.querySQLS(sql_missing, var_map)
                                         missing_ids = [p for p, in res_missing]
                                         tmp_log.debug(f"missing {tmpFileSpec.destinationDBlock} to kill {missing_ids}")
-                                        Client.killJobs(missing_ids, 2)
+                                        Client.kill_jobs(missing_ids, 2)
                                         killed_for_bad_record = True
                                         break
                                     elif datasetSpec.status == "deleted":
@@ -166,7 +167,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                                         _, res_deleted = taskBuffer.querySQLS(sql_deleted, var_map)
                                         deleted_ids = [p for p, in res_deleted]
                                         tmp_log.debug(f"deleted {tmpFileSpec.destinationDBlock} to kill {deleted_ids}")
-                                        Client.killJobs(deleted_ids, 2)
+                                        Client.kill_jobs(deleted_ids, 2)
                                         killed_for_bad_record = True
                                         break
                                     else:
@@ -191,7 +192,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     # finalize failed jobs
     _logger.debug("check stuck merging jobs")
     try:
-        timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=2)
+        timeLimit = naive_utcnow() - datetime.timedelta(hours=2)
         # get PandaIDs
         var_map = {}
         var_map[":prodSourceLabel"] = "managed"
@@ -288,7 +289,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     _logger.debug(f"timeout : {str(workflow_timeout_map)}")
 
     # check heartbeat for analysis jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=workflow_timeout_map["analysis"])
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=workflow_timeout_map["analysis"])
     var_map = {}
     var_map[":modificationTime"] = timeLimit
     var_map[":prodSourceLabel1"] = "panda"
@@ -311,7 +312,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             thr.join()
 
     # check heartbeat for analysis jobs in transferring
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=workflow_timeout_map["analysis"])
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=workflow_timeout_map["analysis"])
     var_map = {}
     var_map[":modificationTime"] = timeLimit
     var_map[":prodSourceLabel1"] = "panda"
@@ -331,7 +332,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             thr.join()
 
     # check heartbeat for sent jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=30)
+    timeLimit = naive_utcnow() - datetime.timedelta(minutes=30)
     var_map = {}
     var_map[":jobStatus"] = "sent"
     var_map[":modificationTime"] = timeLimit
@@ -350,7 +351,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             thr.join()
 
     # check heartbeat for 'holding' analysis/ddm jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=3)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=3)
     # get XMLs
     xmlIDs = set()
     # xmlFiles = os.listdir(panda_config.logdir)
@@ -387,7 +388,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
 
     # check heartbeat for high prio production jobs
     timeOutVal = 3
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=timeOutVal)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=timeOutVal)
     sql = "SELECT PandaID FROM ATLAS_PANDA.jobsActive4 WHERE jobStatus=:jobStatus AND currentPriority>:pLimit "
     sql += "AND (modificationTime<:modificationTime OR (endTime IS NOT NULL AND endTime<:endTime))"
     var_map = {}
@@ -417,7 +418,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     if not timeOutVal:
         timeOutVal = 48
     timeOutVal *= 60
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=timeOutVal)
+    timeLimit = naive_utcnow() - datetime.timedelta(minutes=timeOutVal)
     sql = "SELECT PandaID FROM ATLAS_PANDA.jobsActive4 WHERE jobStatus=:jobStatus AND (modificationTime<:modificationTime OR (endTime IS NOT NULL AND endTime<:endTime))"
     var_map = {}
     var_map[":modificationTime"] = timeLimit
@@ -452,21 +453,15 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         sqlX = sql
         if workflow == "production":
             if len(workflows) > 2:
-                sqlX += "AND (s.data.workflow IS NULL OR s.data.workflow NOT IN ("
-                for ng_workflow in workflows:
-                    if ng_workflow in ["production", "analysis"]:
-                        continue
-                    tmp_key = f":w_{ng_workflow}"
-                    var_map[tmp_key] = ng_workflow
-                    sqlX += f"{tmp_key},"
-                sqlX = sqlX[:-1]
-                sqlX += ")) "
+                ng_workflow_var_names_str, ng_workflow_var_map = get_sql_IN_bind_variables(workflows, prefix=":w_", value_as_suffix=True)
+                sqlX += f"AND (s.data.workflow IS NULL OR s.data.workflow NOT IN ({ng_workflow_var_names_str})) "
+                var_map.update(ng_workflow_var_map)
         else:
             tmp_key = f":w_{workflow}"
             sqlX += f"AND s.data.workflow={tmp_key} "
             var_map[tmp_key] = workflow
         timeOutVal = workflow_timeout_map[workflow]
-        timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=timeOutVal)
+        timeLimit = naive_utcnow() - datetime.timedelta(hours=timeOutVal)
         var_map[":modificationTime"] = timeLimit
         status, res = taskBuffer.querySQLS(sqlX, var_map)
         if res is None:
@@ -491,7 +486,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     _memoryCheck("reassign")
 
     # kill long-waiting jobs in defined table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=7)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=7)
     status, res = taskBuffer.querySQLS(
         "SELECT PandaID,cloud,prodSourceLabel FROM ATLAS_PANDA.jobsDefined4 WHERE creationTime<:creationTime",
         {":creationTime": timeLimit},
@@ -504,10 +499,10 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             jobs.append(pandaID)
     if len(jobs):
         _logger.debug(f"killJobs for Defined ({str(jobs)})")
-        Client.killJobs(jobs, 2)
+        Client.kill_jobs(jobs, 2)
 
     # kill long-waiting jobs in active table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=7)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=7)
     var_map = {}
     var_map[":jobStatus"] = "activated"
     var_map[":creationTime"] = timeLimit
@@ -521,7 +516,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             jobs.append(id)
     if len(jobs):
         _logger.debug(f"killJobs for Active ({str(jobs)})")
-        Client.killJobs(jobs, 2)
+        Client.kill_jobs(jobs, 2)
 
     # fast rebrokerage at PQs where Nq/Nr overshoots
     _logger.debug("fast rebrokerage at PQs where Nq/Nr overshoots")
@@ -632,7 +627,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                             iJob = 0
                             while iJob < len(jediJobs):
                                 _logger.debug(f"reassignJobs for JEDI at Nq/Nr overshoot site {computingSite} ({str(jediJobs[iJob:iJob + nJob])})")
-                                Client.killJobs(jediJobs[iJob : iJob + nJob], 10, keepUnmerged=True)
+                                Client.kill_jobs(jediJobs[iJob : iJob + nJob], 10, keep_unmerged=True)
                                 iJob += nJob
     except Exception as e:
         _logger.error(f"failed with {str(e)} {traceback.format_exc()}")
@@ -641,8 +636,8 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     inactiveTimeLimitSite = 2
     inactiveTimeLimitJob = 4
     inactivePrioLimit = 800
-    timeLimitSite = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=inactiveTimeLimitSite)
-    timeLimitJob = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=inactiveTimeLimitJob)
+    timeLimitSite = naive_utcnow() - datetime.timedelta(hours=inactiveTimeLimitSite)
+    timeLimitJob = naive_utcnow() - datetime.timedelta(hours=inactiveTimeLimitJob)
     # get PandaIDs
     sql = "SELECT distinct computingSite FROM ATLAS_PANDA.jobsActive4 "
     sql += "WHERE prodSourceLabel=:prodSourceLabel "
@@ -715,7 +710,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                 iJob = 0
                 while iJob < len(jediJobs):
                     _logger.debug(f"reassignJobs for JEDI at inactive site {tmpSite} ({jediJobs[iJob:iJob + nJob]})")
-                    Client.killJobs(jediJobs[iJob : iJob + nJob], 51, keepUnmerged=True)
+                    Client.kill_jobs(jediJobs[iJob : iJob + nJob], 51, keep_unmerged=True)
                     iJob += nJob
 
     # reassign defined jobs in defined table
@@ -723,7 +718,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     if not timeoutValue:
         timeoutValue = 4
     timeoutValue *= 60
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=timeoutValue)
+    timeLimit = naive_utcnow() - datetime.timedelta(minutes=timeoutValue)
     # get PandaIDs
     status, res = taskBuffer.lockJobsForReassign(
         "ATLAS_PANDA.jobsDefined4",
@@ -748,11 +743,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jediJobs):
             _logger.debug(f"reassignJobs for JEDI defined jobs ({jediJobs[iJob:iJob + nJob]})")
-            Client.killJobs(jediJobs[iJob : iJob + nJob], 51, keepUnmerged=True)
+            Client.kill_jobs(jediJobs[iJob : iJob + nJob], 51, keep_unmerged=True)
             iJob += nJob
 
     # reassign stalled defined build and non-JEDI jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=timeoutValue)
+    timeLimit = naive_utcnow() - datetime.timedelta(minutes=timeoutValue)
     var_map = {}
     var_map[":jobStatus"] = "defined"
     var_map[":prodSourceLabel_p"] = "panda"
@@ -768,11 +763,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             jobs.append(id)
     # kill
     if len(jobs):
-        Client.killJobs(jobs, 2)
+        Client.kill_jobs(jobs, 2)
         _logger.debug(f"reassign stalled defined build and non-JEDI jobs with timeout {timeoutValue}min ({str(jobs)})")
 
     # reassign long-waiting jobs in defined table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=12)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=12)
     status, res = taskBuffer.lockJobsForReassign("ATLAS_PANDA.jobsDefined4", timeLimit, [], ["managed"], [], [], [], True)
     jediJobs = []
     if res is not None:
@@ -788,11 +783,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jediJobs):
             _logger.debug(f"reassignJobs for long JEDI in defined table ({jediJobs[iJob:iJob + nJob]})")
-            Client.killJobs(jediJobs[iJob : iJob + nJob], 51, keepUnmerged=True)
+            Client.kill_jobs(jediJobs[iJob : iJob + nJob], 51, keep_unmerged=True)
             iJob += nJob
 
     # reassign too long activated jobs in active table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=2)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=2)
     status, res = taskBuffer.lockJobsForReassign(
         "ATLAS_PANDA.jobsActive4",
         timeLimit,
@@ -829,11 +824,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jediJobs):
             _logger.debug(f"reassignJobs for long activated JEDI in active table ({jediJobs[iJob:iJob + nJob]})")
-            Client.killJobs(jediJobs[iJob : iJob + nJob], 51, keepUnmerged=True)
+            Client.kill_jobs(jediJobs[iJob : iJob + nJob], 51, keep_unmerged=True)
             iJob += nJob
 
     # reassign too long starting jobs in active table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=48)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=48)
     status, res = taskBuffer.lockJobsForReassign(
         "ATLAS_PANDA.jobsActive4",
         timeLimit,
@@ -862,11 +857,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jediJobs):
             _logger.debug(f"reassignJobs for long stating JEDI in active table ({jediJobs[iJob:iJob + nJob]})")
-            Client.killJobs(jediJobs[iJob : iJob + nJob], 51, keepUnmerged=True)
+            Client.kill_jobs(jediJobs[iJob : iJob + nJob], 51, keep_unmerged=True)
             iJob += nJob
 
     # kill too long-standing analysis jobs in active table
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=7)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=7)
     var_map = {}
     var_map[":prodSourceLabel1"] = "test"
     var_map[":prodSourceLabel2"] = "panda"
@@ -882,11 +877,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             jobs.append(id)
     # kill
     if len(jobs):
-        Client.killJobs(jobs, 2)
+        Client.kill_jobs(jobs, 2)
         _logger.debug(f"killJobs for Anal Active ({str(jobs)})")
 
     # kill too long pending jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=1)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=1)
     var_map = {}
     var_map[":jobStatus"] = "pending"
     var_map[":creationTime"] = timeLimit
@@ -905,11 +900,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             iJob = 0
             while iJob < len(jobs):
                 _logger.debug(f"killJobs for Pending ({str(jobs[iJob:iJob + nJob])})")
-                Client.killJobs(jobs[iJob : iJob + nJob], 4)
+                Client.kill_jobs(jobs[iJob : iJob + nJob], 4)
                 iJob += nJob
 
     # kick waiting ES merge jobs which were generated from fake co-jumbo
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=10)
+    timeLimit = naive_utcnow() - datetime.timedelta(minutes=10)
     var_map = {}
     var_map[":jobStatus"] = "waiting"
     var_map[":creationTime"] = timeLimit
@@ -931,11 +926,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             iJob = 0
             while iJob < len(jobs):
                 _logger.debug(f"kick waiting ES merge ({str(jobs[iJob:iJob + nJob])})")
-                Client.killJobs(jobs[iJob : iJob + nJob], 2)
+                Client.kill_jobs(jobs[iJob : iJob + nJob], 2)
                 iJob += nJob
 
     # kill too long waiting jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=1)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=1)
     var_map = {}
     var_map[":jobStatus"] = "waiting"
     var_map[":creationTime"] = timeLimit
@@ -954,11 +949,11 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             iJob = 0
             while iJob < len(jobs):
                 _logger.debug(f"killJobs for Waiting ({str(jobs[iJob:iJob + nJob])})")
-                Client.killJobs(jobs[iJob : iJob + nJob], 4)
+                Client.kill_jobs(jobs[iJob : iJob + nJob], 4)
                 iJob += nJob
 
     # kill too long running ES jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=24)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=24)
     var_map = {}
     var_map[":jobStatus1"] = "running"
     var_map[":jobStatus2"] = "starting"
@@ -978,16 +973,16 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jobs):
             _logger.debug(f"killJobs for long running ES jobs ({str(jobs[iJob:iJob + nJob])})")
-            Client.killJobs(
+            Client.kill_jobs(
                 jobs[iJob : iJob + nJob],
                 2,
-                keepUnmerged=True,
-                jobSubStatus="es_toolong",
+                keep_unmerged=True,
+                job_sub_status="es_toolong",
             )
             iJob += nJob
 
     # kill too long running ES merge jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=24)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=24)
     var_map = {}
     var_map[":jobStatus1"] = "running"
     var_map[":jobStatus2"] = "starting"
@@ -1006,7 +1001,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         iJob = 0
         while iJob < len(jobs):
             _logger.debug(f"killJobs for long running ES merge jobs ({str(jobs[iJob:iJob + nJob])})")
-            Client.killJobs(jobs[iJob : iJob + nJob], 2)
+            Client.kill_jobs(jobs[iJob : iJob + nJob], 2)
             iJob += nJob
 
     # rebrokerage
@@ -1018,8 +1013,8 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         timeoutVal = 12
     _logger.debug(f"timeout value : {timeoutVal}h")
     try:
-        normalTimeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=timeoutVal)
-        sortTimeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=3)
+        normalTimeLimit = naive_utcnow() - datetime.timedelta(hours=timeoutVal)
+        sortTimeLimit = naive_utcnow() - datetime.timedelta(hours=3)
         sql = (
             "WITH p AS ("
             "SELECT MIN(PandaID) PandaID,jobDefinitionID,prodUserName,prodUserID,computingSite,jediTaskID,processingType,workingGroup "
@@ -1105,7 +1100,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         sqlJJ += "AND jobDefinitionID=:jobDefID AND computingSite=:computingSite "
         timeoutMap = {}
         if resList != []:
-            recentRuntimeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=3)
+            recentRuntimeLimit = naive_utcnow() - datetime.timedelta(hours=3)
             # loop over all user/jobID combinations
             iComb = 0
             nComb = len(resList)
@@ -1144,9 +1139,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                         if workingGroup not in timeoutMap:
                             tmp_timeoutVal = taskBuffer.getConfigValue("rebroker", f"ANALY_TIMEOUT_{workingGroup}")
                             if tmp_timeoutVal:
-                                timeoutMap[workingGroup] = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(
-                                    hours=tmp_timeoutVal
-                                )
+                                timeoutMap[workingGroup] = naive_utcnow() - datetime.timedelta(hours=tmp_timeoutVal)
                             else:
                                 timeoutMap[workingGroup] = normalTimeLimit
                         tmp_normalTimeLimit = timeoutMap[workingGroup]
@@ -1205,7 +1198,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         _logger.error(f"rebrokerage failed with {str(e)} : {traceback.format_exc()}")
 
     # kill too long running jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=21)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=21)
     status, res = taskBuffer.querySQLS(
         "SELECT PandaID FROM ATLAS_PANDA.jobsActive4 WHERE creationTime<:creationTime",
         {":creationTime": timeLimit},
@@ -1221,7 +1214,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         while iJob < len(jobs):
             # set tobekill
             _logger.debug(f"killJobs for Running ({jobs[iJob:iJob + nJob]})")
-            Client.killJobs(jobs[iJob : iJob + nJob], 2)
+            Client.kill_jobs(jobs[iJob : iJob + nJob], 2)
             # run watcher
             for id in jobs[iJob : iJob + nJob]:
                 thr = Watcher(
@@ -1238,7 +1231,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             time.sleep(10)
 
     # kill too long throttled jobs
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=7)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=7)
     var_map = {}
     var_map[":jobStatus"] = "throttled"
     var_map[":creationTime"] = timeLimit
@@ -1252,14 +1245,14 @@ def main(argv=tuple(), tbuf=None, **kwargs):
             jobs.append(id)
     # kill
     if len(jobs):
-        Client.killJobs(jobs, 2)
+        Client.kill_jobs(jobs, 2)
         _logger.debug(f"killJobs for throttled ({str(jobs)})")
 
     # check if merge job is valid
     _logger.debug("kill invalid pmerge")
     var_map = {}
     var_map[":processingType"] = "pmerge"
-    var_map[":timeLimit"] = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=30)
+    var_map[":timeLimit"] = naive_utcnow() - datetime.timedelta(minutes=30)
     sql = "SELECT PandaID,jediTaskID FROM ATLAS_PANDA.jobsDefined4 WHERE processingType=:processingType AND modificationTime<:timeLimit "
     sql += "UNION "
     sql += "SELECT PandaID,jediTaskID FROM ATLAS_PANDA.jobsActive4 WHERE processingType=:processingType AND modificationTime<:timeLimit "
@@ -1289,7 +1282,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
     _memoryCheck("delete XML")
 
     # delete old files in DA cache
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=7)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=7)
     files = os.listdir(panda_config.cache_dir)
     for file in files:
         # skip special test file
@@ -1321,7 +1314,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
 
     # sandbox
     _logger.debug("Touch sandbox")
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=1)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=1)
     sqlC = (
         "SELECT hostName,fileName,creationTime,userName FROM ATLAS_PANDAMETA.userCacheUsage "
         "WHERE creationTime>:timeLimit AND creationTime>modificationTime "
@@ -1336,7 +1329,7 @@ def main(argv=tuple(), tbuf=None, **kwargs):
         for hostName, fileName, creationTime, userName in res:
             base_url = f"https://{hostName}:{panda_config.pserverport}"
             _logger.debug(f"touch {fileName} on {hostName} created at {creationTime}")
-            s, o = Client.touchFile(base_url, fileName)
+            s, o = Client.touch_file(base_url, fileName)
             _logger.debug(o)
             if o == "True":
                 var_map = dict()
@@ -1345,8 +1338,8 @@ def main(argv=tuple(), tbuf=None, **kwargs):
                 taskBuffer.querySQLS(sqlU, var_map)
 
     _logger.debug("Check sandbox")
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=1)
-    expireLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=30)
+    timeLimit = naive_utcnow() - datetime.timedelta(days=1)
+    expireLimit = naive_utcnow() - datetime.timedelta(days=30)
     sqlD = "DELETE FROM ATLAS_PANDAMETA.userCacheUsage WHERE userName=:userName AND fileName=:fileName "
     nRange = 100
     for i in range(nRange):
