@@ -7,6 +7,7 @@ import time
 import traceback
 
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from pandacommon.pandautils.thread_utils import GenericThread
 
 import pandaserver.taskbuffer.ErrorCode
@@ -251,8 +252,8 @@ def main(tbuf=None, **kwargs):
 
     # close datasets
     _logger.debug("==== close datasets ====")
-    timeLimitU = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=1)
-    timeLimitL = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=3)
+    timeLimitU = naive_utcnow() - datetime.timedelta(minutes=1)
+    timeLimitL = naive_utcnow() - datetime.timedelta(days=3)
     closeLock = threading.Semaphore(5)
     closeProxyLock = threading.Lock()
     closeThreadPool = ThreadPool()
@@ -457,10 +458,10 @@ def main(tbuf=None, **kwargs):
 
     # freeze dataset
     _logger.debug("==== freeze datasets ====")
-    timeLimitRU = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=3)
-    timeLimitRL = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=12)
-    timeLimitU = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=6)
-    timeLimitL = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=14)
+    timeLimitRU = naive_utcnow() - datetime.timedelta(hours=3)
+    timeLimitRL = naive_utcnow() - datetime.timedelta(hours=12)
+    timeLimitU = naive_utcnow() - datetime.timedelta(hours=6)
+    timeLimitL = naive_utcnow() - datetime.timedelta(days=14)
     # reset doing so that Closer can update unmerged datasets
     sql = "SELECT name FROM ATLAS_PANDA.Datasets "
     sql += "WHERE type=:type AND (modificationdate BETWEEN :modificationdateRL AND :modificationdateRU) AND subType=:subType AND status=:oldStatus "
@@ -580,8 +581,8 @@ def main(tbuf=None, **kwargs):
 
     # delete dis datasets
     _logger.debug("==== delete dis datasets ====")
-    timeLimitU = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=30)
-    timeLimitL = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=3)
+    timeLimitU = naive_utcnow() - datetime.timedelta(minutes=30)
+    timeLimitL = naive_utcnow() - datetime.timedelta(days=3)
     disEraseLock = threading.Semaphore(5)
     disEraseProxyLock = threading.Lock()
     disEraseThreadPool = ThreadPool()
@@ -767,7 +768,7 @@ def main(tbuf=None, **kwargs):
     finisherProxyLock = threading.Lock()
     finisherThreadPool = ThreadPool()
     for loopIdx in ["low", "high"]:
-        timeNow = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        timeNow = naive_utcnow()
         if loopIdx == "high":
             highPrioFlag = True
         else:
@@ -875,7 +876,7 @@ def main(tbuf=None, **kwargs):
     activatorLock = threading.Semaphore(3)
     activatorProxyLock = threading.Lock()
     activatorThreadPool = ThreadPool()
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=1)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=1)
     # get jobs
     for ii in range(1000):
         # lock
@@ -973,7 +974,7 @@ def main(tbuf=None, **kwargs):
     activatorLock = threading.Semaphore(3)
     activatorProxyLock = threading.Lock()
     activatorThreadPool = ThreadPool()
-    timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=1)
+    timeLimit = naive_utcnow() - datetime.timedelta(hours=1)
     # get jobs
     for ii in range(1000):
         # lock
@@ -1013,7 +1014,7 @@ def main(tbuf=None, **kwargs):
                         _logger.debug(f"skip non sub {name}")
                         continue
                     _logger.debug(f"delete sub {name}")
-                    if name.startswith("user.") or name.startswith("group.") or name.startswith("hc_test.") or name.startswith("panda.um."):
+                    if name.startswith("user.") or name.startswith("group.") or name.startswith("hc_test."):
                         dsExists = False
                     else:
                         dsExists = True
@@ -1085,8 +1086,8 @@ def main(tbuf=None, **kwargs):
 
     # delete sub datasets
     _logger.debug("==== delete sub datasets ====")
-    timeLimitU = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=30)
-    timeLimitL = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(days=14)
+    timeLimitU = naive_utcnow() - datetime.timedelta(minutes=30)
+    timeLimitL = naive_utcnow() - datetime.timedelta(days=14)
     subdeleteLock = threading.Semaphore(5)
     subdeleteProxyLock = threading.Lock()
     subdeleteThreadPool = ThreadPool()
