@@ -12,6 +12,7 @@ import time
 import traceback
 from typing import Dict, List
 
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from rucio.common.exception import (
     DataIdentifierNotFound,
     FileConsistencyMismatch,
@@ -70,6 +71,7 @@ class AdderAtlasPlugin(AdderPluginBase):
             if self.job.jobStatus == "transferring":
                 self.add_to_top_only = True
                 self.logger.debug("adder for transferring")
+            self.check_output_file_metadata()
             # check if the job goes to merging
             if self.job.produceUnMerge():
                 self.go_to_merging = True
@@ -173,6 +175,45 @@ class AdderAtlasPlugin(AdderPluginBase):
         # return
         return
 
+    # check output file metadata
+    def check_output_file_metadata(self):
+        """
+        Check the metadata of output files for consistency and change the job status if inconsistencies are found.
+        """
+        # check only successful jobs
+        if self.job_status in ["failed", "cancelled", "closed"]:
+            return
+        # get the zip file map
+        zip_file_map = self.job.getZipFileMap()
+        # check only output files
+        for file in self.job.Files:
+            is_zip_file = file.lfn in zip_file_map
+            # check num events and GUID
+            if file.type == "output" and not is_zip_file and not self.add_to_top_only and self.job.prodSourceLabel == "managed":
+                if file.lfn not in self.extra_info["nevents"]:
+                    to_skip = False
+                    # exclude some formats
+                    for patt in ["TXT", "NTUP", "HIST"]:
+                        if file.lfn.startswith(patt):
+                            to_skip = True
+                    if not to_skip:
+                        err_msg = f"nEvents is missing in jobReport for {file.lfn}"
+                        self.logger.error(err_msg)
+                        self.job.ddmErrorCode = ErrorCode.EC_MissingNumEvents
+                        self.job.ddmErrorDiag = err_msg
+                        self.job.jobStatus = "failed"
+                        self.job_status = "failed"
+                        return
+                if file.lfn not in self.extra_info["guid"] or file.GUID != self.extra_info["guid"][file.lfn]:
+                    self.logger.debug(f"extra_info = {str(self.extra_info)}")
+                    err_msg = f"GUID is inconsistent between jobReport and pilot report for {file.lfn}"
+                    self.logger.error(err_msg)
+                    self.job.ddmErrorCode = ErrorCode.EC_InconsistentGUID
+                    self.job.ddmErrorDiag = err_msg
+                    self.job.jobStatus = "failed"
+                    self.job_status = "failed"
+                    return
+
     # update output files
     def update_outputs(self):
         """
@@ -670,7 +711,7 @@ class AdderAtlasPlugin(AdderPluginBase):
         for attempt_number in range(max_attempt):
             is_fatal = False
             is_failed = False
-            reg_start = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            reg_start = naive_utcnow()
             try:
                 if self.add_to_top_only:
                     reg_msg_str = f"File registration for {reg_num_files} files "
@@ -710,7 +751,7 @@ class AdderAtlasPlugin(AdderPluginBase):
                     or "unique constraint (ATLAS_RUCIO.ARCH_CONTENTS_PK) violated" in out
                 )
                 is_failed = True
-            reg_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - reg_start
+            reg_time = naive_utcnow() - reg_start
             self.logger.debug(f"{reg_msg_str} took {reg_time.seconds}.{reg_time.microseconds // 1000:03d} sec")
             # failed
             if is_failed or is_fatal:
