@@ -46,7 +46,10 @@ class EventPicker:
         self.event_picking_file_name = evpFileName
         # logger
         self.logger = LogWrapper(_logger)
-        self.pd2p = dyn_data_distributer.DynDataDistributer([], self.site_mapper, token=" ")
+        dataset_lifetime = self.task_buffer.getConfigValue("event_picker", "EVP_DATASET_LIFETIME")
+        if not dataset_lifetime:
+            dataset_lifetime = 28
+        self.pd2p = dyn_data_distributer.DynDataDistributer([], self.site_mapper, token=" ", dataset_lifetime=dataset_lifetime)
         self.user_dataset_name = ""
         self.creation_time = ""
         self.params = ""
