@@ -17,10 +17,12 @@ import uuid
 from typing import Dict, List, Optional, Tuple
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from rucio.common.exception import DataIdentifierNotFound
 
 import pandaserver.brokerage.broker
 from pandaserver.brokerage.SiteMapper import SiteMapper
+from pandaserver.config import panda_config
 from pandaserver.dataservice import DataServiceUtils, ErrorCode
 from pandaserver.dataservice.DataServiceUtils import select_scope
 from pandaserver.dataservice.ddm import rucioAPI
@@ -57,10 +59,6 @@ class SetupperAtlasPlugin(SetupperPluginBase):
         self.disp_file_list = {}
         # site mapper
         self.site_mapper = None
-        # location map
-        self.replica_map = {}
-        # all replica locations
-        self.all_replica_map = {}
         # available files at satellite sites
         self.available_lfns_in_satellites = {}
         # list of missing datasets
@@ -82,7 +80,7 @@ class SetupperAtlasPlugin(SetupperPluginBase):
             self.memory_check()
             bunch_tag = ""
             tag_job = None
-            time_start = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            time_start = naive_utcnow()
             if self.jobs is not None and len(self.jobs) > 0:
                 tag_job = self.jobs[0]
             elif len(self.jumbo_jobs) > 0:
@@ -181,13 +179,17 @@ class SetupperAtlasPlugin(SetupperPluginBase):
             # setup jumbo jobs
             self.setup_jumbo_jobs()
             self.memory_check()
-            reg_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - time_start
+            reg_time = naive_utcnow() - time_start
             tmp_logger.debug(f"{bunch_tag} took {reg_time.seconds}sec")
             tmp_logger.debug("end")
-        except Exception:
-            error_type, error_value = sys.exc_info()[:2]
-            err_str = f"run() : {error_type} {error_value}"
+        except Exception as e:
+            err_str = f"setupper.run failed with {str(e)}"
             err_str.strip()
+            for job in self.jobs:
+                if job.jobStatus not in ["failed", "cancelled"]:
+                    job.jobStatus = "failed"
+                    job.ddmErrorCode = ErrorCode.EC_Setupper
+                    job.ddmErrorDiag = err_str
             err_str += traceback.format_exc()
             tmp_logger.error(err_str)
 
@@ -320,23 +322,6 @@ class SetupperAtlasPlugin(SetupperPluginBase):
                             else:
                                 file_list[job.dispatchDBlock]["md5sums"].append(f"md5:{file.md5sum}")
 
-                        # get replica locations
-                        self.replica_map.setdefault(job.dispatchDBlock, {})
-                        if file.dataset not in self.all_replica_map:
-                            if file.dataset.endswith("/"):
-                                status, out = self.get_list_dataset_replicas_in_container(file.dataset, True)
-                            else:
-                                status, out = self.get_list_dataset_replicas(file.dataset)
-                            if not status:
-                                tmp_logger.error(out)
-                                disp_error[job.dispatchDBlock] = f"could not get locations for {file.dataset}"
-                                tmp_logger.error(disp_error[job.dispatchDBlock])
-                            else:
-                                tmp_logger.debug(out)
-                                self.all_replica_map[file.dataset] = out
-                        if file.dataset in self.all_replica_map:
-                            self.replica_map[job.dispatchDBlock][file.dataset] = self.all_replica_map[file.dataset]
-
         # register dispatch dataset
         disp_list = self.register_dispatch_datasets(file_list, use_zip_to_pin_map, ds_task_map, tmp_logger, disp_error, jedi_task_id)
         # insert datasets to DB
@@ -443,7 +428,8 @@ class SetupperAtlasPlugin(SetupperPluginBase):
                     self.logger.debug(f"sleep {attempt}/{max_attempt}")
                     time.sleep(10)
             if not is_ok:
-                disp_error[dispatch_data_block] = "setupper.setup_source() could not register dispatch_data_block with {0}".format(err_str.split("\n")[-1])
+                tmp_str = err_str.split("\n")[-1]
+                disp_error[dispatch_data_block] = f"setupper.setup_source() could not register dispatch_data_block with {tmp_str}"
                 continue
             tmp_logger.debug(out)
             new_out = out
@@ -528,8 +514,11 @@ class SetupperAtlasPlugin(SetupperPluginBase):
                 if dest not in dest_error:
                     dest_error[dest] = ""
                     original_name = ""
-                    if (job.prodSourceLabel == "panda") or (
-                        job.prodSourceLabel in JobUtils.list_ptest_prod_sources and job.processingType in ["pathena", "prun", "gangarobot-rctest"]
+                    if (
+                        (job.prodSourceLabel == "panda")
+                        or panda_config.disable_file_aggregation
+                        or (job.prodSourceLabel in JobUtils.list_ptest_prod_sources and job.processingType in ["pathena", "prun"])
+                        or job.processingType.startswith("gangarobot")
                     ):
                         # keep original name
                         name_list = [file.destinationDBlock]
@@ -833,28 +822,9 @@ class SetupperAtlasPlugin(SetupperPluginBase):
 
                 site_spec = self.site_mapper.getSite(job.computingSite)
 
-                # source
-                _, scope_src_output = select_scope(site_spec, job.prodSourceLabel, job.job_label)
-                src_ddm_id = site_spec.ddm_output[scope_src_output]
-
-                # destination
+                # use input RSE with read_lan/0 as destination
                 scope_dst_input, _ = select_scope(site_spec, job.prodSourceLabel, job.job_label)
-                if site_spec.ddm_endpoints_input[scope_dst_input].isAssociated(src_ddm_id):
-                    dst_ddm_id = src_ddm_id
-                else:
-                    dst_ddm_id = site_spec.ddm_input[scope_dst_input]
-
-                # Get the ATLASDATADISK DDM endpoint in site, it will have preference for pre-staging
-                try:
-                    dst_datadisk_id = site_spec.setokens_input[scope_dst_input]["ATLASDATADISK"]
-                except KeyError:
-                    dst_datadisk_id = None
-
-                if dst_datadisk_id and dst_ddm_id != dst_datadisk_id:
-                    ddm_id = dst_datadisk_id
-                else:
-                    ddm_id = dst_ddm_id
-                tmp_logger.debug(f"use {ddm_id} for pre-staging")
+                ddm_id = site_spec.ddm_input[scope_dst_input]
 
                 # set share and activity
                 option_activity = "Production Input"
@@ -949,7 +919,6 @@ class SetupperAtlasPlugin(SetupperPluginBase):
         all_guids = {}
         all_scopes = {}
         lfn_ds_map = {}
-        replica_map = {}
         tmp_logger.debug("start")
 
         # collect input LFNs
@@ -1032,19 +1001,6 @@ class SetupperAtlasPlugin(SetupperPluginBase):
                             tmp_logger.error(prod_error[dataset])
                             tmp_logger.error(out)
 
-                    # get replica locations
-                    if (job.prodSourceLabel in ["managed", "test"]) and prod_error[dataset] == "" and dataset not in replica_map:
-                        if dataset.endswith("/"):
-                            status, out = self.get_list_dataset_replicas_in_container(dataset, True)
-                        else:
-                            status, out = self.get_list_dataset_replicas(dataset)
-                        if not status:
-                            prod_error[dataset] = f"could not get locations for {dataset}"
-                            tmp_logger.error(prod_error[dataset])
-                            tmp_logger.error(out)
-                        else:
-                            replica_map[dataset] = out
-
             # mark job with a missing dataset as failed and update files as missing
             is_failed = False
             for dataset in datasets:
