@@ -19,12 +19,15 @@ from urllib.parse import parse_qsl
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from pandacommon.pandautils.thread_utils import GenericThread
 from werkzeug.datastructures import CombinedMultiDict, EnvironHeaders
 from werkzeug.formparser import parse_form_data
 
 import pandaserver.taskbuffer.ErrorCode
 from pandaserver.api.v1 import credential_management_api as cred_api_v1
+from pandaserver.api.v1 import data_carousel_api as data_carousel_api_v1
+from pandaserver.api.v1 import event_api as event_api_v1
 from pandaserver.api.v1 import file_server_api as file_server_api_v1
 from pandaserver.api.v1 import harvester_api as harvester_api_v1
 from pandaserver.api.v1 import idds_api as idds_api_v1
@@ -156,6 +159,8 @@ LATEST = "1"
 # generate the allowed methods dynamically with all function names present in the API modules,
 # excluding functions imported from other modules or the init_task_buffer function
 cred_api_v1_methods = extract_allowed_methods(cred_api_v1)
+data_carousel_api_v1_methods = extract_allowed_methods(data_carousel_api_v1)
+event_api_v1_methods = extract_allowed_methods(event_api_v1)
 file_server_api_v1_methods = extract_allowed_methods(file_server_api_v1)
 harvester_api_v1_methods = extract_allowed_methods(harvester_api_v1)
 idds_api_v1_methods = extract_allowed_methods(idds_api_v1)
@@ -182,6 +187,8 @@ taskBuffer.init(
 if panda_config.nDBConnection != 0:
     # initialize all the API modules
     cred_api_v1.init_task_buffer(taskBuffer)
+    data_carousel_api_v1.init_task_buffer(taskBuffer)
+    event_api_v1.init_task_buffer(taskBuffer)
     file_server_api_v1.init_task_buffer(taskBuffer)
     harvester_api_v1.init_task_buffer(taskBuffer)
     # IDDS API does not need to be initialized. idds_server_api_v1.init_task_buffer(taskBuffer)
@@ -204,7 +211,7 @@ if panda_config.nDBConnection != 0:
     ban_user_list = CoreUtils.CachedObject("ban_list", 600, taskBuffer.get_ban_users, _logger)
 else:
     # get ban list from remote
-    ban_user_list = CoreUtils.CachedObject("ban_list", 600, Client.get_ban_users, _logger)
+    ban_user_list = CoreUtils.CachedObject("ban_list", 600, Client.get_banned_users, _logger)
 
 
 def pre_validate_request(panda_request):
@@ -349,6 +356,8 @@ def module_mapping(version, api_module):
         "v0": {"panda": {"module": None, "allowed_methods": allowed_methods}},  # legacy API uses globals instead of a particular module
         "v1": {
             "creds": {"module": cred_api_v1, "allowed_methods": cred_api_v1_methods},
+            "data_carousel": {"module": data_carousel_api_v1, "allowed_methods": data_carousel_api_v1_methods},
+            "event": {"module": event_api_v1, "allowed_methods": event_api_v1_methods},
             "file_server": {"module": file_server_api_v1, "allowed_methods": file_server_api_v1_methods},
             "harvester": {"module": harvester_api_v1, "allowed_methods": harvester_api_v1_methods},
             "idds": {"module": idds_api_v1, "allowed_methods": idds_api_v1_methods},
@@ -376,6 +385,13 @@ def validate_method(method_name, api_module, version):
     return False
 
 
+# Encoder: convert datetime → ISO string with a marker
+def encode_special_cases(obj):
+    if isinstance(obj, datetime.datetime):
+        return {"__datetime__": obj.isoformat()}
+    raise TypeError(f"Type not serializable for {obj} ({type(obj)})")
+
+
 # This is the starting point for all WSGI requests
 def application(environ, start_response):
     # Parse the script name to retrieve method, module and version
@@ -385,21 +401,24 @@ def application(environ, start_response):
     cont_length = int(environ.get("CONTENT_LENGTH", 0))
     request_method = environ.get("REQUEST_METHOD", None)  # GET, POST, PUT, DELETE
 
-    # json app means the content type is application/json,
-    # while json body requires additionally to be a PUT or POST request, where the body is json encoded
-    json_app = environ.get("CONTENT_TYPE", None) == "application/json"
-    json_body = environ.get("CONTENT_TYPE", None) == "application/json" and request_method in ["PUT", "POST"]
-
     # see if we are on the new or old APIs
     new_api = is_new_api(api_module)
 
+    # json app means the content type is application/json,
+    # while json body requires additionally to be a PUT or POST request, where the body is json encoded
+    if new_api:
+        json_app = environ.get("CONTENT_TYPE", None) == "application/json" or environ.get("HTTP_ACCEPT", None) == "application/json"
+    else:
+        json_app = environ.get("CONTENT_TYPE", None) == "application/json"
+    json_body = environ.get("CONTENT_TYPE", None) == "application/json" and request_method in ["PUT", "POST"]
+
     # Content encoding specifies whether the body is compressed through gzip or others.
     # No encoding usually means the body is not compressed
     content_encoding = environ.get("HTTP_CONTENT_ENCODING")
 
     tmp_log.debug(f"""start content-length={cont_length} json={json_app} origin={environ.get("HTTP_ORIGIN", None)}""")
 
-    start_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+    start_time = naive_utcnow()
     return_type = None
 
     # check method name is allowed, otherwise return 403
@@ -457,7 +476,7 @@ def application(environ, start_response):
 
         # convert the response to json when specified through CONTENT_TYPE="application/json"
         if json_app and new_api:
-            exec_result = json.dumps(exec_result)
+            exec_result = json.dumps(exec_result, default=encode_special_cases)
 
     except Exception as exc:
         tmp_log.error(f"execution failure : {str(exc)}\n {traceback.format_exc()}")
@@ -486,7 +505,7 @@ def application(environ, start_response):
         tmp_log.debug("done")
 
     # log execution time and return length
-    duration = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - start_time
+    duration = naive_utcnow() - start_time
     tmp_log.info("exec_time=%s.%03d sec, return len=%s B" % (duration.seconds, duration.microseconds / 1000, len(str(exec_result))))
 
     # start the response and return result
