@@ -7,6 +7,8 @@ import re
 import subprocess
 from threading import Lock
 
+from pandacommon.pandautils.PandaUtils import naive_utcnow
+
 
 # replacement for commands
 def commands_get_status_output(com):
@@ -113,6 +115,32 @@ def get_distinguished_name_list(distinguished_name: str) -> list:
     return name_list
 
 
+def normalize_cpu_model(cpu_model):
+    cpu_model = cpu_model.upper()
+    # Remove GHz, cache sizes, and redundant words
+    cpu_model = re.sub(r"@\s*\d+(\.\d+)?\s*GHZ", "", cpu_model)
+    cpu_model = re.sub(r"\d+\s*KB", "", cpu_model)
+    cpu_model = re.sub(r"CORE PROCESSOR\s*\([^)]*\)", "", cpu_model)
+    cpu_model = re.sub(r"\b\d+-CORE\b", "", cpu_model)
+    cpu_model = re.sub(r"CPU|CORE|PROCESSOR|SCALABLE|\(R\)|\(TM\)", "", cpu_model)
+    cpu_model = re.sub(r"\s+", " ", cpu_model)
+    cpu_model = cpu_model.strip()
+    return cpu_model
+
+
+def clean_host_name(host_name):
+    # If the worker node comes in the slot1@worker1.example.com format, we remove the slot1@ part
+    match = re.search(r"@(.+)", host_name)
+    host_name = match.group(1) if match else host_name
+
+    # Special handling for ATLAS worker nodes to extract the third field of the hostname, since the first 2 fields are not unique
+    # e.g. atlprd55-xyz-<third_field>.cern.ch
+    match = re.match(r"^atlprd\d+-[^-]+-([^.]+\.cern\.ch)$", host_name)
+    host_name = match.group(1) if match else host_name
+
+    return host_name
+
+
 # resolve string bool
 def resolve_bool(param):
     if isinstance(param, bool):
@@ -133,7 +161,7 @@ class CachedObject:
         # cached object
         self.cachedObj = None
         # datetime of last updated
-        self.lastUpdated = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        self.lastUpdated = naive_utcnow()
         # update frequency
         self.timeInterval = datetime.timedelta(seconds=time_interval)
         # lock
@@ -148,7 +176,7 @@ class CachedObject:
         # lock
         self.lock.acquire()
         # get current datetime
-        current = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        current = naive_utcnow()
         # update if old
         if self.cachedObj is None or current - self.lastUpdated > self.timeInterval:
             self.log_stream.debug(f"PID={os.getpid()} renewing {self.name} cache")
@@ -207,7 +235,7 @@ class CacheDict:
         self.cache_dict = {}
         self.update_interval = datetime.timedelta(minutes=update_interval)
         self.cleanup_interval = datetime.timedelta(minutes=cleanup_interval)
-        self.last_cleanup = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        self.last_cleanup = naive_utcnow()
 
     def cleanup(self, tmp_log):
         """
@@ -215,7 +243,7 @@ class CacheDict:
         :param tmp_log: logger
         """
         with self.lock:
-            current = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            current = naive_utcnow()
             if current - self.last_cleanup > self.cleanup_interval:
                 for name in list(self.cache_dict):
                     cache = self.cache_dict[name]
@@ -237,7 +265,7 @@ class CacheDict:
         self.cleanup(tmp_log)
         with self.lock:
             obj = self.cache_dict.get(name)
-            current = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            current = naive_utcnow()
             if not obj:
                 tmp_log.debug(f"creating new cache #{self.idx}")
                 # create new cache
