@@ -1,4 +1,5 @@
 import enum
+import json
 import math
 import re
 
@@ -104,7 +105,7 @@ class JediTaskSpec(object):
     # mapping between sequence and attr
     _seqAttrMap = {}
     # limit length
-    _limitLength = {"errorDialog": 255}
+    _limitLength = {"errorDialog": 510}
     # attribute length
     _attrLength = {"workingGroup": 32}
 
@@ -746,6 +747,39 @@ class JediTaskSpec(object):
 
     commandStatusMap = classmethod(commandStatusMap)
 
+    # qualifiers for retry command
+    def get_retry_command_qualifiers(
+        cls,
+        no_child_retry: bool = False,
+        discard_events: bool = False,
+        disable_staging_mode: bool = False,
+        keep_gshare_priority: bool = False,
+        ignore_hard_exhausted: bool = False,
+    ) -> list:
+        """
+        Get the list of qualifiers for the retry command.
+        :param no_child_retry: If True, retry will not be attempted on child tasks.
+        :param discard_events: If True, events will be discarded.
+        :param disable_staging_mode: If True, staging mode will be disabled.
+        :param keep_gshare_priority: If True, current gshare and priority will be kept.
+        :param ignore_hard_exhausted: If True, the limits for hard exhausted will be ignored.
+        :return: A list of qualifiers.
+        """
+        qualifiers = []
+        if no_child_retry:
+            qualifiers.append("sole")
+        if discard_events:
+            qualifiers.append("discard")
+        if disable_staging_mode:
+            qualifiers.append("staged")
+        if keep_gshare_priority:
+            qualifiers.append("keep")
+        if ignore_hard_exhausted:
+            qualifiers.append("transcend")
+        return qualifiers
+
+    get_retry_command_qualifiers = classmethod(get_retry_command_qualifiers)
+
     # set error dialog
     def setErrDiag(self, diag, append=False, prepend=False):
         # check if message can be encoded with UTF-8
@@ -1213,12 +1247,58 @@ class JediTaskSpec(object):
     def useZipToPin(self):
         return self.check_split_rule("useZipToPin")
 
-    # architecture: sw_platform<@base_platform><#host_cpu_spec><&host_gpu_spec>
-    # host_cpu_spec: architecture<-vendor<-instruction_set>>
-    # host_gpu_spec: vendor<-model>
+    # architecture:
+    # old format: sw_platform<@base_platform><#host_cpu_spec><&host_gpu_spec>
+    #             host_cpu_spec: architecture<-vendor<-instruction_set>>
+    #             host_gpu_spec: vendor<-model>
+    #
+    # new format: a json dict with keys of sw_platform, base_platform, cpu_specs, and gpu_spec
+    #             cpu_specs: a list of json dicts with keys of arch, vendor, and instr
+    #             gpu_spec: a json dict with keys of vendor and model
+
+    # reformat architecture into JSON
+    def reformat_architecture(self):
+        if self.architecture is None:
+            return
+        encoded_platform = ""
+        try:
+            # JSON format without encoded platform
+            tmp_dict = json.loads(self.architecture)
+            # skip if encoded platform is not present
+            if "encoded_platform" not in tmp_dict:
+                return
+            encoded_platform = tmp_dict["encoded_platform"]
+        except Exception:
+            pass
+        # convert to new format
+        new_dict = {}
+        val = self.get_sw_platform()
+        if val:
+            new_dict["sw_platform"] = val
+        val = self.get_base_platform(encoded_platform)
+        if val:
+            new_dict["base_platform"] = val
+        val = self.get_host_cpu_spec(encoded_platform)
+        if val:
+            # remove wildcard entries and empty specs
+            l = [x for x in [{k: v for k, v in d.items() if v != "*"} for d in val] if x]
+            if l:
+                new_dict["cpu_specs"] = l
+        val = self.get_host_gpu_spec()
+        if val:
+            # remove wildcard entries and empty specs
+            l = {k: v for k, v in val.items() if v != "*"}
+            if l:
+                new_dict["gpu_spec"] = l
+        self.architecture = json.dumps(new_dict)
 
     # get SW platform
     def get_sw_platform(self):
+        try:
+            d = json.loads(self.architecture)
+            return d.get("sw_platform", "")
+        except Exception:
+            pass
         if self.architecture is not None:
             m = re.search("^([^@#&]*)", self.architecture)
             if m:
@@ -1226,10 +1306,21 @@ class JediTaskSpec(object):
         return self.architecture
 
     # get base platform
-    def get_base_platform(self):
-        if self.architecture is None or "@" not in self.architecture:
+    def get_base_platform(self, encoded_platform=None):
+        try:
+            d = json.loads(self.architecture)
+            val = d.get("base_platform", None)
+            if val is not None or encoded_platform is None:
+                return val
+        except Exception:
+            pass
+        if encoded_platform:
+            architecture = encoded_platform
+        else:
+            architecture = self.architecture
+        if architecture is None or "@" not in architecture:
             return None
-        m = re.search("@([^#&]*)", self.architecture)
+        m = re.search("@([^#&]*)", architecture)
         img = m.group(1)
         if img == "":
             img = None
@@ -1246,18 +1337,34 @@ class JediTaskSpec(object):
         return self.architecture
 
     # get host CPU spec
-    def get_host_cpu_spec(self):
+    def get_host_cpu_spec(self, encoded_platform=None):
         try:
-            if not self.architecture:
+            d = json.loads(self.architecture)
+            specs = d.get("cpu_specs", None)
+            if not specs and encoded_platform is None:
                 return None
-            if "#" not in self.architecture:
-                if re.search(r"^[\^@&]", self.architecture):
+            else:
+                for spec in specs:
+                    spec.setdefault("vendor", "*")
+                    spec.setdefault("instr", "*")
+                return specs
+        except Exception:
+            pass
+        if encoded_platform:
+            architecture = encoded_platform
+        else:
+            architecture = self.architecture
+        try:
+            if not architecture:
+                return None
+            if "#" not in architecture:
+                if re.search(r"^[\^@&]", architecture):
                     return None
-                arch = self.architecture.split("-")[0]
+                arch = architecture.split("-")[0]
                 if arch:
                     return [{"arch": arch, "vendor": "*", "instr": "*"}]
                 return None
-            m = re.search(r"#([^\^@&]*)", self.architecture)
+            m = re.search(r"#([^\^@&]*)", architecture)
             spec_strs = m.group(1)
             if not spec_strs:
                 return None
@@ -1280,6 +1387,14 @@ class JediTaskSpec(object):
 
     # get host GPU spec
     def get_host_gpu_spec(self):
+        try:
+            d = json.loads(self.architecture)
+            spec = d.get("gpu_spec", None)
+            spec.setdefault("vendor", "*")
+            spec.setdefault("model", "*")
+            return spec
+        except Exception:
+            pass
         try:
             if self.architecture is None or "&" not in self.architecture:
                 return None
