@@ -7,6 +7,8 @@ import datetime
 import json
 import re
 
+from pandacommon.pandautils.PandaUtils import naive_utcnow
+
 from pandaserver.taskbuffer.FileSpec import FileSpec
 
 reserveChangedState = False
@@ -184,6 +186,9 @@ class JobSpec(object):
         "commandToPilot": 250,
         "inputFileType": 32,
         "outputFileType": 32,
+        "grid": 50,
+        "sourceSite": 36,
+        "destinationSite": 36,
     }
     # tag for special handling
     _tagForSH = {
@@ -247,7 +252,7 @@ class JobSpec(object):
         newVal = getattr(self, name)
         if name == "jobStatus":
             if oldVal != newVal:
-                self.stateChangeTime = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+                self.stateChangeTime = naive_utcnow()
         # collect changed attributes
         if oldVal != newVal and name not in self._suppAttrs:
             self._changedAttrs[name] = value
@@ -884,6 +889,23 @@ class JobSpec(object):
             file_spec.__setstate__(file_stat)
             self.addFile(file_spec)
 
+    def load_from_dict(self, job_dict):
+        # Extract job attributes (excluding files)
+        job_attrs = []
+        for slot in self.__slots__:
+            if slot == "Files":  # skip files here
+                continue
+            job_attrs.append(job_dict.get(slot, None))
+
+        # Initialize with empty file list
+        self.__setstate__(job_attrs + [[]])
+
+        # Add files
+        for file_data in job_dict.get("Files", []):
+            file_spec = FileSpec()
+            file_spec.__setstate__([file_data.get(s, None) for s in file_spec.__slots__])
+            self.addFile(file_spec)
+
     # set input and output file types
     def set_input_output_file_types(self) -> None:
         """
@@ -919,7 +941,7 @@ class JobSpec(object):
             self.outputFileType = ",".join(out_types)[: self._limitLength["outputFileType"]]
 
     # set task queued time
-    def set_task_queued_time(self, queued_time: float | None):
+    def set_task_queued_time(self, queued_time):
         """
         Set task queued time in job metrics. Skip if queued_time is None
 
@@ -947,7 +969,7 @@ def push_status_changes(special_handling):
 
 
 # get task queued time
-def get_task_queued_time(special_handling) -> datetime.datetime | None:
+def get_task_queued_time(special_handling):
     """
     Get task queued time from job metrics
 
