@@ -1,4 +1,3 @@
-import datetime
 import gc
 import gzip
 import json
@@ -13,6 +12,7 @@ from typing import Generator
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 from werkzeug.datastructures import FileStorage
 
 from pandaserver.config import panda_config
@@ -91,7 +91,7 @@ def putFile(panda_request: PandaRequest, file: FileStorage) -> str:
         string: "True" if the upload was successful, otherwise an error message.
     """
 
-    tmp_log = LogWrapper(_logger, f"putFile-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"putFile-{naive_utcnow().isoformat('/')}")
     tmp_log.debug(f"start")
 
     # check if using secure connection and the proxy is not limited
@@ -173,11 +173,12 @@ def putFile(panda_request: PandaRequest, file: FileStorage) -> str:
         # decode Footer
         footer = file_content[-8:]
         checksum, _ = struct.unpack("II", footer)
+        checksum = str(checksum)
         tmp_log.debug(f"CRC from gzip Footer {checksum}")
     except Exception:
         # use None to avoid delay for now
-        checksum = None
-        tmp_log.debug(f"No CRC calculated {checksum}")
+        checksum = ""
+        tmp_log.debug(f"No CRC calculated")
 
     # calculate the file size
     file_size = len(file_content)
@@ -196,18 +197,26 @@ def putFile(panda_request: PandaRequest, file: FileStorage) -> str:
         if not to_insert:
             tmp_log.debug("skipped to insert to DB")
         else:
-            status_client, output_client = Client.insertSandboxFileInfo(user_name, file.filename, file_size, checksum)
-            if status_client != 0 or output_client.startswith("ERROR"):
+            status_client, output_client = Client.register_cache_file(user_name, file.filename, file_size, checksum)
+            if status_client != 0:
                 error_message = f"ERROR : failed to register sandbox to DB with {status_client} {output_client}"
                 tmp_log.error(error_message)
-                tmp_log.debug("end")
+                tmp_log.debug("Done")
                 return error_message
 
-            tmp_log.debug(f"inserted sandbox to DB with {output_client}")
+            success = output_client["success"]
+            message = output_client["message"]
+            if not success:
+                error_message = f"ERROR : failed to register sandbox to DB with {message}"
+                tmp_log.error(error_message)
+                tmp_log.debug("Done")
+                return error_message
+
+            tmp_log.debug(f"Inserted sandbox to DB with {output_client}")
 
     tmp_log.debug("trigger garbage collection")
     gc.collect()
-    tmp_log.debug("end")
+    tmp_log.debug("Done")
 
     return "True"
 
@@ -256,10 +265,10 @@ def putEventPickingRequest(
 
     user_name = panda_request.subprocess_env["SSL_CLIENT_S_DN"]
 
-    tmp_log = LogWrapper(_logger, f"putEventPickingRequest-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"putEventPickingRequest-{naive_utcnow().isoformat('/')}")
     tmp_log.debug(f"start for {user_name}")
 
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     # get total size
     try:
@@ -341,7 +350,7 @@ def put_file_recovery_request(panda_request: PandaRequest, jediTaskID: str, dryR
     if not Protocol.isSecure(panda_request):
         return json.dumps((False, ERROR_NOT_SECURE))
     user_name = panda_request.subprocess_env["SSL_CLIENT_S_DN"]
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     tmp_log = LogWrapper(_logger, f"put_file_recovery_request < jediTaskID={jediTaskID}")
     tmp_log.debug(f"start user={user_name}")
@@ -389,7 +398,7 @@ def put_workflow_request(panda_request: PandaRequest, data: str, check: bool = F
         return json.dumps((False, ERROR_NOT_SECURE))
 
     user_name = panda_request.subprocess_env["SSL_CLIENT_S_DN"]
-    creation_time = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).strftime("%Y-%m-%d %H:%M:%S")
+    creation_time = naive_utcnow().strftime("%Y-%m-%d %H:%M:%S")
 
     tmp_log = LogWrapper(_logger, "put_workflow_request")
 
