@@ -16,6 +16,18 @@ warnings.filterwarnings("ignore")
 _logger = PandaLogger().getLogger("WrappedCursor")
 
 
+# extract table names from sql query
+def extract_table_names(sql):
+    table_names = []
+    for item in re.findall(r" FROM (.+?)(WHERE|$)", sql, flags=re.IGNORECASE):
+        if "FROM" in item[0]:
+            table_names += extract_table_names(item[0])
+        else:
+            table_strs = item[0].split(",")
+            table_names += [re.sub(r"\(|\)", "", t.strip().lower()) for table_str in table_strs for t in table_str.split() if t.strip()]
+    return table_names
+
+
 # convert SQL and parameters in_printf format
 def convert_query_in_printf_format(sql, var_dict_list, sql_conv_map):
     if sql in sql_conv_map:
@@ -39,7 +51,7 @@ def convert_query_in_printf_format(sql, var_dict_list, sql_conv_map):
         # sub query + rownum
         sql = re.sub(r"\)\s+WHERE\s+rownum", r") tmp_sub WHERE rownum", sql, flags=re.IGNORECASE)
         # sub query + GROUP BY
-        if re.search(r"FROM\s+\(SELECT", sql, flags=re.IGNORECASE):
+        if re.search(r"FROM\s+\(\s*SELECT", sql, flags=re.IGNORECASE):
             sql = re.sub(r"\)\s+GROUP\s+BY", r") tmp_sub GROUP BY", sql, flags=re.IGNORECASE)
         # rownum
         sql = re.sub(
@@ -68,12 +80,14 @@ def convert_query_in_printf_format(sql, var_dict_list, sql_conv_map):
             # remove \n to make regexp easier
             sql = re.sub(r"\n", r" ", sql)
             # collect table names
-            table_names = set()
-            for item in re.findall(r" FROM (.+?)(WHERE|$)", sql, flags=re.IGNORECASE):
-                table_strs = item[0].split(",")
-                table_names.update([re.sub(r"\(|\)", "", t.strip().lower()) for table_str in table_strs for t in table_str.split() if t.strip()])
+            table_names = set(extract_table_names(sql))
+            checked_items = set()
             # look for a.b(.c)*
             for item in re.findall(r"(\w+\.\w+\.*\w*)", sql):
+                # skip if already checked
+                if item in checked_items:
+                    continue
+                checked_items.add(item)
                 item_l = item.lower()
                 # ignore tables
                 if item_l in table_names:
@@ -104,7 +118,7 @@ def convert_query_in_printf_format(sql, var_dict_list, sql_conv_map):
                 if not new_pat:
                     new_pat = re.sub(r"\.(?P<pat>\w+)", r"->>'\1'", item)
                 # guess type
-                right_vals = re.findall(old_pat + r"\s*[=<>!]+\s*([\w:\']+)", sql)
+                right_vals = re.findall(old_pat + r"\s*[=<>!*]+\s*([\w:\']+)", sql)
                 for right_val in right_vals:
                     # string
                     if "'" in right_val:
@@ -128,6 +142,7 @@ def convert_query_in_printf_format(sql, var_dict_list, sql_conv_map):
                             new_pat = f"CAST({new_pat} AS float)"
                             break
                 # replace
+                print(old_pat, new_pat)
                 sql = sql.replace(old_pat, new_pat)
             # cache
             sql_conv_map[old_sql] = sql
