@@ -2,8 +2,10 @@ import datetime
 import json
 import re
 import sys
+from typing import Dict
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 from pandaserver.config import panda_config
 from pandaserver.srvcore import CoreUtils
@@ -241,9 +243,7 @@ class MetricsModule(BaseModule):
             # add duration
             task_metrics.setdefault("queuingPeriods", [])
             if len(task_metrics["queuingPeriods"]) < 10000:
-                task_metrics["queuingPeriods"].append(
-                    {"start": queued_time, "end": datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None), "status": task_status}
-                )
+                task_metrics["queuingPeriods"].append({"start": queued_time, "end": naive_utcnow(), "status": task_status})
                 tmp_success = self.set_workload_metrics(jedi_task_id, None, task_metrics, False)
                 if not tmp_success:
                     err_str = f"failed to update task metrics for jediTaskId={jedi_task_id}"
@@ -300,7 +300,7 @@ class MetricsModule(BaseModule):
             else:
                 job_metrics["queuingPeriod"] = {
                     "start": task_queued_time,
-                    "end": datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None),
+                    "end": naive_utcnow(),
                     "status": job_status,
                 }
                 tmp_success = self.set_workload_metrics(jedi_task_id, panda_id, job_metrics, False)
@@ -356,7 +356,7 @@ class MetricsModule(BaseModule):
             task_metrics["activePeriod"].append(
                 {
                     "start": activated_time,
-                    "end": datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None),
+                    "end": naive_utcnow(),
                     "status": task_status,
                 }
             )
@@ -435,7 +435,7 @@ class MetricsModule(BaseModule):
                     if num_finished is not None and num_failed is not None and num_finished + num_failed
                     else None
                 ),
-                "failed_hep_score_hour": int(bad_hep_score_sec / 60 / 60),
+                "failed_hep_score_hour": int(bad_hep_score_sec / 60 / 60) if bad_hep_score_sec is not None else None,
                 "failed_hep_score_ratio": (
                     round(bad_hep_score_sec / (good_hep_score_sec + bad_hep_score_sec), 3)
                     if good_hep_score_sec is not None and bad_hep_score_sec is not None and good_hep_score_sec + bad_hep_score_sec
@@ -821,6 +821,53 @@ class MetricsModule(BaseModule):
             self.dump_error_message(tmpLog)
             return False, {}
 
+    # gets statistics on the number of jobs with a specific status for each nucleus at each site
+    def get_num_jobs_with_status_by_nucleus(self, vo: str, job_status: str) -> [bool, Dict[str, Dict[str, int]]]:
+        """
+        This function will return the number of jobs with a specific status for each nucleus at each site.
+
+        :param vo: Virtual Organization
+        :param job_status: Job status
+        :return: True/False and Dictionary with the number of jobs with a specific status for each nucleus at each site
+        """
+        comment = " /* DBProxy.get_num_jobs_with_status_by_nucleus */"
+        tmp_log = self.create_tagged_logger(comment, f" vo={vo} status={job_status}")
+        tmp_log.debug("start")
+
+        # define the var map of query parameters
+        var_map = {":vo": vo, ":job_status": job_status}
+
+        # sql to query on pre-cached job statistics table
+        sql_jt = """
+               SELECT /*+ RESULT_CACHE */ computingSite, nucleus, SUM(njobs) FROM %s
+               WHERE vo=:vo AND jobStatus=:job_status GROUP BY computingSite, nucleus
+               """
+
+        if job_status in ["transferring", "running", "activated" "holding"]:
+            table = f"{panda_config.schemaPANDA}.JOBS_SHARE_STATS"
+        else:
+            table = f"{panda_config.schemaPANDA}.JOBSDEFINED_SHARE_STATS"
+
+        return_map = {}
+        try:
+            self.cur.arraysize = 10000
+            sql_exe = (sql_jt + comment) % table
+            self.cur.execute(sql_exe, var_map)
+            res = self.cur.fetchall()
+
+            # create a dict
+            for panda_site, nucleus, n_jobs in res:
+                if n_jobs:
+                    # add site
+                    return_map.setdefault(panda_site, {})
+                    # add stat per nucleus
+                    return_map[panda_site][nucleus] = n_jobs
+            tmp_log.debug("done")
+            return True, return_map
+        except Exception:
+            self.dump_error_message(tmp_log)
+            return False, {}
+
 
 # get metrics module
 def get_metrics_module(base_mod) -> MetricsModule:
