@@ -6,6 +6,7 @@ import re
 import sys
 import traceback
 import uuid
+from statistics import mean
 
 import numpy
 from pandacommon.pandalogger.LogWrapper import LogWrapper
@@ -290,18 +291,22 @@ class TaskUtilsModule(BaseModule):
             cpuTimeRank = 95
 
         # sql to get preset values
-        sqlGPV = "SELECT "
-        sqlGPV += "prodSourceLabel, outDiskUnit, walltime, ramUnit, baseRamCount, "
-        sqlGPV += "workDiskCount, cpuEfficiency, baseWalltime, splitRule, "
-        sqlGPV += "memory_leak_core, memory_leak_x2 "
-        sqlGPV += f"FROM {panda_config.schemaJEDI}.JEDI_Tasks "
-        sqlGPV += "WHERE jediTaskID=:jediTaskID "
+        sqlGPV = (
+            "SELECT prodSourceLabel, outDiskUnit, walltime, ramUnit, baseRamCount, workDiskCount, cpuEfficiency, baseWalltime, "
+            "splitRule, memory_leak_core, memory_leak_x2 "
+            f"FROM {panda_config.schemaJEDI}.JEDI_Tasks "
+            "WHERE jediTaskID = :jediTaskID "
+        )
 
         # sql to get scout job data from JEDI
-        sqlSCF = "SELECT tabF.PandaID,tabF.fsize,tabF.startEvent,tabF.endEvent,tabF.nEvents,tabF.type "
-        sqlSCF += "FROM {0}.JEDI_Datasets tabD, {0}.JEDI_Dataset_Contents tabF WHERE ".format(panda_config.schemaJEDI)
-        sqlSCF += "tabD.jediTaskID=tabF.jediTaskID AND tabD.jediTaskID=:jediTaskID AND tabF.status=:status "
-        sqlSCF += "AND tabD.datasetID=tabF.datasetID "
+        sqlSCF = (
+            "SELECT tabF.PandaID, tabF.fsize, tabF.startEvent, tabF.endEvent, tabF.nEvents, tabF.type "
+            f"FROM {panda_config.schemaJEDI}.JEDI_Datasets tabD, {panda_config.schemaJEDI}.JEDI_Dataset_Contents tabF "
+            "WHERE tabD.jediTaskID = tabF.jediTaskID "
+            "AND tabD.jediTaskID = :jediTaskID "
+            "AND tabF.status = :status "
+            "AND tabD.datasetID = tabF.datasetID "
+        )
         if not mergeScout:
             sqlSCF += f"AND tabF.type IN ({INPUT_TYPES_var_str}) "
         else:
@@ -327,32 +332,36 @@ class TaskUtilsModule(BaseModule):
         sqlCSSR += ") tmp_sub "
 
         # sql to get normal scout job data from Panda
-        sqlSCDN = "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
-        sqlSCDN += "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, jobMetrics, nEvents, "
-        sqlSCDN += "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2 "
-        sqlSCDN += f"FROM {panda_config.schemaPANDA}.jobsArchived4 "
-        sqlSCDN += "WHERE PandaID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
-        sqlSCDN += "UNION "
-        sqlSCDN += "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
-        sqlSCDN += "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, jobMetrics, nEvents, "
-        sqlSCDN += "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2 "
-        sqlSCDN += f"FROM {panda_config.schemaPANDAARCH}.jobsArchived "
-        sqlSCDN += "WHERE PandaID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
-        sqlSCDN += "AND modificationTime>(CURRENT_DATE-30) "
+        sqlSCDN = (
+            "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
+            "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, specialHandling, nEvents, "
+            "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2, modificationhost "
+            f"FROM {panda_config.schemaPANDA}.jobsArchived4 "
+            "WHERE PandaID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
+            "UNION "
+            "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
+            "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, specialHandling, nEvents, "
+            "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2, modificationhost "
+            f"FROM {panda_config.schemaPANDAARCH}.jobsArchived "
+            "WHERE PandaID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
+            "AND modificationTime>(CURRENT_DATE-30) "
+        )
 
         # sql to get ES scout job data from Panda
-        sqlSCDE = "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
-        sqlSCDE += "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, jobMetrics, nEvents, "
-        sqlSCDE += "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2 "
-        sqlSCDE += f"FROM {panda_config.schemaPANDA}.jobsArchived4 "
-        sqlSCDE += "WHERE jobsetID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
-        sqlSCDE += "UNION "
-        sqlSCDE += "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
-        sqlSCDE += "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, jobMetrics, nEvents, "
-        sqlSCDE += "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2 "
-        sqlSCDE += f"FROM {panda_config.schemaPANDAARCH}.jobsArchived "
-        sqlSCDE += "WHERE jobsetID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
-        sqlSCDE += "AND modificationTime>(CURRENT_DATE-14) "
+        sqlSCDE = (
+            "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
+            "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, specialHandling, nEvents, "
+            "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2, modificationhost "
+            f"FROM {panda_config.schemaPANDA}.jobsArchived4 "
+            "WHERE jobsetID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
+            "UNION "
+            "SELECT eventService, jobsetID, PandaID, jobStatus, outputFileBytes, jobMetrics, cpuConsumptionTime, "
+            "actualCoreCount, coreCount, startTime, endTime, computingSite, maxPSS, specialHandling, nEvents, "
+            "totRBYTES, totWBYTES, inputFileBytes, memory_leak, memory_leak_x2, modificationhost "
+            f"FROM {panda_config.schemaPANDAARCH}.jobsArchived "
+            "WHERE jobsetID=:pandaID AND jobStatus=:jobStatus AND jediTaskID=:jediTaskID "
+            "AND modificationTime>(CURRENT_DATE-14) "
+        )
 
         # get size of lib
         sqlLIB = "SELECT MAX(fsize) "
@@ -385,7 +394,8 @@ class TaskUtilsModule(BaseModule):
             # begin transaction
             self.conn.begin()
         self.cur.arraysize = 100000
-        # get preset values
+
+        # get preset values to the task
         varMap = {}
         varMap[":jediTaskID"] = jediTaskID
         self.cur.execute(sqlGPV + comment, varMap)
@@ -422,9 +432,11 @@ class TaskUtilsModule(BaseModule):
             preCpuEfficiency = 100
         if preBaseWalltime is None:
             preBaseWalltime = 0
+
         # don't use baseRamCount for pmerge
         if mergeScout:
             preBaseRamCount = 0
+
         # use original ramCount if available
         if task_params_map is not None:
             preCpuTime = task_params_map.get("cpuTime")
@@ -449,20 +461,25 @@ class TaskUtilsModule(BaseModule):
             pass
         extraInfo["oldCpuTime"] = preCpuTime
         extraInfo["oldRamCount"] = preRamCount
+
         # get minimum ram count
         minRamCount = self.getConfigValue("dbproxy", "SCOUT_RAMCOUNT_MIN", "jedi")
+
         # get limit for short jobs
         shortExecTime = self.getConfigValue("dbproxy", f"SCOUT_SHORT_EXECTIME_{prodSourceLabel}", "jedi")
         if shortExecTime is None:
             shortExecTime = 0
+
         # get limit for cpu-inefficient jobs
         lowCpuEff = self.getConfigValue("dbproxy", f"SCOUT_LOW_CPU_EFFICIENCY_{prodSourceLabel}", "jedi")
         if lowCpuEff is None:
             lowCpuEff = 0
+
         # cap on diskIO
         capOnDiskIO = self.getConfigValue("dbproxy", "SCOUT_DISK_IO_CAP", "jedi")
         extraInfo["shortExecTime"] = shortExecTime
         extraInfo["cpuEfficiencyCap"] = lowCpuEff
+
         # get the size of lib
         varMap = {}
         varMap[":jediTaskID"] = jediTaskID
@@ -477,6 +494,7 @@ class TaskUtilsModule(BaseModule):
                 libSize /= 1024 * 1024
             except Exception:
                 pass
+
         # get files
         varMap = {}
         varMap[":jediTaskID"] = jediTaskID
@@ -495,27 +513,27 @@ class TaskUtilsModule(BaseModule):
             scoutSucceeded = False
             tmpLog.debug("no scouts succeeded")
             extraInfo["successRate"] = 0
-        else:
-            if not mergeScout and task_spec and task_spec.useScout():
-                # check scout success rate
-                varMap = {}
-                varMap[":jediTaskID"] = jediTaskID
-                varMap.update(INPUT_TYPES_var_map)
-                self.cur.execute(sqlCSSR + comment, varMap)
-                scTotal, scOK, scNG = self.cur.fetchone()
+        elif not mergeScout and task_spec and task_spec.useScout():
+            # check scout success rate
+            varMap = {":jediTaskID": jediTaskID}
+            varMap.update(INPUT_TYPES_var_map)
+            self.cur.execute(sqlCSSR + comment, varMap)
+            scTotal, scOK, scNG = self.cur.fetchone()
+
+            if scTotal > 0 and scOK + scNG > 0:
+                extraInfo["successRate"] = scOK / (scOK + scNG)
+            else:
+                extraInfo["successRate"] = 0
+            tmpLog.debug(
+                f"""scout total={scTotal} finished={scOK} failed={scNG} target_rate={None if scoutSuccessRate is None else scoutSuccessRate/10} actual_rate={extraInfo["successRate"]}"""
+            )
+            if scoutSuccessRate and scTotal and extraInfo["successRate"] < scoutSuccessRate / 10:
+                tmpLog.debug("not enough scouts succeeded")
+                scoutSucceeded = False
 
-                if scTotal > 0 and scOK + scNG > 0:
-                    extraInfo["successRate"] = scOK / (scOK + scNG)
-                else:
-                    extraInfo["successRate"] = 0
-                tmpLog.debug(
-                    f"""scout total={scTotal} finished={scOK} failed={scNG} target_rate={None if scoutSuccessRate is None else scoutSuccessRate/10} actual_rate={extraInfo["successRate"]}"""
-                )
-                if scoutSuccessRate and scTotal and extraInfo["successRate"] < scoutSuccessRate / 10:
-                    tmpLog.debug("not enough scouts succeeded")
-                    scoutSucceeded = False
         # upper limit
         limitWallTime = 999999999
+
         # loop over all files
         outSizeList = []
         outSizeDict = {}
@@ -568,6 +586,7 @@ class TaskUtilsModule(BaseModule):
             total_actual_input_size += fsize
             if fType == "pseudo_input":
                 pseudoInput.add(pandaID)
+
         # get nFiles
         totalJobs = 0
         totFiles = 0
@@ -618,6 +637,7 @@ class TaskUtilsModule(BaseModule):
         extraInfo["nFilesFinished"] = totFinished
         extraInfo["nNewJobs"] = nNewJobs
         extraInfo["expectedNumJobsWithEvent"] = total_jobs_with_event
+
         # loop over all jobs
         loopPandaIDs = list(inFSizeMap.keys())
         random.shuffle(loopPandaIDs)
@@ -659,39 +679,54 @@ class TaskUtilsModule(BaseModule):
                         endTime,
                         computingSite,
                         maxPSS,
-                        jobMetrics,
+                        specialHandling,
                         nEvents,
                         totRBYTES,
                         totWBYTES,
                         inputFileByte,
                         memory_leak,
                         memory_leak_x2,
+                        modificationhost,
                     ) = oneResData
 
+                    # event service job
+                    is_event_service = eventServiceJob == EventServiceUtils.esJobFlagNumber and not EventServiceUtils.isJobCloningSH(specialHandling)
                     # add inputSize and nEvents
                     if pandaID not in inFSizeMap:
                         inFSizeMap[pandaID] = totalFSize
-                    if pandaID not in inEventsMap or eventServiceJob == EventServiceUtils.esJobFlagNumber:
+                    if pandaID not in inEventsMap or is_event_service:
                         inEventsMap[pandaID] = nEvents
                     totInSizeMap[pandaID] = inputFileByte
 
                     siteMap[pandaID] = computingSite
 
-                    # get core power
-                    if computingSite not in corePowerMap:
-                        varMap = {}
-                        varMap[":site"] = computingSite
-                        self.cur.execute(sqlCore + comment, varMap)
-                        resCore = self.cur.fetchone()
-                        if resCore is not None:
-                            (corePower,) = resCore
-                            corePower = float(corePower)
-                        else:
-                            corePower = None
-                        corePowerMap[computingSite] = corePower
-                    corePower = corePowerMap[computingSite]
-                    if corePower in [0, None]:
+                    # --- core power by host (CPU model) ---
+                    benchmarks = []
+                    atlas_site = "NO_SITE"  # in case of no match
+                    if site_mapper:
+                        atlas_site = site_mapper.getSite(computingSite).pandasite
+                        benchmarks = self.get_cpu_benchmarks_by_host(atlas_site, modificationhost) or []
+
+                    vals = [v for _, v in benchmarks]
+                    benchmark_specific = next(
+                        (v for s, v in benchmarks if s and atlas_site and (s.upper() in atlas_site.upper() or atlas_site.upper() in s.upper())), 0
+                    )
+                    benchmark_average = mean(vals) if vals else 0
+
+                    # --- core power by site (fallback) ---
+                    if not benchmark_specific and not benchmark_average:
+                        if computingSite not in corePowerMap:
+                            self.cur.execute(sqlCore + comment, {":site": computingSite})
+                            row = self.cur.fetchone()
+                            corePowerMap[computingSite] = float(row[0]) if row and row[0] is not None else None
+                        corePower = corePowerMap[computingSite]
+                    else:
+                        corePower = benchmark_specific or benchmark_average
+
+                    # --- final fallback default ---
+                    if not corePower or corePower == 0:
                         corePower = 10
+
                     finishedJobs.append(pandaID)
                     inFSizeList.append(totalFSize)
                     jMetricsMap[pandaID] = jobMetrics
@@ -702,7 +737,7 @@ class TaskUtilsModule(BaseModule):
 
                     # output size
                     tmpWorkSize = 0
-                    if eventServiceJob != EventServiceUtils.esJobFlagNumber:
+                    if not is_event_service:
                         try:
                             try:
                                 # add size of intermediate files
@@ -745,9 +780,7 @@ class TaskUtilsModule(BaseModule):
                     # CPU time
                     if eventServiceJob != EventServiceUtils.esMergeJobFlagNumber:
                         try:
-                            if preCpuTimeUnit in ["HS06sPerEventFixed", "mHS06sPerEventFixed"]:
-                                pass
-                            else:
+                            if preCpuTimeUnit not in ["HS06sPerEventFixed", "mHS06sPerEventFixed"]:
                                 tmpVal = JobUtils.getHS06sec(
                                     startTime, endTime, corePower, coreCount, baseWalltime=preBaseWalltime, cpuEfficiency=preCpuEfficiency
                                 )
@@ -877,6 +910,7 @@ class TaskUtilsModule(BaseModule):
                 returnMap["outDiskUnit"] = "kBPerEvent"
             else:
                 returnMap["outDiskUnit"] = "kB"
+
         if walltimeList != []:
             maxWallTime = max(walltimeList)
             extraInfo["maxCpuConsumptionTime"] = maxWallTime
@@ -896,6 +930,7 @@ class TaskUtilsModule(BaseModule):
             if returnMap["walltime"] > limitWallTime:
                 returnMap["walltime"] = limitWallTime
         returnMap["walltimeUnit"] = "kSI2kseconds"
+
         if cpuTimeList != []:
             maxCpuTime, origValues = CoreUtils.percentile(cpuTimeList, cpuTimeRank, cpuTimeDict)
             for origValue in origValues:
@@ -915,12 +950,14 @@ class TaskUtilsModule(BaseModule):
                 returnMap["cpuTimeUnit"] = "HS06sPerEvent"
             maxCpuTime = int(math.ceil(maxCpuTime))
             returnMap["cpuTime"] = maxCpuTime
+
         if ioIntentList != []:
             maxIoIntent = max(ioIntentList)
             addTag(jobTagMap, ioIntentDict, maxIoIntent, "ioIntensity")
             maxIoIntent = int(math.ceil(maxIoIntent))
             returnMap["ioIntensity"] = maxIoIntent
             returnMap["ioIntensityUnit"] = "kBPerS"
+
         if diskIoList != []:
             aveDiskIo = sum(diskIoList) // len(diskIoList)
             aveDiskIo = int(math.ceil(aveDiskIo))
@@ -928,12 +965,15 @@ class TaskUtilsModule(BaseModule):
                 aveDiskIo = min(aveDiskIo, capOnDiskIO)
             returnMap["diskIO"] = aveDiskIo
             returnMap["diskIOUnit"] = "kBPerS"
+
         if leak_list:
             ave_leak = int(math.ceil(sum(leak_list) / len(leak_list)))
             returnMap["memory_leak_core"] = ave_leak
+
         if leak_x2_list:
             ave_leak_x2 = int(math.ceil(sum(leak_x2_list) / len(leak_x2_list)))
             returnMap["memory_leak_x2"] = ave_leak_x2
+
         if memSizeList != []:
             memVal, origValues = CoreUtils.percentile(memSizeList, ramCountRank, memSizeDict)
             for origValue in origValues:
@@ -953,6 +993,7 @@ class TaskUtilsModule(BaseModule):
             else:
                 returnMap["ramUnit"] = "MB"
                 returnMap["ramCount"] = memVal
+
         if workSizeList != []:
             median = max(workSizeList)
             returnMap["workDiskCount"] = int(median)
@@ -960,10 +1001,12 @@ class TaskUtilsModule(BaseModule):
             # use preset value if larger
             if preWorkDiskCount is not None and preWorkDiskCount > returnMap["workDiskCount"]:
                 returnMap["workDiskCount"] = preWorkDiskCount
+
         if cpuEffList != []:
             minCpuEfficiency = int(numpy.median(cpuEffList))
             addTag(jobTagMap, cpuEffDict, minCpuEfficiency, "cpuEfficiency")
             extraInfo["minCpuEfficiency"] = minCpuEfficiency
+
         nShortJobs = 0
         nShortJobsWithCtoS = 0
         nTotalForShort = 0
@@ -1126,6 +1169,7 @@ class TaskUtilsModule(BaseModule):
                 sqlTSL += " WHERE jediTaskID=:jediTaskID "
                 tmpLog.debug(sqlTSL + comment + str(varMap))
                 self.cur.execute(sqlTSL + comment, varMap)
+
         # set average merge job data
         mergeScoutSucceeded = None
         if taskSpec.mergeOutput():
@@ -1145,6 +1189,7 @@ class TaskUtilsModule(BaseModule):
                 sqlTSD += " WHERE jediTaskID=:jediTaskID "
                 tmpLog.debug(sqlTSD + comment + str(varMap))
                 self.cur.execute(sqlTSD + comment, varMap)
+
         # go to exhausted if necessary
         nNewJobsCutoff = 20
         if useExhausted and scoutSucceeded and extraInfo["nNewJobs"] > nNewJobsCutoff:
@@ -1432,107 +1477,6 @@ class TaskUtilsModule(BaseModule):
             self.dump_error_message(tmpLog)
             return None
 
-    # retry child tasks
-    def retryChildTasks_JEDI(self, jediTaskID, keep_share_priority=False, useCommit=True):
-        comment = " /* JediDBProxy.retryChildTasks_JEDI */"
-        tmpLog = self.create_tagged_logger(comment, f"jediTaskID={jediTaskID}")
-        tmpLog.debug("start")
-        retried_tasks = []
-        try:
-            # sql to get output datasets of parent task
-            sqlPD = f"SELECT datasetName,containerName FROM {panda_config.schemaJEDI}.JEDI_Datasets "
-            sqlPD += "WHERE jediTaskID=:jediTaskID AND type IN (:type1,:type2) "
-            # sql to get child tasks
-            sqlGT = f"SELECT jediTaskID,status FROM {panda_config.schemaJEDI}.JEDI_Tasks "
-            sqlGT += "WHERE parent_tid=:jediTaskID AND parent_tid<>jediTaskID "
-            # sql to get input datasets of child task
-            sqlRD = f"SELECT datasetID,datasetName FROM {panda_config.schemaJEDI}.JEDI_Datasets "
-            sqlRD += f"WHERE jediTaskID=:jediTaskID AND type IN ({PROCESS_TYPES_var_str}) "
-            # sql to change task status
-            sqlCT = f"UPDATE {panda_config.schemaJEDI}.JEDI_Tasks "
-            sqlCT += "SET status=:status,errorDialog=NULL,stateChangeTime=CURRENT_DATE "
-            sqlCT += "WHERE jediTaskID=:jediTaskID "
-            # sql to set mutable to dataset status
-            sqlMD = f"UPDATE {panda_config.schemaJEDI}.JEDI_Datasets "
-            sqlMD += "SET state=:state,stateCheckTime=CURRENT_DATE "
-            sqlMD += "WHERE jediTaskID=:jediTaskID AND datasetID=:datasetID "
-            # sql to set dataset status
-            sqlCD = f"UPDATE {panda_config.schemaJEDI}.JEDI_Datasets "
-            sqlCD += "SET status=:status "
-            sqlCD += "WHERE jediTaskID=:jediTaskID AND type=:type "
-            # begin transaction
-            if useCommit:
-                self.conn.begin()
-            # get output datasets of parent task
-            varMap = {}
-            varMap[":jediTaskID"] = jediTaskID
-            varMap[":type1"] = "output"
-            varMap[":type2"] = "log"
-            self.cur.execute(sqlPD + comment, varMap)
-            resList = self.cur.fetchall()
-            parentDatasets = set()
-            for tmpDS, tmpDC in resList:
-                parentDatasets.add(tmpDS)
-                parentDatasets.add(tmpDC)
-            # get child tasks
-            varMap = {}
-            varMap[":jediTaskID"] = jediTaskID
-            self.cur.execute(sqlGT + comment, varMap)
-            resList = self.cur.fetchall()
-            for cJediTaskID, cTaskStatus in resList:
-                # not to retry if child task is aborted/broken
-                if cTaskStatus in ["aborted", "toabort", "aborting", "broken", "tobroken", "failed"]:
-                    tmpLog.debug(f"not to retry child jediTaskID={cJediTaskID} in {cTaskStatus}")
-                    continue
-                # get input datasets of child task
-                varMap = {}
-                varMap[":jediTaskID"] = cJediTaskID
-                varMap.update(PROCESS_TYPES_var_map)
-                self.cur.execute(sqlRD + comment, varMap)
-                dsList = self.cur.fetchall()
-                inputReady = False
-                for datasetID, datasetName in dsList:
-                    # set dataset status to mutable
-                    if datasetName in parentDatasets or datasetName.split(":")[-1] in parentDatasets:
-                        varMap = {}
-                        varMap[":jediTaskID"] = cJediTaskID
-                        varMap[":datasetID"] = datasetID
-                        varMap[":state"] = "mutable"
-                        self.cur.execute(sqlMD + comment, varMap)
-                        inputReady = True
-                # set task status
-                if not inputReady:
-                    # set task status to registered since dataset is not ready
-                    varMap = {}
-                    varMap[":jediTaskID"] = cJediTaskID
-                    varMap[":status"] = "registered"
-                    self.cur.execute(sqlCT + comment, varMap)
-                    # add missing record_task_status_change and push_task_status_message updates
-                    self.record_task_status_change(cJediTaskID)
-                    self.push_task_status_message(None, cJediTaskID, varMap[":status"])
-                    tmpLog.debug(f"set status of child jediTaskID={cJediTaskID} to {varMap[':status']}")
-                elif cTaskStatus not in ["ready", "running", "scouting", "scouted"]:
-                    # incexec child task
-                    tmpLog.debug(f"incremental execution for child jediTaskID={cJediTaskID}")
-                    _, _, tmp_retried_tasks = self.retryTask_JEDI(
-                        cJediTaskID, "incexec", useCommit=False, statusCheck=False, keep_share_priority=keep_share_priority
-                    )
-                    retried_tasks += tmp_retried_tasks
-            # commit
-            if useCommit:
-                if not self._commit():
-                    raise RuntimeError("Commit error")
-            # return
-            tmpLog.debug("done")
-            return True, retried_tasks
-        except Exception:
-            # roll back
-            if useCommit:
-                self._rollback()
-            # error
-            self.dump_error_message(tmpLog)
-            return False, retried_tasks
-
     # kill child tasks
     def killChildTasks_JEDI(self, jediTaskID, taskStatus, useCommit=True):
         comment = " /* JediDBProxy.killChildTasks_JEDI */"
@@ -1863,51 +1807,64 @@ class TaskUtilsModule(BaseModule):
             return failedRet
 
     # check parent task status
-    def checkParentTask_JEDI(self, jediTaskID, useCommit=True):
+    def checkParentTask_JEDI(self, parent_task_id: int, jedi_task_id: int = None, use_commit: bool = True) -> str | None:
+        """
+        Check the status of parent task
+        Args:
+            parent_task_id: JEDI task ID of parent task
+            jedi_task_id: JEDI task ID of child task (for logging purpose)
+            use_commit: whether to use commit/rollback
+        Returns:
+          "completed": parent task is done/finished
+          "corrupted": parent task is broken/aborted/failed
+          "running": parent task is still running
+          "unknown": parent task is not found
+          None: error
+        """
         comment = " /* JediDBProxy.checkParentTask_JEDI */"
-        tmpLog = self.create_tagged_logger(comment, f"jediTaskID={jediTaskID}")
-        tmpLog.debug("start")
+        tmp_log = self.create_tagged_logger(comment, f"jediTaskID={jedi_task_id} parent={parent_task_id}")
+        tmp_log.debug("start")
+        ret_val = None
         try:
-            retVal = None
+
             sql = f"SELECT status FROM {panda_config.schemaJEDI}.JEDI_Tasks "
             sql += "WHERE jediTaskID=:jediTaskID "
-            varMap = {}
-            varMap[":jediTaskID"] = jediTaskID
+            var_map = {":jediTaskID": parent_task_id}
             # start transaction
-            if useCommit:
+            if use_commit:
                 self.conn.begin()
-            self.cur.execute(sql + comment, varMap)
-            resTK = self.cur.fetchone()
-            if useCommit:
+            self.cur.execute(sql + comment, var_map)
+            res_tk = self.cur.fetchone()
+            if use_commit:
                 # commit
                 if not self._commit():
                     raise RuntimeError("Commit error")
-            if resTK is None:
-                tmpLog.error("parent not found")
-                retVal = "unknown"
+            if res_tk is None:
+                tmp_log.error("parent not found")
+                ret_val = "unknown"
             else:
                 # task status
-                (taskStatus,) = resTK
-                tmpLog.debug(f"parent status = {taskStatus}")
-                if taskStatus in ["done", "finished"]:
+                (task_status,) = res_tk
+                tmp_log.debug(f"parent status = {task_status}")
+                if task_status in ["done", "finished"]:
                     # parent is completed
-                    retVal = "completed"
-                elif taskStatus in ["broken", "aborted", "failed"]:
+                    ret_val = "completed"
+                elif task_status in ["broken", "aborted", "failed"]:
                     # parent is corrupted
-                    retVal = "corrupted"
+                    ret_val = "corrupted"
                 else:
                     # parent is running
-                    retVal = "running"
+                    ret_val = "running"
             # return
-            tmpLog.debug(f"done with {retVal}")
-            return retVal
+            tmp_log.debug(f"done with {ret_val}")
+            return ret_val
         except Exception:
-            if useCommit:
+            if use_commit:
                 # roll back
                 self._rollback()
             # error
-            self.dump_error_message(tmpLog)
-            return retVal
+            self.dump_error_message(tmp_log)
+            return ret_val
 
 
 # get module
