@@ -5,10 +5,11 @@ import re
 import sys
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
-from pandacommon.pandautils.PandaUtils import naive_utcnow
+from pandacommon.pandautils.PandaUtils import get_sql_IN_bind_variables, naive_utcnow
 
 from pandaserver.config import panda_config
 from pandaserver.srvcore import CoreUtils
+from pandaserver.srvcore.CoreUtils import clean_host_name
 from pandaserver.taskbuffer import ErrorCode, JobUtils
 from pandaserver.taskbuffer.db_proxy_mods.base_module import BaseModule
 from pandaserver.taskbuffer.db_proxy_mods.entity_module import get_entity_module
@@ -120,7 +121,7 @@ class WorkerModule(BaseModule):
                 "GROUP BY computingSite,harvester_ID,jobType,resourceType,status "
             )
             varMap = dict()
-            varMap[":time_limit"] = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=4)
+            varMap[":time_limit"] = naive_utcnow() - datetime.timedelta(hours=4)
             self.cur.execute(sqlGA + comment, varMap)
             res_active = self.cur.fetchall()
             retMap = {}
@@ -178,13 +179,13 @@ class WorkerModule(BaseModule):
                 if (
                     commandStatus in ["new", "lock", "retrieved"]
                     and lockInterval is not None
-                    and statusDate > datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=lockInterval)
+                    and statusDate > naive_utcnow() - datetime.timedelta(minutes=lockInterval)
                 ):
                     toSkip = True
                 elif (
                     commandStatus in ["retrieved", "acknowledged"]
                     and comInterval is not None
-                    and statusDate > datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=comInterval)
+                    and statusDate > naive_utcnow() - datetime.timedelta(minutes=comInterval)
                 ):
                     toSkip = True
                 else:
@@ -295,6 +296,7 @@ class WorkerModule(BaseModule):
         comment = " /* DBProxy.get_average_memory_workers */"
         tmp_log = self.create_tagged_logger(comment)
         tmp_log.debug("start")
+
         try:
             # sql to calculate the average memory for the queue - harvester_id combination
             # "* 1" in sj.data.blah * 1 is required to notify postgres the data type is an int since json element is
@@ -433,12 +435,20 @@ class WorkerModule(BaseModule):
         if assigned_harvester_id and assigned_harvester_id in harvester_ids_temp:
             harvester_id = assigned_harvester_id
         else:
+            # commit for postgres to avoid idle transactions
+            if not self._commit():
+                raise RuntimeError("Commit error")
             tmp_log.error("No harvester instance assigned or not in statistics")
             return {}
 
+        # There is the case where the grid has no workloads and running HIMEM jobs is better than running no jobs
+        ignore_meanrss = self.getConfigValue("meanrss", "IGNORE_MEANRSS")
+        if ignore_meanrss == True:
+            tmp_log.debug(f"Accepting all resource types since meanrss throttling is ignored")
+
         # If the site defined a memory target, calculate the memory requested by running and queued workers
         resource_types_under_target = []
-        if average_memory_target:
+        if ignore_meanrss != True and average_memory_target:
             average_memory_workers_running_submitted, average_memory_workers_running = self.get_average_memory_workers(
                 queue, harvester_id, average_memory_target
             )
@@ -527,9 +537,9 @@ class WorkerModule(BaseModule):
 
             # if we need to filter on resource types
             if resource_types_under_target:
-                resource_type_string = ", ".join([f":{item}" for item in resource_types_under_target])
-                sql += f"   AND resource_type IN ({resource_type_string}) "
-                var_map.update({f":{item}": item for item in resource_types_under_target})
+                rtype_var_names_str, rtype_var_map = get_sql_IN_bind_variables(resource_types_under_target, prefix=":", value_as_suffix=True)
+                sql += f"   AND resource_type IN ({rtype_var_names_str}) "
+                var_map.update(rtype_var_map)
 
             sql += "ORDER BY currentpriority DESC"
             self.cur.execute(sql + comment, var_map)
@@ -602,6 +612,9 @@ class WorkerModule(BaseModule):
         new_workers_per_harvester = {harvester_id: new_workers}
 
         tmp_log.debug(f"Workers to submit: {new_workers_per_harvester}")
+        # commit for postgres to avoid idle transactions
+        if not self._commit():
+            raise RuntimeError("Commit error")
         tmp_log.debug("done")
         return new_workers_per_harvester
 
@@ -650,7 +663,7 @@ class WorkerModule(BaseModule):
         tmp_log = self.create_tagged_logger(comment, f"harvesterID={harvester_ID} command={command}")
         tmp_log.debug("start")
         try:
-            timeNow = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            timeNow = naive_utcnow()
             # sql to get commands
             sqlC = "SELECT computingSite,resourceType FROM ATLAS_PANDA.Harvester_Command_Lock "
             sqlC += "WHERE harvester_ID=:harvester_ID AND command=:command "
@@ -807,13 +820,13 @@ class WorkerModule(BaseModule):
         tmp_log = self.create_tagged_logger(comment, f"harvesterID={harvesterID} pid={os.getpid()}")
         try:
             tmp_log.debug(f"start {len(data)} workers")
-            regStart = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            regStart = naive_utcnow()
             sqlC = f"SELECT {WorkerSpec.columnNames()} FROM ATLAS_PANDA.Harvester_Workers "
             sqlC += "WHERE harvesterID=:harvesterID AND workerID=:workerID "
             # loop over all workers
             retList = []
             for workerData in data:
-                timeNow = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+                timeNow = naive_utcnow()
                 if useCommit:
                     self.conn.begin()
                 workerSpec = WorkerSpec()
@@ -970,7 +983,7 @@ class WorkerModule(BaseModule):
                                 varMap[":jobStatus"] = "failed"
                                 varMap[":attemptNr"] = attemptNr
                                 varMap[":data"] = None
-                                varMap[":timeStamp"] = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+                                varMap[":timeStamp"] = naive_utcnow()
                                 try:
                                     self.cur.execute(sqlI + comment, varMap)
                                 except Exception:
@@ -1006,7 +1019,7 @@ class WorkerModule(BaseModule):
                     if not self._commit():
                         raise RuntimeError("Commit error")
                 retList.append(True)
-            regTime = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - regStart
+            regTime = naive_utcnow() - regStart
             tmp_log.debug("done. exec_time=%s.%03d sec" % (regTime.seconds, regTime.microseconds / 1000))
             return retList
         except Exception:
@@ -1021,7 +1034,7 @@ class WorkerModule(BaseModule):
         comment = " /* DBProxy.updateWorkerPilotStatus */"
         tmp_log = self.create_tagged_logger(comment, f"harvesterID={harvesterID} workerID={workerID}")
 
-        timestamp_utc = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        timestamp_utc = naive_utcnow()
         var_map = {
             ":status": status,
             ":harvesterID": harvesterID,
@@ -1062,6 +1075,7 @@ class WorkerModule(BaseModule):
         site,
         host_name,
         cpu_model,
+        cpu_model_normalized,
         n_logical_cpus,
         n_sockets,
         cores_per_socket,
@@ -1070,6 +1084,7 @@ class WorkerModule(BaseModule):
         cpu_architecture_level,
         clock_speed,
         total_memory,
+        total_local_disk,
     ):
         comment = " /* DBProxy.update_worker_node */"
         method_name = comment.split(" ")[-2].split(".")[-1]
@@ -1077,11 +1092,10 @@ class WorkerModule(BaseModule):
         tmp_logger = self.create_tagged_logger(comment, f"{method_name} < site={site} host_name={host_name} cpu_model={cpu_model} >")
         tmp_logger.debug("Start")
 
-        timestamp_utc = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+        timestamp_utc = naive_utcnow()
 
-        # If the worker node comes in the slot1@worker1.example.com format, we remove the slot1@ part
-        match = re.search(r"@(.+)", host_name)
-        host_name = match.group(1) if match else host_name
+        # clean up host name from any prefixes
+        host_name = clean_host_name(host_name)
 
         locked = True  # Track whether the worker node was locked by another pilot update
 
@@ -1092,8 +1106,7 @@ class WorkerModule(BaseModule):
             var_map = {":site": site, ":host_name": host_name, ":cpu_model": cpu_model}
 
             sql = (
-                "SELECT site, host_name, cpu_model, n_logical_cpus, n_sockets, cores_per_socket, threads_per_core, "
-                "cpu_architecture, cpu_architecture_level, clock_speed, total_memory "
+                "SELECT site, host_name, cpu_model "
                 "FROM ATLAS_PANDA.worker_node "
                 "WHERE site=:site AND host_name=:host_name AND cpu_model=:cpu_model "
                 "FOR UPDATE NOWAIT"
@@ -1121,6 +1134,7 @@ class WorkerModule(BaseModule):
                 ":site": site,
                 ":host_name": host_name,
                 ":cpu_model": cpu_model,
+                ":cpu_model_normalized": cpu_model_normalized,
                 ":n_logical_cpus": n_logical_cpus,
                 "n_sockets": n_sockets,
                 ":cores_per_socket": cores_per_socket,
@@ -1129,16 +1143,17 @@ class WorkerModule(BaseModule):
                 ":cpu_architecture_level": cpu_architecture_level,
                 ":clock_speed": clock_speed,
                 ":total_memory": total_memory,
+                ":total_local_disk": total_local_disk,
                 ":last_seen": timestamp_utc,
             }
 
             sql = (
                 "INSERT INTO ATLAS_PANDA.worker_node "
-                "(site, host_name, cpu_model, n_logical_cpus, n_sockets, cores_per_socket, threads_per_core, "
-                "cpu_architecture, cpu_architecture_level, clock_speed, total_memory, last_seen) "
+                "(site, host_name, cpu_model, cpu_model_normalized, n_logical_cpus, n_sockets, cores_per_socket, threads_per_core, "
+                "cpu_architecture, cpu_architecture_level, clock_speed, total_memory, total_local_disk, last_seen) "
                 "VALUES "
-                "(:site, :host_name, :cpu_model, :n_logical_cpus, :n_sockets, :cores_per_socket, :threads_per_core, "
-                ":cpu_architecture, :cpu_architecture_level, :clock_speed, :total_memory, :last_seen)"
+                "(:site, :host_name, :cpu_model, :cpu_model_normalized, :n_logical_cpus, :n_sockets, :cores_per_socket, :threads_per_core, "
+                ":cpu_architecture, :cpu_architecture_level, :clock_speed, :total_memory, :total_local_disk, :last_seen)"
             )
 
             self.cur.execute(sql + comment, var_map)
@@ -1162,6 +1177,117 @@ class WorkerModule(BaseModule):
             tmp_logger.error(error_message)
             return False, error_message
 
+    def update_worker_node_gpu(
+        self,
+        site: str,
+        host_name: str,
+        vendor: str,
+        model: str,
+        count: int,
+        vram: int,
+        architecture: str,
+        framework: str,
+        framework_version: str,
+        driver_version: str,
+    ):
+        comment = " /* DBProxy.update_worker_node_gpu */"
+        method_name = comment.split(" ")[-2].split(".")[-1]
+
+        tmp_logger = self.create_tagged_logger(comment, f"{method_name} < site={site} host_name={host_name} vendor={vendor} model={model} >")
+        tmp_logger.debug("Start")
+
+        timestamp_utc = naive_utcnow()
+
+        # clean up host name from any prefixes
+        host_name = clean_host_name(host_name)
+
+        locked = True  # Track whether the worker node was locked by another pilot update
+
+        try:
+            self.conn.begin()
+
+            # Select the GPU to see if it exists in the database
+            var_map = {":site": site, ":host_name": host_name, ":vendor": vendor, ":model": model}
+
+            sql = (
+                "SELECT site, host_name, vendor, model "
+                "FROM ATLAS_PANDA.worker_node_gpus "
+                "WHERE site=:site AND host_name=:host_name AND vendor=:vendor AND model=:model "
+                "FOR UPDATE NOWAIT"
+            )
+
+            self.cur.execute((sql + comment), var_map)
+            res = self.cur.fetchone()
+            locked = False  # If the row was locked, the NOWAIT clause will make the query except and go to the end
+
+            # The worker node GPU entry exists, we update the worker node's last_seen timestamp, count, framework, and framework_version
+            if res:
+                var_map = {
+                    ":site": site,
+                    ":host_name": host_name,
+                    ":vendor": vendor,
+                    ":model": model,
+                    ":framework": framework,
+                    ":framework_version": framework_version,
+                    ":count": count,
+                    ":last_seen": timestamp_utc,
+                }
+
+                sql = (
+                    "UPDATE ATLAS_PANDA.worker_node_gpus SET last_seen=:last_seen, framework=:framework, framework_version=:framework_version, count=:count "
+                    "WHERE site=:site AND host_name=:host_name AND vendor=:vendor AND model=:model"
+                )
+
+                self.cur.execute((sql + comment), var_map)
+                tmp_logger.debug("Worker node GPU was found in the database. Updated last_seen timestamp and count.")
+                if not self._commit():
+                    raise RuntimeError("Commit error")
+
+                return True, "Updated existing worker node GPU."
+
+            # The worker node GPU entry did not exist, we insert it as a new worker node GPU
+            var_map = {
+                ":site": site,
+                ":host_name": host_name,
+                ":vendor": vendor,
+                ":model": model,
+                ":count": count,
+                ":vram": vram,
+                ":architecture": architecture,
+                ":framework": framework,
+                ":framework_version": framework_version,
+                ":driver_version": driver_version,
+                ":last_seen": timestamp_utc,
+            }
+
+            sql = (
+                "INSERT INTO ATLAS_PANDA.worker_node_gpus "
+                "(site, host_name, vendor, model, count, vram, architecture, framework, framework_version, driver_version, last_seen) "
+                "VALUES "
+                "(:site, :host_name, :vendor, :model, :count, :vram, :architecture, :framework, :framework_version, :driver_version, :last_seen)"
+            )
+
+            self.cur.execute(sql + comment, var_map)
+            if not self._commit():
+                raise RuntimeError("Commit error")
+            tmp_logger.debug("Inserted as new worker node GPU.")
+
+            return True, "Inserted new worker node GPU."
+
+        except Exception:
+            # Always roll back the transaction
+            self._rollback(True)
+
+            # Failed because of the NOWAIT clause
+            if locked:
+                return False, "Another pilot was updating the worker node GPU at the same time."
+
+            # General failure
+            err_type, err_value = sys.exc_info()[:2]
+            error_message = f"Worker node GPU update failed with {err_type} {err_value}"
+            tmp_logger.error(error_message)
+            return False, error_message
+
     # get workers for a job
     def getWorkersForJob(self, PandaID):
         comment = " /* DBProxy.getWorkersForJob */"
@@ -1202,9 +1328,9 @@ class WorkerModule(BaseModule):
             tmp_log.debug("Starting")
 
             # give harvester a chance to discover the status change itself
-            discovery_period = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=60)
+            discovery_period = naive_utcnow() - datetime.timedelta(minutes=60)
             # don't repeat the same workers in each cycle
-            retry_period = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=30)
+            retry_period = naive_utcnow() - datetime.timedelta(minutes=30)
 
             # Select workers where the status is more advanced according to the pilot than to harvester
             sql_select = """
@@ -1222,7 +1348,7 @@ class WorkerModule(BaseModule):
                 ":retry_period": retry_period,
             }
 
-            now_ts = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            now_ts = naive_utcnow()
             sql_update = """
             UPDATE ATLAS_PANDA.harvester_workers
             SET pilotStatusSyncTime = :lastSync
@@ -1376,7 +1502,7 @@ class WorkerModule(BaseModule):
         else:
             sqlU += "AND resourceType=:resourceType "
         try:
-            timeNow = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+            timeNow = naive_utcnow()
             # start transaction
             self.conn.begin()
             # check
@@ -1601,7 +1727,7 @@ class WorkerModule(BaseModule):
             var_map = {
                 ":panda_id": panda_id,
                 ":message": pilot_log[:4000],  # clip if longer than 4k characters
-                ":now": datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None),
+                ":now": naive_utcnow(),
                 ":name": "panda.mon.prod",
                 ":module": "JobDispatcher",
                 ":type": "pilotLog",
@@ -1640,6 +1766,9 @@ class WorkerModule(BaseModule):
         tmp_log = self.create_tagged_logger(comment)
         tmp_log.debug("start")
 
+        # start transaction for postgres to avoid idle transactions
+        self.conn.begin()
+
         # get current pilot distribution in harvester for the queue
         sql = f"""
               SELECT computingsite, harvester_id, jobType, resourceType, status, n_workers
@@ -1647,7 +1776,7 @@ class WorkerModule(BaseModule):
               WHERE lastupdate > :time_limit
               """
         var_map = {}
-        var_map[":time_limit"] = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=60)
+        var_map[":time_limit"] = naive_utcnow() - datetime.timedelta(minutes=60)
 
         self.cur.execute(sql + comment, var_map)
         worker_stats_rows = self.cur.fetchall()
@@ -1666,9 +1795,39 @@ class WorkerModule(BaseModule):
             worker_stats_dict[computing_site][harvester_id][job_type].setdefault(resource_type, {})
             worker_stats_dict[computing_site][harvester_id][job_type][resource_type][status] = n_workers
 
+        if not self._commit():
+            raise RuntimeError("Commit error")
         tmp_log.debug("done")
         return worker_stats_dict
 
+    def get_cpu_benchmarks_by_host(self, site: str, host_name: str) -> list[tuple[str, float]]:
+        comment = " /* DBProxy.get_cpu_benchmarks_by_host */"
+        tmp_log = self.create_tagged_logger(comment, f"host_name={host_name}")
+        tmp_log.debug("Start")
+
+        host_name_clean = clean_host_name(host_name)
+
+        try:
+            sql = (
+                "SELECT cb.site, score_per_core FROM atlas_panda.worker_node wn, atlas_panda.cpu_benchmarks cb "
+                "WHERE wn.site = :site "
+                "AND wn.host_name = :host_name "
+                "AND cb.cpu_type_normalized = wn.cpu_model_normalized "
+                "AND wn.threads_per_core = cb.smt_enabled + 1"
+            )
+
+            var_map = {"site": site, "host_name": host_name_clean}
+
+            self.cur.execute(sql + comment, var_map)
+            results = self.cur.fetchall()
+
+            tmp_log.debug(f"Got {len(results)} benchmarks")
+            return results
+
+        except Exception:
+            self.dump_error_message(tmp_log)
+            return []
+
 
 # get worker module
 def get_worker_module(base_mod) -> WorkerModule:
