@@ -1,16 +1,13 @@
 import optparse
 import time
 
-import pandaserver.userinterface.Client as Client
-
 # password
 from pandaserver.config import panda_config
 from pandaserver.taskbuffer.OraDBProxy import DBProxy
+from pandaserver.userinterface import Client
 
-aSrvID = None
-
-optP = optparse.OptionParser(conflict_handler="resolve")
-optP.add_option(
+option_parser = optparse.OptionParser(conflict_handler="resolve")
+option_parser.add_option(
     "-9",
     action="store_const",
     const=True,
@@ -18,7 +15,7 @@ optP.add_option(
     default=False,
     help="kill jobs even if they are still running",
 )
-optP.add_option(
+option_parser.add_option(
     "--noRunning",
     action="store_const",
     const=True,
@@ -26,7 +23,7 @@ optP.add_option(
     default=True,
     help="kill jobs if they are not in running or transferring (ON by default)",
 )
-optP.add_option(
+option_parser.add_option(
     "--killAny",
     action="store_const",
     const=True,
@@ -34,7 +31,7 @@ optP.add_option(
     default=False,
     help="kill jobs in any status",
 )
-optP.add_option(
+option_parser.add_option(
     "--prodSourceLabel",
     action="store",
     dest="prodSourceLabel",
@@ -42,7 +39,7 @@ optP.add_option(
     help="prodSourceLabel",
 )
 
-options, args = optP.parse_args()
+options, args = option_parser.parse_args()
 
 proxyS = DBProxy()
 proxyS.connect(panda_config.dbhost, panda_config.dbpasswd, panda_config.dbuser, panda_config.dbname)
@@ -76,8 +73,8 @@ if len(jobs):
     while iJob < len(jobs):
         print(f"kill {str(jobs[iJob:iJob + nJob])}")
         if options.forceKill:
-            Client.killJobs(jobs[iJob : iJob + nJob], 9)
+            Client.kill_jobs(jobs[iJob : iJob + nJob], 9)
         else:
-            Client.killJobs(jobs[iJob : iJob + nJob])
+            Client.kill_jobs(jobs[iJob : iJob + nJob])
         iJob += nJob
         time.sleep(1)
