@@ -2,19 +2,20 @@ import argparse
 import datetime
 import time
 
-import pandaserver.userinterface.Client as Client
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 # password
 from pandaserver.config import panda_config
 from pandaserver.taskbuffer.OraDBProxy import DBProxy
+from pandaserver.userinterface import Client
 
 proxyS = DBProxy()
 proxyS.connect(panda_config.dbhost, panda_config.dbpasswd, panda_config.dbuser, panda_config.dbname)
 
 
-optP = argparse.ArgumentParser(conflict_handler="resolve", description="Reassign jobs in a task")
-optP.add_argument("taskid", action="store", metavar="TASKID", help="taskID of the task")
-optP.add_argument(
+option_parser = argparse.ArgumentParser(conflict_handler="resolve", description="Reassign jobs in a task")
+option_parser.add_argument("taskid", action="store", metavar="TASKID", help="taskID of the task")
+option_parser.add_argument(
     "-m",
     dest="limit",
     type=int,
@@ -23,7 +24,7 @@ optP.add_argument(
     metavar="MIMUTES",
     help="time limit in minute",
 )
-optP.add_argument(
+option_parser.add_argument(
     "-9",
     action="store_const",
     const=True,
@@ -31,7 +32,7 @@ optP.add_argument(
     default=False,
     help="kill jobs before next heartbeat is coming",
 )
-optP.add_argument(
+option_parser.add_argument(
     "--keepUnmerged",
     action="store_const",
     const=True,
@@ -39,7 +40,7 @@ optP.add_argument(
     default=False,
     help="generate new jobs after kiliing old jobs, to keep unmerged events",
 )
-options = optP.parse_args()
+options = option_parser.parse_args()
 
 taskid = options.taskid
 
@@ -53,7 +54,7 @@ if options.forceKill:
 jobs = []
 jediJobs = []
 
-timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(minutes=options.limit)
+timeLimit = naive_utcnow() - datetime.timedelta(minutes=options.limit)
 varMap = {}
 varMap[":modificationTime"] = timeLimit
 varMap[":taskID"] = taskid
@@ -101,7 +102,7 @@ if len(jobs):
     iJob = 0
     while iJob < len(jobs):
         print(f"reassign  {str(jobs[iJob:iJob + nJob])}")
-        Client.reassignJobs(jobs[iJob : iJob + nJob])
+        Client.reassign_jobs(jobs[iJob : iJob + nJob])
         iJob += nJob
         time.sleep(10)
 
@@ -110,7 +111,7 @@ if len(jediJobs) != 0:
     iJob = 0
     while iJob < len(jediJobs):
         print(f"kill JEDI jobs {str(jediJobs[iJob:iJob + nJob])}")
-        Client.killJobs(jediJobs[iJob : iJob + nJob], codeV, keepUnmerged=options.keepUnmerged)
+        Client.kill_jobs(jediJobs[iJob : iJob + nJob], codeV, keep_unmerged=options.keepUnmerged)
         iJob += nJob
 
 print(f"\nreassigned {len(jobs + jediJobs)} jobs")
