@@ -1,14 +1,15 @@
 import datetime
 import time
 
-import pandaserver.userinterface.Client as Client
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 # password
 from pandaserver.config import panda_config
 from pandaserver.taskbuffer.OraDBProxy import DBProxy
+from pandaserver.userinterface import Client
 
 # time limit
-timeLimit = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - datetime.timedelta(hours=1)
+timeLimit = naive_utcnow() - datetime.timedelta(hours=1)
 
 # instantiate DB proxies
 proxyS = DBProxy()
@@ -33,6 +34,6 @@ while True:
     iJob = 0
     while iJob < len(jobs):
         print(f"reassignJobs({jobs[iJob:iJob + nJob]})")
-        Client.reassignJobs(jobs[iJob : iJob + nJob])
+        Client.reassign_jobs(jobs[iJob : iJob + nJob])
         iJob += nJob
         time.sleep(60)
