@@ -1,10 +1,10 @@
 import optparse
 import sys
 
-import pandaserver.userinterface.Client as Client
+from pandaserver.userinterface import Client
 
-optP = optparse.OptionParser(conflict_handler="resolve", usage="%prog [options] <PandaID>")
-optP.add_option(
+option_parser = optparse.OptionParser(conflict_handler="resolve", usage="%prog [options] <PandaID>")
+option_parser.add_option(
     "--on",
     action="store_const",
     const=True,
@@ -12,7 +12,7 @@ optP.add_option(
     default=False,
     help="turn the debug mode on",
 )
-optP.add_option(
+option_parser.add_option(
     "--off",
     action="store_const",
     const=True,
@@ -20,23 +20,19 @@ optP.add_option(
     default=False,
     help="turn the debug mode off",
 )
-options, args = optP.parse_args()
+options, args = option_parser.parse_args()
 
 
 if (options.modeOn and options.modeOff) or (not options.modeOn and not options.modeOff):
     print("ERROR: please set --on or --off")
     sys.exit(1)
 
-if options.modeOn:
-    s, o = Client.setDebugMode(args[0], True)
-else:
-    s, o = Client.setDebugMode(args[0], False)
+job_id = int(args[0])
 
-if o == "Succeeded":
-    print(o)
+if options.modeOn:
+    status, output = Client.set_debug_mode(job_id, True)
 else:
-    print("ERROR:", o)
-if s != 0:
-    print("ERROR: communication failure to the panda server")
-    sys.exit(1)
+    status, output = Client.set_debug_mode(job_id, False)
+
+print(f"status: {status}, output: {output}")
 sys.exit(0)
