@@ -13,6 +13,10 @@ import tempfile
 import requests
 from pandacommon.pandautils.net_utils import replace_hostname_in_url_randomly
 
+from pandaserver.api.v1.http_client import HttpClient as HttpClientV1
+from pandaserver.api.v1.http_client import api_url_ssl as api_url_ssl_v1
+from pandaserver.taskbuffer.JobUtils import dump_jobs_json
+
 # PanDA server configuration
 baseURL = os.environ.get("PANDA_URL", "http://pandaserver.cern.ch:25080/server/panda")
 baseURLSSL = os.environ.get("PANDA_URL_SSL", "https://pandaserver.cern.ch:25443/server/panda")
@@ -61,6 +65,9 @@ class HttpClient:
         self.oidc = os.getenv("PANDA_AUTH") == "oidc"
         self.auth_vo = os.getenv("PANDA_AUTH_VO") if self.oidc else None
         self.id_token = os.getenv("PANDA_AUTH_ID_TOKEN") if self.oidc else None
+        if self.id_token and self.id_token.startswith("file:"):
+            with open(self.id_token[5:], "r") as f:
+                self.id_token = f.read().strip()
 
     def _x509(self):
         # retrieve the X509_USER_PROXY from the environment variables and check if it is readable
@@ -180,14 +187,12 @@ Client API
 """
 
 
-def submitJobs(jobs, toPending=False):
+def submit_jobs(jobs):
     """
     Submit jobs
 
     args:
         jobs: the list of JobSpecs
-        toPending: set True if jobs need to be pending state for the
-                   two-staged submission mechanism
     returns:
         status code
               0: communication succeeded to the panda server
@@ -196,69 +201,48 @@ def submitJobs(jobs, toPending=False):
               True: request is processed
               False: not processed
     """
-    # set hostname
+    # set hostname to jobs
     hostname = socket.getfqdn()
     for job in jobs:
         job.creationHost = hostname
-    # serialize
-    str_jobs = pickle_dumps(jobs)
 
-    http_client = HttpClient()
+    # serialize the jobs to json
+    jobs = dump_jobs_json(jobs)
+
+    http_client = HttpClientV1()
+
+    url = f"{api_url_ssl_v1}/job/submit"
+    data = {"jobs": jobs}
 
-    url = f"{baseURLSSL}/submitJobs"
-    data = {"jobs": str_jobs}
-    if toPending:
-        data["toPending"] = True
     status, output = http_client.post(url, data)
-    if status != 0:
-        print(output)
-        return status, output
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        err_type, err_value, _ = sys.exc_info()
-        err_str = f"ERROR submitJobs : {err_type} {err_value}"
-        print(err_str)
-        return EC_Failed, f"{output}\n{err_str}"
+    return status, output
 
 
-def getJobStatus(panda_ids):
+def get_job_status(job_ids):
     """
     Get job status
 
     args:
-        ids: the list of PandaIDs
-        use_json: using json instead of pickle
+        job_ids: the list of PandaIDs
     returns:
         status code
               0: communication succeeded to the panda server
               255: communication failure
         the list of JobSpecs (or Nones for non-existing PandaIDs)
     """
-    # Serialize the panda IDs
-    str_ids = json.dumps(panda_ids)
-
-    http_client = HttpClient()
-    http_client.use_json = True
-
-    # Execute
-    url = f"{baseURL}/getJobStatus"
-    data = {"ids": str_ids}
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/pilot/get_job_status"
+    data = {"job_ids": job_ids}
     status, output = http_client.post(url, data)
-    try:
-        return status, json.loads(output)
-    except Exception as e:
-        err_str = f"ERROR getJobStatus: {str(e)}"
-        print(err_str)
-        return EC_Failed, f"{output}\n{err_str}"
+
+    return status, output
 
 
-def killJobs(
-    ids,
+def kill_jobs(
+    job_ids,
     code=None,
-    useMailAsID=False,
-    keepUnmerged=False,
-    jobSubStatus=None,
+    keep_unmerged=False,
+    job_sub_status=None,
 ):
     """
     Kill jobs. Normal users can kill only their own jobs.
@@ -267,7 +251,7 @@ def killJobs(
     Set code=9 if running jobs need to be killed immediately.
 
        args:
-           ids: the list of PandaIDs
+           job_ids: the list of PandaIDs
            code: specify why the jobs are killed
                  2: expire
                  3: aborted
@@ -278,47 +262,41 @@ def killJobs(
                  10: fast re-brokerage on overloaded PQs
                  50: kill by JEDI
                  91: kill user jobs with prod role
-           useMailAsID: obsolete
-           keepUnmerged: set True not to cancel unmerged jobs when pmerge is killed.
-           jobSubStatus: set job sub status if any
+           keep_unmerged: set True not to cancel unmerged jobs when pmerge is killed.
+           job_sub_status: set job sub status if any
        returns:
            status code
                  0: communication succeeded to the panda server
                  255: communication failure
            the list of clouds (or Nones if tasks are not yet assigned)
     """
-    # serialize
-    str_panda_ids = pickle_dumps(ids)
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
+
+    url = f"{api_url_ssl_v1}/job/kill"
+    data = {"job_ids": job_ids}
+
+    if code:
+        data["code"] = code
+
+    kill_options = []
+    if keep_unmerged == True:
+        kill_options.append("keepUnmerged")
+    if job_sub_status:
+        kill_options.append(f"jobSubStatus={job_sub_status}")
+    if kill_options:
+        data["kill_options"] = kill_options
 
-    # execute
-    url = f"{baseURLSSL}/killJobs"
-    data = {"ids": str_panda_ids, "code": code, "useMailAsID": useMailAsID}
-    kill_options = ""
-    if keepUnmerged:
-        kill_options += "keepUnmerged,"
-    if jobSubStatus is not None:
-        kill_options += f"jobSubStatus={jobSubStatus},"
-    data["killOpts"] = kill_options[:-1]
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR killJobs : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
+    return status, output
 
 
-def reassignJobs(ids, forPending=False, firstSubmission=None):
+def reassign_jobs(job_ids):
     """
-    Triggers reassignment of jobs. This is not effective if jobs were preassigned to sites before being submitted.
+    Triggers reassignment of jobs.
 
     args:
         ids: the list of taskIDs
-        forPending: set True if pending jobs are reassigned
-        firstSubmission: set True if first jobs are submitted for a task, or False if not
     returns:
         status code
               0: communication succeeded to the panda server
@@ -328,37 +306,68 @@ def reassignJobs(ids, forPending=False, firstSubmission=None):
               False: not processed
 
     """
-    # serialize
-    str_task_ids = pickle_dumps(ids)
+    http_client = HttpClientV1()
 
-    http_client = HttpClient()
-
-    # execute
-    url = f"{baseURLSSL}/reassignJobs"
-    data = {"ids": str_task_ids}
-    if forPending:
-        data["forPending"] = True
-    if firstSubmission is not None:
-        data["firstSubmission"] = firstSubmission
+    url = f"{api_url_ssl_v1}/job/reassign"
+    data = {"job_ids": job_ids}
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR reassignJobs : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"stat={status} err={output} {error_str}"
+    return status, output
 
 
+def job_stats_by_cloud(job_type=None):
+    """
+    Get job statistics by cloud. Used by panglia monitor in TRIUMF
+
+    args:
+        job_type: string with the type of jobs to consider
+            analysis: analysis jobs
+            production: production jobs
+    returns:
+        status code
+              0: communication succeeded to the panda server
+              255: communication failure
+        map of the number jobs per job status in each site
+
+    """
+    if job_type not in [None, "analysis", "production"]:
+        print("Invalid job type, must be one of [None, 'analysis', 'production'']")
+        return EC_Failed, "Invalid job type"
+
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/statistics/job_stats_by_cloud"
+
+    data = {}
+    if job_type:
+        data["type"] = job_type
+
+    status, output = http_client.get(url, data)
+    if status != 0 or not output.get("success"):
+        print(f"Failed to retrieve job_stats_by_cloud for {job_type}. Status: {status}, Output: {output}")
+        return status, output
+
+    statistics = output["data"]
+    ret = {}
+    for cloud, values in statistics.items():
+        if cloud not in ret:
+            # append cloud values (make a shallow copy to avoid mutating original)
+            ret[cloud] = dict(values)
+        else:
+            # sum statistics per status
+            for job_status, count in values.items():
+                ret[cloud][job_status] = ret[cloud].get(job_status, 0) + count
+
+    return 0, ret
+
+
+# alias the old name to the new function for backwards compatibility
 def getJobStatistics(sourcetype=None):
+    return job_stats_by_cloud(sourcetype)
+
+
+def production_job_stats_by_cloud_and_processing_type():
     """
-    Get job statistics
+    Get job statistics by cloud and processing type. Used by panglia monitor in TRIUMF
 
-    args:
-        sourcetype: type of jobs
-            all: all jobs
-            analysis: analysis jobs
-            production: production jobs
     returns:
         status code
               0: communication succeeded to the panda server
@@ -367,172 +376,50 @@ def getJobStatistics(sourcetype=None):
 
     """
 
-    http_client = HttpClient()
-    # execute
-    ret = {}
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/statistics/production_job_stats_by_cloud_and_processing_type"
+    status, output = http_client.get(url, {})
 
-    url = f"{baseURL}/getJobStatistics"
-    data = {}
-    if sourcetype is not None:
-        data["sourcetype"] = sourcetype
-    status, output = http_client.get(url, data)
-    try:
-        tmp_return = status, pickle_loads(output)
-        if status != 0:
-            return tmp_return
-    except Exception:
-        print(output)
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR getJobStatistics : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
-    # gather
-    for tmpCloud in tmp_return[1]:
-        tmpVal = tmp_return[1][tmpCloud]
-        if tmpCloud not in ret:
-            # append cloud values
-            ret[tmpCloud] = tmpVal
-        else:
-            # sum statistics
-            for tmpStatus in tmpVal:
-                tmpCount = tmpVal[tmpStatus]
-                if tmpStatus in ret[tmpCloud]:
-                    ret[tmpCloud][tmpStatus] += tmpCount
-                else:
-                    ret[tmpCloud][tmpStatus] = tmpCount
+    if status != 0 or not output.get("success"):
+        print(f"Failed to retrieve production_job_stats_by_cloud_and_processing_type. Status: {status}, Output: {output}")
+        return status, output
 
-    return 0, ret
+    statistics = output["data"]
+    aggregated = {}
+
+    for cloud, processing_type_map in statistics.items():
+        # ensure we work with a shallow copy of the incoming mappings
+        processing_type_map = dict(processing_type_map)
+
+        if cloud not in aggregated:
+            # copy nested structures to avoid mutating the original
+            aggregated[cloud] = {processing_type: dict(status_map) for processing_type, status_map in processing_type_map.items()}
+            continue
+
+        # merge into existing cloud entry
+        for processing_type, status_map in processing_type_map.items():
+            status_map = dict(status_map)
+            if processing_type not in aggregated[cloud]:
+                aggregated[cloud][processing_type] = status_map
+                continue
+
+            # sum counts per status
+            for status, count in status_map.items():
+                aggregated[cloud][processing_type][status] = aggregated[cloud][processing_type].get(status, 0) + count
+    return 0, aggregated
 
 
+# alias the old name to the new function for backwards compatibility
 def getJobStatisticsForBamboo(useMorePG=False):
+    return production_job_stats_by_cloud_and_processing_type()
+
+
+def job_stats_by_site_and_resource_type(time_window=None):
     """
-    Get job statistics for Bamboo (used by TRIUMF panglia monitoring)
+    Get job statistics per site and resource. Used by panglia monitor in TRIUMF
 
     args:
-        useMorePG: set True if fine-grained classification is required
-    returns:
-        status code
-              0: communication succeeded to the panda server
-              255: communication failure
-        map of the number jobs per job status in each site
-
-    """
-
-    http_client = HttpClient()
-    # execute
-    ret = {}
-    url = f"{baseURL}/getJobStatisticsForBamboo"
-    data = {}
-    if useMorePG is not False:
-        data["useMorePG"] = useMorePG
-    status, output = http_client.get(url, data)
-    try:
-        tmp_return = status, pickle_loads(output)
-        if status != 0:
-            return tmp_return
-    except Exception:
-        print(output)
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR getJobStatisticsForBamboo : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
-    # gather
-    for tmpCloud in tmp_return[1]:
-        tmpMap = tmp_return[1][tmpCloud]
-        if tmpCloud not in ret:
-            # append cloud values
-            ret[tmpCloud] = tmpMap
-        else:
-            # sum statistics
-            for tmpPType in tmpMap:
-                tmpVal = tmpMap[tmpPType]
-                if tmpPType not in ret[tmpCloud]:
-                    ret[tmpCloud][tmpPType] = tmpVal
-                else:
-                    for tmpStatus in tmpVal:
-                        tmpCount = tmpVal[tmpStatus]
-                        if tmpStatus in ret[tmpCloud][tmpPType]:
-                            ret[tmpCloud][tmpPType][tmpStatus] += tmpCount
-                        else:
-                            ret[tmpCloud][tmpPType][tmpStatus] = tmpCount
-    return 0, ret
-
-
-def getJobStatisticsPerSite(
-    predefined=False,
-    workingGroup="",
-    countryGroup="",
-    jobType="",
-    minPriority=None,
-    readArchived=None,
-):
-    """
-    Get job statistics with job attributes
-
-    args:
-        predefined: get jobs which are assigned to sites before being submitted
-        workingGroup: comma-separated list of workingGroups
-        countryGroup: comma-separated list of countryGroups
-        jobType: type of jobs
-            all: all jobs
-            analysis: analysis jobs
-            production: production jobs
-        minPriority: get jobs with higher priorities than this value
-        readArchived: get jobs with finished/failed/cancelled state in addition
-    returns:
-        status code
-              0: communication succeeded to the panda server
-              255: communication failure
-        map of the number jobs per job status in each site
-
-    """
-
-    http_client = HttpClient()
-    # execute
-    ret = {}
-    url = f"{baseURL}/getJobStatisticsPerSite"
-    data = {"predefined": predefined}
-    if workingGroup not in ["", None]:
-        data["workingGroup"] = workingGroup
-    if countryGroup not in ["", None]:
-        data["countryGroup"] = countryGroup
-    if jobType not in ["", None]:
-        data["jobType"] = jobType
-    if minPriority not in ["", None]:
-        data["minPriority"] = minPriority
-    if readArchived not in ["", None]:
-        data["readArchived"] = readArchived
-    status, output = http_client.get(url, data)
-    try:
-        tmp_return = status, pickle_loads(output)
-        if status != 0:
-            return tmp_return
-    except Exception:
-        print(output)
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR getJobStatisticsPerSite : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
-
-    # gather
-    for tmp_site, tmp_value in tmp_return[1].items():
-        if tmp_site not in ret:
-            # append site values
-            ret[tmp_site] = tmp_value
-        else:
-            # sum statistics
-            for tmp_status, tmp_count in tmp_value.items():
-                ret[tmp_site][tmp_status] = ret[tmp_site].get(tmp_status, 0) + tmp_count
-
-    return 0, ret
-
-
-def getJobStatisticsPerSiteResource(timeWindow=None):
-    """
-    Get job statistics per site and resource. This is used by panglia (TRIUMF monitoring)
-
-    args:
-       timeWindow: to count number of jobs that finish/failed/cancelled for last N minutes. 12*60 by default
+       time_window: to count number of jobs that finish/failed/cancelled for last N minutes. 12*60 by default
     returns:
         status code
               0: communication succeeded to the panda server
@@ -541,24 +428,27 @@ def getJobStatisticsPerSiteResource(timeWindow=None):
 
     """
 
-    http_client = HttpClient()
-    # execute
-    url = f"{baseURL}/getJobStatisticsPerSiteResource"
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/statistics/job_stats_by_site_and_resource_type"
     data = {}
-    if timeWindow is not None:
-        data["timeWindow"] = timeWindow
+    if time_window:
+        data["time_window"] = time_window
+
     status, output = http_client.get(url, data)
-    try:
-        return status, json.loads(output)
-    except Exception:
-        print(output)
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR getJobStatisticsPerSiteResource : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
+
+    if status != 0 or not output.get("success"):
+        print(f"Failed to retrieve job_stats_by_site_and_resource_type. Status: {status}, Output: {output}")
+        return status, output
+
+    return 0, output.get("data")
 
 
-def get_job_statistics_per_site_label_resource(time_window=None):
+# alias the old name to the new function for backwards compatibility
+def getJobStatisticsPerSiteResource(timeWindow=None):
+    return job_stats_by_site_and_resource_type(timeWindow)
+
+
+def job_stats_by_site_share_and_resource_type(time_window=None):
     """
     Get job statistics per site, label, and resource
 
@@ -572,54 +462,98 @@ def get_job_statistics_per_site_label_resource(time_window=None):
 
     """
 
-    http_client = HttpClient()
-    # execute
-    url = f"{baseURL}/get_job_statistics_per_site_label_resource"
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/statistics/job_stats_by_site_share_and_resource_type"
     data = {}
-    if time_window is not None:
+    if time_window:
         data["time_window"] = time_window
+
     status, output = http_client.get(url, data)
-    try:
-        return status, json.loads(output)
-    except Exception as e:
-        print(output)
-        error_str = f"ERROR get_job_statistics_per_site_label_resource : {str(e)}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
+
+    if status != 0 or not output.get("success"):
+        print(f"Failed to retrieve job_stats_by_site_share_and_resource_type. Status: {status}, Output: {output}")
+        return status, output
+
+    return 0, output.get("data")
 
 
-def insertSandboxFileInfo(userName, fileName, fileSize, checkSum):
+# alias the old name to the new function for backwards compatibility
+def get_job_statistics_per_site_label_resource(time_window=None):
+    return job_stats_by_site_share_and_resource_type(time_window)
+
+
+def get_site_specs(site_type=None):
     """
-    Insert information of input sandbox
+    Get list of site specifications. Used by panglia monitor in TRIUMF
 
     args:
-        userName: the name of the user
-        fileName: the file name
-        fileSize: the file size
-        fileSize: md5sum of the file
+        site_type: type of sites
+            all: all sites
+            None: defaults to analysis sites
+            analysis: analysis sites
+            production: production sites
+            unified: unified sites
+    returns:
+        status code
+              0: communication succeeded to the panda server
+              255: communication failure
+        map of site and attributes
+
+    """
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/metaconfig/get_site_specs"
+    if site_type not in [None, "all", "analysis", "production", "unified"]:
+        return EC_Failed, "Invalid site type"
+
+    data = {}
+    if site_type:
+        data = {"type": site_type}
+
+    status, output = http_client.get(url, data)
+
+    if status != 0 or not output.get("success"):
+        print(f"Failed to retrieve get_site_specs. Status: {status}, Output: {output}")
+        return status, output
+
+    return 0, output.get("data")
+
+
+# alias the old name to the new function for backwards compatibility
+def getSiteSpecs(siteType=None):
+    return get_site_specs(siteType)
+
+
+def register_cache_file(user_name: str, file_name: str, file_size: int, checksum: str):
+    """
+    Register information about the input sandbox that is being stored in PanDA cache
+
+    args:
+        user_name: the name of the user
+        file_name: the file name
+        file_size: the file size
+        checksum: md5sum of the file
     returns:
         status code
               0: communication succeeded to the panda server
               else: communication failure
 
     """
+    http_client = HttpClientV1()
 
-    http_client = HttpClient()
+    url = f"{api_url_ssl_v1}/file_server/register_cache_file"
 
-    # execute
-    url = f"{baseURLSSL}/insertSandboxFileInfo"
     data = {
-        "userName": userName,
-        "fileName": fileName,
-        "fileSize": fileSize,
-        "checkSum": checkSum,
+        "user_name": user_name,
+        "file_name": file_name,
+        "file_size": file_size,
+        "checksum": str(checksum),
     }
     return http_client.post(url, data)
 
 
-def putFile(file):
+def put_file(file):
     """
-    Upload input sandbox
+    Upload input sandbox to PanDA cache
 
     args:
         file: the file name
@@ -630,69 +564,21 @@ def putFile(file):
 
     """
 
-    http_client = HttpClient()
-
-    # execute
-    url = f"{baseURLSSL}/putFile"
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/file_server/upload_cache_file"
     data = {"file": file}
     return http_client.post_files(url, data)
 
 
-# delete file (obsolete)
-# TODO: is this really obsolete? I think it's used in panda cache
-def deleteFile(file):
-    http_client = HttpClient()
-
-    # execute
-    url = f"{baseURLSSL}/deleteFile"
-    data = {"file": file}
+def touch_file(source_url, file_name):
+    http_client = HttpClientV1()
+    # Note the special construction of the URL here, since it is not going through the api_url_ssl_v1,
+    # but directly to the source_url pointing at the concrete instance provided
+    url = f"{source_url}/api/v1/file_server/touch_cache_file"
+    data = {"file_name": file_name}
     return http_client.post(url, data)
 
 
-# touch file (obsolete)
-# TODO: is this really obsolete? I think it's used in panda cache
-def touchFile(source_url, filename):
-    http_client = HttpClient()
-
-    # execute
-    url = f"{source_url}/server/panda/touchFile"
-    data = {"filename": filename}
-    return http_client.post(url, data)
-
-
-def getSiteSpecs(siteType=None):
-    """
-    Get list of site specifications
-
-    args:
-        siteType: type of sites
-            None: all sites
-            analysis: analysis sites
-            production: production sites
-    returns:
-        status code
-              0: communication succeeded to the panda server
-              255: communication failure
-        map of site and attributes
-
-    """
-
-    http_client = HttpClient()
-    # execute
-    url = f"{baseURL}/getSiteSpecs"
-    data = {}
-    if siteType is not None:
-        data = {"siteType": siteType}
-    status, output = http_client.get(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value, _ = sys.exc_info()
-        error_str = f"ERROR getSiteSpecs : {error_type} {error_value}"
-        print(error_str)
-        return EC_Failed, f"{output}\n{error_str}"
-
-
 def insertTaskParams(taskParams):
     """
     Insert task parameters
@@ -724,12 +610,12 @@ def insertTaskParams(taskParams):
         return EC_Failed, f"{output}\n{error_str}"
 
 
-def killTask(jediTaskID, broadcast=False):
+def kill_task(task_id, broadcast=False):
     """
     Kill a task
 
     args:
-        jediTaskID: jediTaskID of the task to be killed
+        task_id: task ID of the task to be killed
         broadcast: True to push the message to the pilot subscribing the MB
     returns:
         status code
@@ -745,28 +631,24 @@ def killTask(jediTaskID, broadcast=False):
             101: irrelevant taskID
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
+
+    url = f"{api_url_ssl_v1}/task/kill"
+    data = {"task_id": task_id, "broadcast": broadcast}
 
-    # execute
-    url = f"{baseURLSSL}/killTask"
-    data = {"jediTaskID": jediTaskID, "properErrorCode": True, "broadcast": broadcast}
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value = sys.exc_info()[:2]
-        error_str = f"ERROR killTask : {error_type} {error_value}"
-        return EC_Failed, f"{output}\n{error_str}"
+
+    return status, output
 
 
-def finishTask(jediTaskID, soft=False, broadcast=False):
+def finish_task(task_id, soft=False, broadcast=False):
     """
     Finish a task
 
     args:
         jediTaskID: jediTaskID of the task to be finished
         soft: If True, new jobs are not generated and the task is
-              finihsed once all remaining jobs are done.
+              finished once all remaining jobs are done.
               If False, all remaining jobs are killed and then the
               task is finished
         broadcast: True to push the message to the pilot subscribing the MB
@@ -783,21 +665,14 @@ def finishTask(jediTaskID, soft=False, broadcast=False):
             100: non SSL connection
             101: irrelevant taskID
     """
+    http_client = HttpClientV1()
 
-    http_client = HttpClient()
+    url = f"{api_url_ssl_v1}/task/finish"
+    data = {"task_id": task_id, "soft": soft, "broadcast": broadcast}
 
-    # execute
-    url = f"{baseURLSSL}/finishTask"
-    data = {"jediTaskID": jediTaskID, "properErrorCode": True, "broadcast": broadcast}
-    if soft:
-        data["soft"] = True
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value = sys.exc_info()[:2]
-        error_str = f"ERROR finishTask : {error_type} {error_value}"
-        return EC_Failed, f"{output}\n{error_str}"
+
+    return status, output
 
 
 def reassignTaskToSite(jediTaskID, site, mode=None):
@@ -917,13 +792,13 @@ def reassignTaskToNucleus(jediTaskID, nucleus, mode=None):
         return EC_Failed, f"{output}\n{error_str}"
 
 
-def uploadLog(logStr, logFileName):
+def uploadLog(log_string, log_file_name):
     """
     Upload log
 
     args:
         logStr: log message
-        logFileName: name of log file
+        log_file_name: name of log file
     returns:
         status code
               0: communication succeeded to the panda server
@@ -931,21 +806,22 @@ def uploadLog(logStr, logFileName):
 
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
 
     # write log to a tmp file
     fh = tempfile.NamedTemporaryFile(delete=False)
     gfh = gzip.open(fh.name, mode="wb")
     if sys.version_info[0] >= 3:
-        logStr = logStr.encode("utf-8")
-    gfh.write(logStr)
+        log_string = log_string.encode("utf-8")
+    gfh.write(log_string)
     gfh.close()
     # execute
-    url = f"{baseURLSSL}/uploadLog"
+    url = f"{api_url_ssl_v1}/file_server/upload_jedi_log"
+
     # sometimes the destination file name (=logFileName) comes as an integer (e.g. a JEDI task ID) and it needs to be converted to a string
-    logFileName = str(logFileName)
-    data = {"file": (logFileName, fh.name)}
-    return_value = http_client.post_files(url, data)
+    log_file_name = str(log_file_name)
+    data = {"file": (log_file_name, fh.name)}
+    return_value = http_client.post_files(url, data, encoding="gzip")
     os.unlink(fh.name)
     return return_value
 
@@ -981,13 +857,13 @@ def changeTaskPriority(jediTaskID, newPriority):
         return EC_Failed, f"{output}\n{error_str}"
 
 
-def setDebugMode(pandaID, modeOn):
+def set_debug_mode(job_id, mode):
     """
     Turn debug mode for a job on/off
 
     args:
-        pandaID: PandaID of the job
-        modeOn: True to turn it on. Oppositely, False
+        job_id: job_id of the job
+        mode: True to turn it on. Oppositely, False
     returns:
         status code
               0: communication succeeded to the panda server
@@ -995,22 +871,24 @@ def setDebugMode(pandaID, modeOn):
         error message
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
 
-    # execute
-    url = f"{baseURLSSL}/setDebugMode"
-    data = {"pandaID": pandaID, "modeOn": modeOn}
-    return http_client.post(url, data)
+    url = f"{api_url_ssl_v1}/job/set_debug_mode"
+    data = {"job_id": job_id, "mode": mode}
+
+    status, output = http_client.post(url, data)
+
+    return status, output
 
 
-def retryTask(jediTaskID, noChildRetry=False, discardEvents=False, disable_staging_mode=False, keep_gshare_priority=False):
+def retry_task(task_id, no_child_retry=False, discard_events=False, disable_staging_mode=False, keep_gshare_priority=False):
     """
     Retry a task
 
     args:
-        jediTaskID: jediTaskID of the task to retry
-        noChildRetry: True not to retry child tasks
-        discardEvents: discard events
+        task_id: jediTaskID of the task to retry
+        no_child_retry: True not to retry child tasks
+        discard_events: discard events
         disable_staging_mode: disable staging mode
         keep_gshare_priority: keep current gshare and priority
     returns:
@@ -1027,29 +905,24 @@ def retryTask(jediTaskID, noChildRetry=False, discardEvents=False, disable_stagi
             101: irrelevant taskID
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/task/retry"
 
-    # execute
-    url = f"{baseURLSSL}/retryTask"
-    data = {"jediTaskID": jediTaskID, "properErrorCode": True}
-    if noChildRetry:
-        data["noChildRetry"] = True
-    if discardEvents:
-        data["discardEvents"] = True
+    data = {"task_id": task_id}
+    if no_child_retry:
+        data["no_child_retry"] = True
+    if discard_events:
+        data["discard_events"] = True
     if disable_staging_mode:
         data["disable_staging_mode"] = True
     if keep_gshare_priority:
         data["keep_gshare_priority"] = True
+
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value = sys.exc_info()[:2]
-        error_str = f"ERROR retryTask : {error_type} {error_value}"
-        return EC_Failed, f"{output}\n{error_str}"
+    return status, output
 
 
-def reloadInput(jediTaskID):
+def reload_input(task_id):
     """
     Reload the input for a task
 
@@ -1068,19 +941,14 @@ def reloadInput(jediTaskID):
             100: non SSL connection
             101: irrelevant taskID
     """
+    http_client = HttpClientV1()
 
-    http_client = HttpClient()
+    url = f"{api_url_ssl_v1}/task/reload_input"
+    data = {"task_id": task_id}
 
-    # execute
-    url = f"{baseURLSSL}/reloadInput"
-    data = {"jediTaskID": jediTaskID}
     status, output = http_client.post(url, data)
-    try:
-        return status, pickle_loads(output)
-    except Exception:
-        error_type, error_value = sys.exc_info()[:2]
-        error_str = f"ERROR reloadInput : {error_type} {error_value}"
-        return EC_Failed, f"{output}\n{error_str}"
+
+    return status, output
 
 
 def changeTaskWalltime(jediTaskID, wallTime):
@@ -1731,7 +1599,7 @@ def sweepPQ(panda_queue, status_list, ce_list, submission_host_list):
         return EC_Failed, f"{output}\n{error_str}"
 
 
-def send_command_to_job(panda_id, com):
+def send_command_to_job(panda_id, command):
     """
     Send a command to a job
 
@@ -1747,21 +1615,16 @@ def send_command_to_job(panda_id, com):
               True: the command received
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/job/set_command"
+    data = {"job_id": panda_id, "command": command}
 
-    # execute
-    url = f"{baseURLSSL}/send_command_to_job"
-    data = {"panda_id": panda_id, "com": com}
     status, output = http_client.post(url, data)
 
-    try:
-        return status, json.loads(output)
-    except Exception as e:
-        error_str = f"ERROR send_command_to_job : {str(e)}"
-        return EC_Failed, f"{output}\n{error_str}"
+    return status, output
 
 
-def get_ban_users():
+def get_banned_users():
     """
     Get list of banned users
 
@@ -1773,19 +1636,21 @@ def get_ban_users():
 
     """
 
-    http_client = HttpClient()
+    http_client = HttpClientV1()
+    url = f"{api_url_ssl_v1}/metaconfig/get_banned_users"
 
-    # execute
-    url = f"{baseURL}/get_ban_users"
-    output = None
-    try:
-        status, output = http_client.post(url, {})
-        if status == 0:
-            return json.loads(output)
-        else:
-            return False, f"bad response: {output}"
-    except Exception:
-        return False, f"broken response: {output}"
+    status, output = http_client.get(url, {})
+    if status != 0:
+        return False, f"bad response: {output}"
+
+    success = output["success"]
+    message = output.get("message", "")
+    data = output.get("data", None)
+
+    if success:
+        return True, data
+    else:
+        return False, f"error message: {message}"
 
 
 def release_task(jedi_task_id):
