@@ -12,6 +12,7 @@ import traceback
 
 from pandacommon.pandalogger.LogWrapper import LogWrapper
 from pandacommon.pandalogger.PandaLogger import PandaLogger
+from pandacommon.pandautils.PandaUtils import naive_utcnow
 
 import pandaserver.jobdispatcher.Protocol as Protocol
 from pandaserver.brokerage.SiteMapper import SiteMapper
@@ -20,6 +21,7 @@ from pandaserver.dataservice.ddm import rucioAPI
 from pandaserver.srvcore import CoreUtils
 from pandaserver.srvcore.CoreUtils import clean_user_id, resolve_bool
 from pandaserver.taskbuffer import JobUtils, PrioUtil
+from pandaserver.taskbuffer.JediTaskSpec import JediTaskSpec
 from pandaserver.taskbuffer.WrappedPickle import WrappedPickle
 
 try:
@@ -370,8 +372,12 @@ class UserIF:
         return ret
 
     # reload input
-    def reloadInput(self, jediTaskID, user, prodRole):
-        ret = self.taskBuffer.sendCommandTaskPanda(jediTaskID, user, prodRole, "incexec", comComment="{}", properErrorCode=True)
+    def reloadInput(self, jediTaskID, user, prodRole, ignore_hard_exhausted):
+        if not prodRole and ignore_hard_exhausted:
+            ignore_hard_exhausted = False
+        com_qualifier = JediTaskSpec.get_retry_command_qualifiers(ignore_hard_exhausted=ignore_hard_exhausted)
+        com_comment = json.dumps([{}, com_qualifier])
+        ret = self.taskBuffer.sendCommandTaskPanda(jediTaskID, user, prodRole, "incexec", comComment=com_comment, properErrorCode=True)
         return ret
 
     # retry task
@@ -386,6 +392,7 @@ class UserIF:
         discardEvents,
         disable_staging_mode,
         keep_gshare_priority,
+        ignore_hard_exhausted,
     ):
         # retry with new params
         if newParams is not None:
@@ -413,16 +420,12 @@ class UserIF:
                 err_type, err_value = sys.exc_info()[:2]
                 ret = 1, f"server error with {err_type}:{err_value}"
         else:
-            com_qualifier = ""
-            for com_key, com_param in [
-                ("sole", noChildRetry),
-                ("discard", discardEvents),
-                ("staged", disable_staging_mode),
-                ("keep", keep_gshare_priority),
-            ]:
-                if com_param:
-                    com_qualifier += f"{com_key} "
-            com_qualifier = com_qualifier.strip()
+            if not prodRole and ignore_hard_exhausted:
+                ignore_hard_exhausted = False
+            com_qualifier = JediTaskSpec.get_retry_command_qualifiers(
+                noChildRetry, discardEvents, disable_staging_mode, keep_gshare_priority, ignore_hard_exhausted
+            )
+            com_qualifier = " ".join(com_qualifier)
             # normal retry
             ret = self.taskBuffer.sendCommandTaskPanda(
                 jediTaskID,
@@ -940,7 +943,7 @@ def getFullJobStatus(req, ids):
 
 # insert task params
 def insertTaskParams(req, taskParams=None, properErrorCode=None, parent_tid=None):
-    tmp_log = LogWrapper(_logger, f"insertTaskParams-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"insertTaskParams-{naive_utcnow().isoformat('/')}")
     tmp_log.debug("start")
     properErrorCode = resolve_true(properErrorCode)
 
@@ -1010,12 +1013,14 @@ def retryTask(
     discardEvents=None,
     disable_staging_mode=None,
     keep_gshare_priority=None,
+    ignore_hard_exhausted=None,
 ):
     properErrorCode = resolve_true(properErrorCode)
     noChildRetry = resolve_true(noChildRetry)
     discardEvents = resolve_true(discardEvents)
     disable_staging_mode = resolve_true(disable_staging_mode)
     keep_gshare_priority = resolve_true(keep_gshare_priority)
+    ignore_hard_exhausted = resolve_true(ignore_hard_exhausted)
 
     # check security
     if not isSecure(req):
@@ -1045,6 +1050,7 @@ def retryTask(
         discardEvents,
         disable_staging_mode,
         keep_gshare_priority,
+        ignore_hard_exhausted,
     )
     return WrappedPickle.dumps(ret)
 
@@ -1112,7 +1118,7 @@ def finishTask(req, jediTaskID=None, properErrorCode=None, soft=None, broadcast=
 
 
 # reload input
-def reloadInput(req, jediTaskID, properErrorCode=None):
+def reloadInput(req, jediTaskID, properErrorCode=None, ignore_hard_exhausted=None):
     properErrorCode = resolve_true(properErrorCode)
     # check security
     if not isSecure(req):
@@ -1131,8 +1137,8 @@ def reloadInput(req, jediTaskID, properErrorCode=None):
     except Exception:
         error_code = CODE_LOGIC if properErrorCode else False
         return WrappedPickle.dumps((error_code, MESSAGE_TASK_ID))
-
-    ret = userIF.reloadInput(jediTaskID, user, is_production_role)
+    ignore_hard_exhausted = resolve_true(ignore_hard_exhausted)
+    ret = userIF.reloadInput(jediTaskID, user, is_production_role, ignore_hard_exhausted)
     return WrappedPickle.dumps(ret)
 
 
@@ -1460,7 +1466,12 @@ def reassignShare(req, jedi_task_ids_pickle, share, reassign_running):
         return WrappedPickle.dumps((False, MESSAGE_PROD_ROLE))
 
     jedi_task_ids = WrappedPickle.loads(jedi_task_ids_pickle)
-    _logger.debug(f"reassignShare: jedi_task_ids: {jedi_task_ids}, share: {share}, reassign_running: {reassign_running}")
+    _logger.debug(f"reassignShare: jedi_task_ids: {jedi_task_ids}, share: {share}, reassign_running: {reassign_running} (type {type(reassign_running)})")
+
+    if isinstance(reassign_running, str) and "true" in reassign_running.lower():
+        reassign_running = True
+    else:
+        reassign_running = False
 
     if not ((isinstance(jedi_task_ids, list) or (isinstance(jedi_task_ids, tuple)) and isinstance(share, str))):
         return WrappedPickle.dumps((False, "jedi_task_ids must be tuple/list and share must be string"))
@@ -1489,7 +1500,7 @@ def updateWorkers(req, harvesterID, workers):
     # hostname
     host = req.get_remote_host()
     return_value = None
-    tStart = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+    tStart = naive_utcnow()
     # convert
     try:
         data = json.loads(workers)
@@ -1498,7 +1509,7 @@ def updateWorkers(req, harvesterID, workers):
     # update
     if return_value is None:
         return_value = userIF.updateWorkers(user, host, harvesterID, data)
-    tDelta = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - tStart
+    tDelta = naive_utcnow() - tStart
     _logger.debug(f"updateWorkers {harvesterID} took {tDelta.seconds}.{tDelta.microseconds // 1000:03d} sec")
 
     return return_value
@@ -1514,7 +1525,7 @@ def updateServiceMetrics(req, harvesterID, metrics):
 
     host = req.get_remote_host()
     return_value = None
-    tStart = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+    tStart = naive_utcnow()
 
     # convert
     try:
@@ -1526,7 +1537,7 @@ def updateServiceMetrics(req, harvesterID, metrics):
     if return_value is None:
         return_value = userIF.updateServiceMetrics(user, host, harvesterID, data)
 
-    tDelta = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None) - tStart
+    tDelta = naive_utcnow() - tStart
     _logger.debug(f"updateServiceMetrics {harvesterID} took {tDelta.seconds}.{tDelta.microseconds // 1000:03d} sec")
 
     return return_value
@@ -1675,7 +1686,7 @@ def decode_idds_enum(d):
 def relay_idds_command(req, command_name, args=None, kwargs=None, manager=None, json_outputs=None):
     tmp_log = LogWrapper(
         _logger,
-        f"relay_idds_command-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}",
+        f"relay_idds_command-{naive_utcnow().isoformat('/')}",
     )
     # check security
     if not isSecure(req):
@@ -1738,7 +1749,7 @@ def execute_idds_workflow_command(req, command_name, kwargs=None, json_outputs=N
     try:
         tmp_log = LogWrapper(
             _logger,
-            f"execute_idds_workflow_command-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}",
+            f"execute_idds_workflow_command-{naive_utcnow().isoformat('/')}",
         )
         if kwargs:
             try:
@@ -1818,7 +1829,7 @@ def send_command_to_job(req, panda_id, com):
 
 # set user secret
 def set_user_secret(req, key=None, value=None):
-    tmp_log = LogWrapper(_logger, f"set_user_secret-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"set_user_secret-{naive_utcnow().isoformat('/')}")
     # get owner
     dn = req.subprocess_env.get("SSL_CLIENT_S_DN")
     if not dn:
@@ -1831,7 +1842,7 @@ def set_user_secret(req, key=None, value=None):
 
 # get user secrets
 def get_user_secrets(req, keys=None, get_json=None):
-    tmp_log = LogWrapper(_logger, f"get_user_secrets-{datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None).isoformat('/')}")
+    tmp_log = LogWrapper(_logger, f"get_user_secrets-{naive_utcnow().isoformat('/')}")
     # get owner
     dn = req.subprocess_env.get("SSL_CLIENT_S_DN")
     get_json = resolve_true(get_json)
